local C = {}
local Categories = {
    'Axe', '1H', '2H', 'Ammo', 'Armor', 'Banner', 'Battery', 'Bow', 'Belt', 'Bijou',
    'Boots', 'Box', 'Bracer', 'Cask', 'Chest', 'Crate', 'Crown', 'DataCrystal', 'DiabloStone',
    'Drink', 'Egg', 'Elemental', 'Enchant', 'Fishing', 'Food', 'Fabric', 'Feather', 'Gauntlets',
    'Gizmo', 'Hammer', 'Helmet', 'Holiday', 'Ingot', 'Jewelcrafting', 'Jewelry',
    'Letter', 'Mace', 'Mask', 'Musket',
    'Misc - Bag',
    'Misc - Bandana/Basket/Birdbeck',
    'Misc - Bandage/Beer/Bomb',
    'Misc - Bone/Book/Branch',
    'Misc - Candle-Cape',
    'Misc - Cauldron-Coin',
    'Misc - Comb-DragonKite',
    'Misc - Drum-Fish',
    'Misc - Flower-Gem',
    'Misc - Gift-Herb',
    'Misc - Hook-Missile',
    'Misc - MonsterClaw-OrnateBox',
    'Misc - Pelt-Quiver',
    'Misc - Ribbon-Wrench',
    'Misc - Trinkets/Apexis',
    'Mushroom', 'Netherwhelp', 'Offhand',
    'Ore', 'Pants', 'Pick', 'Poison', 'Potion', 'Qiraj', 'Relics', 'Rod', 'Rose', 'Scroll',
    'Scarab', 'Shield', 'Shirt', 'Spear', 'Shoulder', 'Staff', 'Stone', 'Spear', 'SummerFest',
    'Sword', 'ThrowingAxe', 'ThrowingKnife', 'Torch', 'TradeskillItem', 'Trinket', 'Valentine',
    'Wand', 'Weapon', 'ZulGurubTrinket',
}

local function GetDropDownCategories()
    local dropDownList = {}
    for _,cat in ipairs(Categories) do
       dropDownList[cat] = cat
    end
    return dropDownList
end

C.dropDownItems = GetDropDownCategories()

function C:GetCategoryNames()
    return Categories
end

function C:GetDropDownItems()
    return self.dropDownItems
end

local function getCategory(texturePath)
    if not texturePath then return nil end

    for _,cat in ipairs(Categories) do
        local lcat = string.lower('_' .. cat)
        local lpath = string.lower(texturePath)
        if string.find(lpath, lcat) then
            return cat
        end
    end
    return nil
end

function C:GetItemsByCategory(macroIcons, category)
    -- id, category, path
    local items = {}
    for _, iconId in ipairs(macroIcons) do
        --print('iconId: ', iconId)
        local texturePath = ART_TEXTURES[iconId]
        if texturePath then
            local cat = getCategory(texturePath)
            if cat and category == cat then
                --table.insert(items, {
                --    id = iconId,
                --    category = category,
                --    path = texturePath
                --})
                items[iconId] = texturePath
            end
        end
    end

    return items
end

C.categoriesCache = {
    ['1H'] = {
        [132374] = 'Interface/Icons/INV_1H_Auchindoun_01',
        [132375] = 'Interface/Icons/INV_1H_HaremMatron_D_01',
        [132593] = 'Interface/Icons/INV_Bow_1H_Auchindoun_D_01',
        [133454] = 'Interface/Icons/INV_knife_1h_stratholme_d_01',
        [133455] = 'Interface/Icons/INV_knife_1h_stratholme_d_02',
        [133456] = 'Interface/Icons/INV_knife_1h_stratholme_d_03',
        [133495] = 'Interface/Icons/INV_Mace_1H_Stratholme_D_01',
        [133496] = 'Interface/Icons/INV_Mace_1H_Stratholme_D_02',
        [135318] = 'Interface/Icons/INV_Sword_1H_Blacksmithing_01',
        [135319] = 'Interface/Icons/INV_Sword_1H_Blacksmithing_02',
        [135320] = 'Interface/Icons/INV_Sword_1H_Blacksmithing_03',
        [135481] = 'Interface/Icons/INV_Wand_1H_Stratholme_D_01',
        [135482] = 'Interface/Icons/INV_Wand_1H_Stratholme_D_02'
    },
    ['2H'] = {
        [132376] = 'Interface/Icons/INV_2H_Auchindoun_01',
        [133507] = 'Interface/Icons/INV_Mace_2H_Blacksmithing_01',
        [133508] = 'Interface/Icons/INV_Mace_2H_Blacksmithing_02',
        [133509] = 'Interface/Icons/INV_Mace_2H_Blacksmithing_03',
        [135331] = 'Interface/Icons/INV_Sword_2H_AshbringerCorrupt',
        [135332] = 'Interface/Icons/INV_Sword_2H_Blacksmithing_01',
        [135333] = 'Interface/Icons/INV_Sword_2H_Blacksmithing_02',
        [135334] = 'Interface/Icons/INV_Sword_2H_Blacksmithing_03',
        [135335] = 'Interface/Icons/INV_Sword_2H_Blood_B_01',
        [135336] = 'Interface/Icons/INV_Sword_2H_Blood_B_02',
        [135337] = 'Interface/Icons/INV_Sword_2H_Blood_C_01',
        [135338] = 'Interface/Icons/INV_Sword_2H_Blood_C_02',
        [135339] = 'Interface/Icons/INV_Sword_2H_Blood_C_03'
    },
    Ammo = {
        [132381] = 'Interface/Icons/INV_Ammo_Arrow_01',
        [132382] = 'Interface/Icons/INV_Ammo_Arrow_02',
        [132383] = 'Interface/Icons/INV_Ammo_Bullet_01',
        [132384] = 'Interface/Icons/INV_Ammo_Bullet_02',
        [132385] = 'Interface/Icons/INV_Ammo_Bullet_03',
        [132386] = 'Interface/Icons/INV_Ammo_FireTar',
        [132387] = 'Interface/Icons/INV_Ammo_Snowball',
        [133576] = 'Interface/Icons/INV_Misc_Ammo_Arrow_01',
        [133577] = 'Interface/Icons/INV_Misc_Ammo_Arrow_02',
        [133578] = 'Interface/Icons/INV_Misc_Ammo_Arrow_03',
        [133579] = 'Interface/Icons/INV_Misc_Ammo_Arrow_04',
        [133580] = 'Interface/Icons/INV_Misc_Ammo_Arrow_05',
        [133581] = 'Interface/Icons/INV_Misc_Ammo_Bullet_01',
        [133582] = 'Interface/Icons/INV_Misc_Ammo_Bullet_02',
        [133583] = 'Interface/Icons/INV_Misc_Ammo_Bullet_03',
        [133584] = 'Interface/Icons/INV_Misc_Ammo_Bullet_04',
        [133585] = 'Interface/Icons/INV_Misc_Ammo_Bullet_05',
        [133586] = 'Interface/Icons/INV_Misc_Ammo_Bullet_06',
        [133587] = 'Interface/Icons/INV_Misc_Ammo_Gunpowder_01',
        [133588] = 'Interface/Icons/INV_Misc_Ammo_Gunpowder_02',
        [133589] = 'Interface/Icons/Inv_Misc_ammo_Gunpowder_03',
        [133590] = 'Interface/Icons/Inv_Misc_ammo_Gunpowder_04',
        [133591] = 'Interface/Icons/Inv_Misc_ammo_Gunpowder_05',
        [133592] = 'Interface/Icons/Inv_Misc_ammo_Gunpowder_06',
        [133593] = 'Interface/Icons/Inv_Misc_ammo_Gunpowder_07'
    },
    Armor = {
        [132388] = 'Interface/Icons/INV_Armor_Helm_Plate_Naxxramas_RaidWarrior_C_01',
        [132389] = 'Interface/Icons/INV_Armor_Shield_Naxxramas_D_01',
        [132390] = 'Interface/Icons/INV_Armor_Shield_Naxxramas_D_02',
        [132391] = 'Interface/Icons/INV_Armor_Shoulder_Plate_Naxxramas_RaidWarrior_C_01',
        [133596] = 'Interface/Icons/INV_Misc_ArmorKit_01',
        [133597] = 'Interface/Icons/INV_Misc_ArmorKit_02',
        [133598] = 'Interface/Icons/INV_Misc_ArmorKit_03',
        [133599] = 'Interface/Icons/INV_Misc_ArmorKit_04',
        [133600] = 'Interface/Icons/INV_Misc_ArmorKit_05',
        [133601] = 'Interface/Icons/INV_Misc_ArmorKit_06',
        [133602] = 'Interface/Icons/INV_Misc_ArmorKit_07',
        [133603] = 'Interface/Icons/INV_Misc_ArmorKit_08',
        [133604] = 'Interface/Icons/INV_Misc_ArmorKit_09',
        [133605] = 'Interface/Icons/INV_Misc_ArmorKit_10',
        [133606] = 'Interface/Icons/INV_Misc_ArmorKit_11',
        [133607] = 'Interface/Icons/INV_Misc_ArmorKit_12',
        [133608] = 'Interface/Icons/INV_Misc_ArmorKit_14',
        [133609] = 'Interface/Icons/INV_Misc_ArmorKit_15',
        [133610] = 'Interface/Icons/INV_Misc_ArmorKit_16',
        [133611] = 'Interface/Icons/INV_Misc_ArmorKit_17',
        [133612] = 'Interface/Icons/INV_Misc_ArmorKit_18',
        [133613] = 'Interface/Icons/INV_Misc_ArmorKit_19',
        [133614] = 'Interface/Icons/INV_Misc_ArmorKit_20',
        [133615] = 'Interface/Icons/INV_Misc_ArmorKit_21',
        [133616] = 'Interface/Icons/INV_Misc_ArmorKit_22',
        [133617] = 'Interface/Icons/INV_Misc_ArmorKit_23',
        [133618] = 'Interface/Icons/INV_Misc_ArmorKit_24',
        [133619] = 'Interface/Icons/INV_Misc_ArmorKit_25',
        [133620] = 'Interface/Icons/INV_Misc_ArmorKit_26',
        [133621] = 'Interface/Icons/INV_Misc_ArmorKit_27'
    },
    Axe = {
        [132392] = 'Interface/Icons/INV_Axe_01',
        [132393] = 'Interface/Icons/INV_Axe_02',
        [132394] = 'Interface/Icons/INV_Axe_03',
        [132395] = 'Interface/Icons/INV_Axe_04',
        [132396] = 'Interface/Icons/INV_Axe_05',
        [132397] = 'Interface/Icons/INV_Axe_06',
        [132398] = 'Interface/Icons/INV_Axe_07',
        [132399] = 'Interface/Icons/INV_Axe_08',
        [132400] = 'Interface/Icons/INV_Axe_09',
        [132401] = 'Interface/Icons/INV_Axe_10',
        [132402] = 'Interface/Icons/INV_Axe_11',
        [132403] = 'Interface/Icons/INV_Axe_12',
        [132404] = 'Interface/Icons/INV_Axe_13',
        [132405] = 'Interface/Icons/INV_Axe_14',
        [132406] = 'Interface/Icons/INV_Axe_15',
        [132407] = 'Interface/Icons/INV_Axe_16',
        [132408] = 'Interface/Icons/INV_Axe_17',
        [132409] = 'Interface/Icons/INV_Axe_18',
        [132410] = 'Interface/Icons/INV_Axe_19',
        [132411] = 'Interface/Icons/INV_Axe_1H_BlackSmithing_01',
        [132412] = 'Interface/Icons/INV_Axe_1H_BlackSmithing_02',
        [132413] = 'Interface/Icons/INV_Axe_1H_BlackSmithing_03',
        [132414] = 'Interface/Icons/INV_Axe_20',
        [132415] = 'Interface/Icons/INV_Axe_21',
        [132416] = 'Interface/Icons/INV_Axe_22',
        [132417] = 'Interface/Icons/INV_Axe_23',
        [132418] = 'Interface/Icons/INV_Axe_24',
        [132419] = 'Interface/Icons/INV_AXE_25',
        [132420] = 'Interface/Icons/INV_AXE_26',
        [132421] = 'Interface/Icons/INV_Axe_29',
        [132422] = 'Interface/Icons/INV_axe_2h_stratholme_d_01',
        [132423] = 'Interface/Icons/INV_Axe_30',
        [132425] = 'Interface/Icons/INV_Axe_32',
        [132426] = 'Interface/Icons/INV_Axe_33',
        [132427] = 'Interface/Icons/INV_Axe_34',
        [132428] = 'Interface/Icons/INV_Axe_35',
        [132429] = 'Interface/Icons/INV_Axe_36',
        [132430] = 'Interface/Icons/INV_Axe_37',
        [132431] = 'Interface/Icons/INV_Axe_38',
        [132432] = 'Interface/Icons/INV_Axe_39',
        [132433] = 'Interface/Icons/INV_Axe_40',
        [132434] = 'Interface/Icons/INV_Axe_44',
        [132435] = 'Interface/Icons/INV_Axe_45',
        [132436] = 'Interface/Icons/INV_Axe_46',
        [132437] = 'Interface/Icons/INV_Axe_49',
        [132438] = 'Interface/Icons/INV_Axe_50',
        [132439] = 'Interface/Icons/INV_Axe_51',
        [132440] = 'Interface/Icons/INV_Axe_52',
        [132441] = 'Interface/Icons/INV_Axe_53',
        [132442] = 'Interface/Icons/INV_Axe_54',
        [132443] = 'Interface/Icons/INV_Axe_55',
        [132444] = 'Interface/Icons/INV_Axe_56',
        [132445] = 'Interface/Icons/INV_Axe_57',
        [132446] = 'Interface/Icons/INV_Axe_59',
        [132447] = 'Interface/Icons/INV_Axe_60',
        [132448] = 'Interface/Icons/INV_Axe_61',
        [132449] = 'Interface/Icons/INV_Axe_62',
        [132450] = 'Interface/Icons/INV_Axe_63',
        [132451] = 'Interface/Icons/INV_Axe_64',
        [132452] = 'Interface/Icons/INV_Axe_65',
        [132453] = 'Interface/Icons/INV_Axe_66',
        [132454] = 'Interface/Icons/INV_Axe_67',
        [132455] = 'Interface/Icons/INV_Axe_68',
        [132456] = 'Interface/Icons/INV_Axe_69',
        [132457] = 'Interface/Icons/INV_Axe_70',
        [132458] = 'Interface/Icons/INV_Axe_71',
        [132459] = 'Interface/Icons/INV_Axe_72',
        [132460] = 'Interface/Icons/INV_Axe_73',
        [132470] = 'Interface/Icons/INV_Axe_84',
        [132471] = 'Interface/Icons/INV_Axe_85'
    },
    Banner = {
        [132482] = 'Interface/Icons/INV_Banner_01',
        [132483] = 'Interface/Icons/INV_Banner_02',
        [132484] = 'Interface/Icons/INV_Banner_03',
        [132485] = 'Interface/Icons/INV_BannerPVP_01',
        [132486] = 'Interface/Icons/INV_BannerPVP_02',
        [132487] = 'Interface/Icons/INV_BannerPVP_03',
        [132619] = 'Interface/Icons/INV_BRD_Banner'
    },
    Battery = {
        [132488] = 'Interface/Icons/INV_Battery_01',
        [132489] = 'Interface/Icons/INV_Battery_02'
    },
    Belt = {
        [132490] = 'Interface/Icons/INV_Belt_01',
        [132491] = 'Interface/Icons/INV_Belt_02',
        [132492] = 'Interface/Icons/INV_Belt_03',
        [132493] = 'Interface/Icons/INV_Belt_04',
        [132494] = 'Interface/Icons/INV_Belt_05',
        [132495] = 'Interface/Icons/INV_Belt_06',
        [132496] = 'Interface/Icons/INV_Belt_07',
        [132497] = 'Interface/Icons/INV_Belt_08',
        [132498] = 'Interface/Icons/INV_Belt_09',
        [132499] = 'Interface/Icons/INV_Belt_10',
        [132500] = 'Interface/Icons/INV_Belt_11',
        [132501] = 'Interface/Icons/INV_Belt_12',
        [132502] = 'Interface/Icons/INV_Belt_13',
        [132503] = 'Interface/Icons/INV_Belt_14',
        [132504] = 'Interface/Icons/INV_Belt_15',
        [132505] = 'Interface/Icons/INV_Belt_16',
        [132506] = 'Interface/Icons/INV_Belt_17',
        [132507] = 'Interface/Icons/INV_Belt_18',
        [132508] = 'Interface/Icons/INV_Belt_19',
        [132509] = 'Interface/Icons/INV_Belt_20',
        [132510] = 'Interface/Icons/INV_Belt_21',
        [132511] = 'Interface/Icons/INV_Belt_22',
        [132512] = 'Interface/Icons/INV_Belt_23',
        [132513] = 'Interface/Icons/INV_Belt_24',
        [132514] = 'Interface/Icons/INV_Belt_25',
        [132515] = 'Interface/Icons/INV_Belt_26',
        [132516] = 'Interface/Icons/INV_Belt_27',
        [132517] = 'Interface/Icons/INV_Belt_28',
        [132518] = 'Interface/Icons/INV_Belt_29',
        [132519] = 'Interface/Icons/INV_Belt_30',
        [132520] = 'Interface/Icons/INV_Belt_31',
        [132521] = 'Interface/Icons/INV_Belt_32',
        [132522] = 'Interface/Icons/INV_Belt_33',
        [132523] = 'Interface/Icons/INV_Belt_34',
        [132524] = 'Interface/Icons/INV_Belt_35'
    },
    Bijou = {
        [132526] = 'Interface/Icons/INV_Bijou_Blue',
        [132527] = 'Interface/Icons/INV_Bijou_Bronze',
        [132528] = 'Interface/Icons/INV_Bijou_Gold',
        [132529] = 'Interface/Icons/INV_Bijou_Green',
        [132530] = 'Interface/Icons/INV_Bijou_Orange',
        [132531] = 'Interface/Icons/INV_Bijou_Purple',
        [132532] = 'Interface/Icons/INV_Bijou_Red',
        [132533] = 'Interface/Icons/INV_Bijou_Silver',
        [132534] = 'Interface/Icons/INV_Bijou_Yellow'
    },
    Boots = {
        [132535] = 'Interface/Icons/INV_Boots_01',
        [132536] = 'Interface/Icons/INV_Boots_02',
        [132537] = 'Interface/Icons/INV_Boots_03',
        [132538] = 'Interface/Icons/INV_Boots_04',
        [132539] = 'Interface/Icons/INV_Boots_05',
        [132540] = 'Interface/Icons/INV_Boots_06',
        [132541] = 'Interface/Icons/INV_Boots_07',
        [132542] = 'Interface/Icons/INV_Boots_08',
        [132543] = 'Interface/Icons/INV_BOOTS_09',
        [132544] = 'Interface/Icons/INV_Boots_Chain_01',
        [132545] = 'Interface/Icons/INV_Boots_Chain_02',
        [132546] = 'Interface/Icons/INV_Boots_Chain_03',
        [132547] = 'Interface/Icons/INV_Boots_Chain_04',
        [132548] = 'Interface/Icons/INV_Boots_Chain_05',
        [132549] = 'Interface/Icons/INV_Boots_Chain_06',
        [132550] = 'Interface/Icons/INV_Boots_Chain_07',
        [132551] = 'Interface/Icons/INV_Boots_Chain_08',
        [132552] = 'Interface/Icons/INV_Boots_Chain_09',
        [132553] = 'Interface/Icons/INV_Boots_Chain_10',
        [132554] = 'Interface/Icons/INV_Boots_Chain_11',
        [132555] = 'Interface/Icons/INV_Boots_Chain_12',
        [132556] = 'Interface/Icons/INV_Boots_Chain_13',
        [132557] = 'Interface/Icons/INV_Boots_Christmas01',
        [132558] = 'Interface/Icons/INV_Boots_Cloth_01',
        [132559] = 'Interface/Icons/INV_Boots_Cloth_02',
        [132560] = 'Interface/Icons/INV_Boots_Cloth_03',
        [132561] = 'Interface/Icons/INV_Boots_Cloth_04',
        [132562] = 'Interface/Icons/INV_Boots_Cloth_05',
        [132563] = 'Interface/Icons/INV_Boots_Cloth_06',
        [132564] = 'Interface/Icons/INV_Boots_Cloth_07',
        [132565] = 'Interface/Icons/INV_Boots_Cloth_08',
        [132566] = 'Interface/Icons/INV_Boots_Cloth_09',
        [132567] = 'Interface/Icons/INV_Boots_Cloth_10',
        [132568] = 'Interface/Icons/INV_Boots_Cloth_11',
        [132569] = 'Interface/Icons/INV_Boots_Cloth_12',
        [132570] = 'Interface/Icons/INV_Boots_Cloth_13',
        [132571] = 'Interface/Icons/INV_Boots_Cloth_14',
        [132572] = 'Interface/Icons/INV_Boots_Cloth_15',
        [132573] = 'Interface/Icons/INV_Boots_Cloth_16',
        [132574] = 'Interface/Icons/INV_Boots_Cloth_17',
        [132575] = 'Interface/Icons/INV_Boots_Cloth_18',
        [132577] = 'Interface/Icons/INV_Boots_Cloth_20',
        [132579] = 'Interface/Icons/INV_Boots_Fabric_01',
        [132580] = 'Interface/Icons/INV_Boots_Leather01',
        [132581] = 'Interface/Icons/INV_Boots_Mail_01',
        [132582] = 'Interface/Icons/INV_Boots_Plate_01',
        [132583] = 'Interface/Icons/INV_Boots_Plate_02',
        [132584] = 'Interface/Icons/INV_Boots_Plate_03',
        [132585] = 'Interface/Icons/INV_Boots_Plate_04',
        [132586] = 'Interface/Icons/INV_Boots_Plate_05',
        [132587] = 'Interface/Icons/INV_Boots_Plate_06',
        [132588] = 'Interface/Icons/INV_Boots_Plate_07',
        [132589] = 'Interface/Icons/INV_Boots_Plate_08',
        [132590] = 'Interface/Icons/INV_Boots_Plate_09',
        [132591] = 'Interface/Icons/INV_Boots_Plate_10',
        [132592] = 'Interface/Icons/INV_Boots_Wolf'
    },
    Bow = {
        [133748] = 'Interface/Icons/INV_Misc_Bowl_01',
        [135461] = 'Interface/Icons/INV_WAEPON_BOW_ZULGRUB_D_01',
        [135462] = 'Interface/Icons/INV_WAEPON_BOW_ZULGRUB_D_02',
        [135489] = 'Interface/Icons/INV_Weapon_Bow_01',
        [135490] = 'Interface/Icons/INV_Weapon_Bow_02',
        [135491] = 'Interface/Icons/INV_Weapon_Bow_03',
        [135492] = 'Interface/Icons/INV_Weapon_Bow_04',
        [135493] = 'Interface/Icons/INV_Weapon_Bow_05',
        [135494] = 'Interface/Icons/INV_Weapon_Bow_06',
        [135495] = 'Interface/Icons/INV_Weapon_Bow_07',
        [135496] = 'Interface/Icons/INV_Weapon_Bow_08',
        [135497] = 'Interface/Icons/INV_Weapon_Bow_09',
        [135498] = 'Interface/Icons/INV_Weapon_Bow_10',
        [135499] = 'Interface/Icons/INV_Weapon_Bow_11',
        [135500] = 'Interface/Icons/INV_Weapon_Bow_12',
        [135501] = 'Interface/Icons/INV_Weapon_Bow_13',
        [135502] = 'Interface/Icons/INV_WEAPON_BOW_14',
        [135503] = 'Interface/Icons/INV_Weapon_Bow_15',
        [135504] = 'Interface/Icons/INV_Weapon_Bow_16',
        [135505] = 'Interface/Icons/INV_Weapon_Bow_17',
        [135506] = 'Interface/Icons/INV_Weapon_Bow_18',
        [135507] = 'Interface/Icons/INV_Weapon_Bow_19',
        [135508] = 'Interface/Icons/INV_Weapon_Bow_20',
        [135509] = 'Interface/Icons/INV_Weapon_Bow_28',
        [135510] = 'Interface/Icons/INV_Weapon_Bow_30',
        [135511] = 'Interface/Icons/INV_Weapon_Bow_31',
        [135512] = 'Interface/Icons/INV_Weapon_Bow_32',
        [135517] = 'Interface/Icons/INV_Weapon_Bow_37',
        [135518] = 'Interface/Icons/INV_WEAPON_BOW_38',
        [135519] = 'Interface/Icons/INV_WEAPON_BOW_39'
    },
    Box = {
        [132594] = 'Interface/Icons/INV_Box_01',
        [132595] = 'Interface/Icons/INV_Box_02',
        [132596] = 'Interface/Icons/INV_Box_03',
        [132597] = 'Interface/Icons/INV_Box_04',
        [132598] = 'Interface/Icons/INV_Box_Birdcage_01',
        [132599] = 'Interface/Icons/INV_Box_PetCarrier_01'
    },
    Bracer = {
        [132600] = 'Interface/Icons/INV_Bracer_01',
        [132601] = 'Interface/Icons/INV_Bracer_02',
        [132602] = 'Interface/Icons/INV_Bracer_03',
        [132603] = 'Interface/Icons/INV_Bracer_04',
        [132604] = 'Interface/Icons/INV_Bracer_05',
        [132605] = 'Interface/Icons/INV_Bracer_06',
        [132606] = 'Interface/Icons/INV_Bracer_07',
        [132607] = 'Interface/Icons/INV_Bracer_08',
        [132608] = 'Interface/Icons/INV_Bracer_09',
        [132609] = 'Interface/Icons/INV_Bracer_10',
        [132610] = 'Interface/Icons/INV_Bracer_11',
        [132611] = 'Interface/Icons/INV_Bracer_12',
        [132612] = 'Interface/Icons/INV_Bracer_13',
        [132613] = 'Interface/Icons/INV_Bracer_14',
        [132614] = 'Interface/Icons/INV_Bracer_15',
        [132615] = 'Interface/Icons/INV_Bracer_16',
        [132616] = 'Interface/Icons/INV_Bracer_17',
        [132617] = 'Interface/Icons/INV_Bracer_18',
        [132618] = 'Interface/Icons/INV_Bracer_19'
    },
    Cask = {
        [132620] = 'Interface/Icons/INV_Cask_01',
        [132621] = 'Interface/Icons/INV_Cask_02',
        [132622] = 'Interface/Icons/INV_Cask_03',
        [132623] = 'Interface/Icons/INV_Cask_04'
    },
    Chest = {
        [132624] = 'Interface/Icons/INV_Chest_Chain',
        [132625] = 'Interface/Icons/INV_Chest_Chain_03',
        [132626] = 'Interface/Icons/INV_Chest_Chain_04',
        [132627] = 'Interface/Icons/INV_Chest_Chain_05',
        [132628] = 'Interface/Icons/INV_Chest_Chain_06',
        [132629] = 'Interface/Icons/INV_Chest_Chain_07',
        [132630] = 'Interface/Icons/INV_Chest_Chain_08',
        [132631] = 'Interface/Icons/INV_Chest_Chain_09',
        [132632] = 'Interface/Icons/INV_Chest_Chain_10',
        [132633] = 'Interface/Icons/INV_Chest_Chain_11',
        [132634] = 'Interface/Icons/INV_Chest_Chain_12',
        [132635] = 'Interface/Icons/INV_Chest_Chain_13',
        [132636] = 'Interface/Icons/INV_Chest_Chain_14',
        [132637] = 'Interface/Icons/INV_Chest_Chain_15',
        [132638] = 'Interface/Icons/INV_Chest_Chain_16',
        [132639] = 'Interface/Icons/INV_Chest_Chain_17',
        [132640] = 'Interface/Icons/INV_Chest_Christmas01',
        [132641] = 'Interface/Icons/INV_Chest_Christmas02',
        [132642] = 'Interface/Icons/INV_Chest_Cloth_01',
        [132643] = 'Interface/Icons/INV_Chest_Cloth_02',
        [132644] = 'Interface/Icons/INV_Chest_Cloth_03',
        [132645] = 'Interface/Icons/INV_Chest_Cloth_04',
        [132646] = 'Interface/Icons/INV_Chest_Cloth_05',
        [132647] = 'Interface/Icons/INV_Chest_Cloth_06',
        [132648] = 'Interface/Icons/INV_Chest_Cloth_07',
        [132649] = 'Interface/Icons/INV_Chest_Cloth_08',
        [132650] = 'Interface/Icons/INV_Chest_Cloth_09',
        [132651] = 'Interface/Icons/INV_Chest_Cloth_10',
        [132652] = 'Interface/Icons/INV_Chest_Cloth_11',
        [132653] = 'Interface/Icons/INV_Chest_Cloth_12',
        [132654] = 'Interface/Icons/INV_Chest_Cloth_13',
        [132655] = 'Interface/Icons/INV_Chest_Cloth_14',
        [132656] = 'Interface/Icons/INV_Chest_Cloth_15',
        [132657] = 'Interface/Icons/INV_Chest_Cloth_16',
        [132658] = 'Interface/Icons/INV_Chest_Cloth_17',
        [132659] = 'Interface/Icons/INV_Chest_Cloth_18',
        [132660] = 'Interface/Icons/INV_Chest_Cloth_19',
        [132661] = 'Interface/Icons/INV_Chest_Cloth_20',
        [132662] = 'Interface/Icons/INV_Chest_Cloth_21',
        [132663] = 'Interface/Icons/INV_Chest_Cloth_22',
        [132664] = 'Interface/Icons/INV_Chest_Cloth_23',
        [132665] = 'Interface/Icons/INV_Chest_Cloth_24',
        [132666] = 'Interface/Icons/INV_Chest_Cloth_25',
        [132667] = 'Interface/Icons/INV_Chest_Cloth_26',
        [132668] = 'Interface/Icons/INV_Chest_Cloth_27',
        [132669] = 'Interface/Icons/INV_Chest_Cloth_28',
        [132670] = 'Interface/Icons/INV_Chest_Cloth_29',
        [132671] = 'Interface/Icons/INV_Chest_Cloth_30',
        [132672] = 'Interface/Icons/INV_Chest_Cloth_31',
        [132673] = 'Interface/Icons/INV_Chest_Cloth_32',
        [132674] = 'Interface/Icons/INV_Chest_Cloth_33',
        [132675] = 'Interface/Icons/INV_Chest_Cloth_34',
        [132676] = 'Interface/Icons/INV_Chest_Cloth_35',
        [132677] = 'Interface/Icons/INV_Chest_Cloth_36',
        [132678] = 'Interface/Icons/INV_Chest_Cloth_37',
        [132679] = 'Interface/Icons/INV_Chest_Cloth_38',
        [132680] = 'Interface/Icons/INV_Chest_Cloth_39',
        [132681] = 'Interface/Icons/INV_Chest_Cloth_40',
        [132682] = 'Interface/Icons/INV_Chest_Cloth_41',
        [132683] = 'Interface/Icons/INV_Chest_Cloth_42',
        [132684] = 'Interface/Icons/INV_Chest_Cloth_43',
        [132685] = 'Interface/Icons/INV_Chest_Cloth_44',
        [132686] = 'Interface/Icons/INV_Chest_Cloth_45',
        [132687] = 'Interface/Icons/INV_Chest_Cloth_46',
        [132688] = 'Interface/Icons/INV_Chest_Cloth_47',
        [132689] = 'Interface/Icons/INV_Chest_Cloth_48',
        [132690] = 'Interface/Icons/INV_Chest_Cloth_49',
        [132691] = 'Interface/Icons/INV_Chest_Cloth_50',
        [132692] = 'Interface/Icons/INV_Chest_Cloth_51',
        [132693] = 'Interface/Icons/INV_Chest_Cloth_52',
        [132694] = 'Interface/Icons/INV_Chest_Cloth_53',
        [132695] = 'Interface/Icons/INV_Chest_Cloth_54',
        [132696] = 'Interface/Icons/INV_Chest_Cloth_55',
        [132697] = 'Interface/Icons/INV_Chest_Cloth_56',
        [132698] = 'Interface/Icons/INV_Chest_Cloth_57',
        [132699] = 'Interface/Icons/INV_Chest_Cloth_58',
        [132700] = 'Interface/Icons/INV_Chest_Cloth_59',
        [132701] = 'Interface/Icons/INV_Chest_Cloth_60',
        [132702] = 'Interface/Icons/INV_Chest_Cloth_61',
        [132703] = 'Interface/Icons/INV_Chest_Cloth_62',
        [132704] = 'Interface/Icons/INV_Chest_Cloth_63',
        [132705] = 'Interface/Icons/INV_Chest_Cloth_64',
        [132706] = 'Interface/Icons/INV_Chest_Cloth_65',
        [132707] = 'Interface/Icons/INV_Chest_Cloth_66',
        [132708] = 'Interface/Icons/INV_Chest_Cloth_67',
        [132709] = 'Interface/Icons/INV_CHEST_CLOTH_68',
        [132710] = 'Interface/Icons/INV_Chest_Cloth_69',
        [132711] = 'Interface/Icons/INV_Chest_Cloth_70',
        [132713] = 'Interface/Icons/INV_Chest_Cloth_72',
        [132715] = 'Interface/Icons/INV_Chest_Fur',
        [132716] = 'Interface/Icons/INV_Chest_Leather_01',
        [132717] = 'Interface/Icons/INV_Chest_Leather_02',
        [132718] = 'Interface/Icons/INV_Chest_Leather_03',
        [132719] = 'Interface/Icons/INV_Chest_Leather_04',
        [132720] = 'Interface/Icons/INV_Chest_Leather_05',
        [132721] = 'Interface/Icons/INV_Chest_Leather_06',
        [132722] = 'Interface/Icons/INV_Chest_Leather_07',
        [132723] = 'Interface/Icons/INV_Chest_Leather_08',
        [132724] = 'Interface/Icons/INV_Chest_Leather_09',
        [132725] = 'Interface/Icons/INV_Chest_Leather_10',
        [132726] = 'Interface/Icons/INV_Chest_Leather_11',
        [132727] = 'Interface/Icons/INV_Chest_Leather_12',
        [132728] = 'Interface/Icons/INV_Chest_Leather_13',
        [132729] = 'Interface/Icons/INV_Chest_Leather_14',
        [132730] = 'Interface/Icons/INV_CHEST_LEATHER_15',
        [132731] = 'Interface/Icons/INV_CHEST_LEATHER_16',
        [132732] = 'Interface/Icons/INV_CHEST_MAIL_02',
        [132733] = 'Interface/Icons/INV_CHEST_MAIL_03',
        [132734] = 'Interface/Icons/INV_CHEST_MAIL_04',
        [132735] = 'Interface/Icons/INV_Chest_Mail_05',
        [132736] = 'Interface/Icons/INV_Chest_Plate01',
        [132737] = 'Interface/Icons/INV_Chest_Plate02',
        [132738] = 'Interface/Icons/INV_Chest_Plate03',
        [132739] = 'Interface/Icons/INV_Chest_Plate04',
        [132740] = 'Interface/Icons/INV_Chest_Plate05',
        [132741] = 'Interface/Icons/INV_Chest_Plate06',
        [132742] = 'Interface/Icons/INV_Chest_Plate07',
        [132743] = 'Interface/Icons/INV_Chest_Plate08',
        [132744] = 'Interface/Icons/INV_Chest_Plate09',
        [132745] = 'Interface/Icons/INV_Chest_Plate10',
        [132746] = 'Interface/Icons/INV_Chest_Plate11',
        [132747] = 'Interface/Icons/INV_Chest_Plate12',
        [132748] = 'Interface/Icons/INV_Chest_Plate13',
        [132749] = 'Interface/Icons/INV_Chest_Plate14',
        [132750] = 'Interface/Icons/INV_Chest_Plate15',
        [132751] = 'Interface/Icons/INV_Chest_Plate16',
        [132752] = 'Interface/Icons/INV_Chest_Plate18',
        [132753] = 'Interface/Icons/INV_Chest_Plate19',
        [132754] = 'Interface/Icons/INV_Chest_Plate20',
        [132755] = 'Interface/Icons/INV_Chest_Plate21',
        [132756] = 'Interface/Icons/INV_CHEST_PLATE_22',
        [132757] = 'Interface/Icons/INV_CHEST_PLATE_23',
        [132758] = 'Interface/Icons/INV_Chest_Plate_24',
        [132759] = 'Interface/Icons/INV_Chest_Samurai',
        [132760] = 'Interface/Icons/INV_Chest_Wolf'
    },
    Crate = {
        [132761] = 'Interface/Icons/INV_Crate_01',
        [132762] = 'Interface/Icons/INV_Crate_02',
        [132763] = 'Interface/Icons/INV_Crate_03',
        [132764] = 'Interface/Icons/INV_Crate_04',
        [132765] = 'Interface/Icons/INV_Crate_05',
        [132766] = 'Interface/Icons/INV_Crate_06'
    },
    Crown = {
        [132767] = 'Interface/Icons/INV_Crown_01',
        [132768] = 'Interface/Icons/INV_Crown_02',
        [132769] = 'Interface/Icons/INV_Crown_13',
        [132770] = 'Interface/Icons/INV_Crown_14',
        [132771] = 'Interface/Icons/INV_Crown_15'
    },
    DataCrystal = {
        [132775] = 'Interface/Icons/INV_DataCrystal01',
        [132776] = 'Interface/Icons/INV_DataCrystal02',
        [132777] = 'Interface/Icons/INV_DataCrystal03',
        [132778] = 'Interface/Icons/INV_DataCrystal04',
        [132779] = 'Interface/Icons/INV_DataCrystal05',
        [132780] = 'Interface/Icons/INV_DataCrystal06',
        [132781] = 'Interface/Icons/INV_DataCrystal07',
        [132782] = 'Interface/Icons/INV_DataCrystal08',
        [132783] = 'Interface/Icons/INV_DataCrystal09',
        [132784] = 'Interface/Icons/INV_DataCrystal10',
        [132785] = 'Interface/Icons/INV_DataCrystal11',
        [132786] = 'Interface/Icons/INV_DataCrystal12'
    },
    DiabloStone = {
        [132787] = 'Interface/Icons/INV_DiabloStone'
    },
    Drink = {
        [132788] = 'Interface/Icons/INV_Drink_01',
        [132789] = 'Interface/Icons/INV_Drink_02',
        [132790] = 'Interface/Icons/INV_Drink_03',
        [132791] = 'Interface/Icons/INV_Drink_04',
        [132792] = 'Interface/Icons/INV_Drink_05',
        [132793] = 'Interface/Icons/INV_Drink_06',
        [132794] = 'Interface/Icons/INV_DRINK_07',
        [132795] = 'Interface/Icons/INV_Drink_08',
        [132796] = 'Interface/Icons/INV_Drink_09',
        [132797] = 'Interface/Icons/INV_Drink_10',
        [132798] = 'Interface/Icons/INV_Drink_11',
        [132799] = 'Interface/Icons/INV_Drink_12',
        [132800] = 'Interface/Icons/INV_Drink_13',
        [132801] = 'Interface/Icons/INV_Drink_14',
        [132802] = 'Interface/Icons/INV_Drink_15',
        [132803] = 'Interface/Icons/INV_Drink_16',
        [132804] = 'Interface/Icons/INV_Drink_17',
        [132805] = 'Interface/Icons/INV_Drink_18',
        [132806] = 'Interface/Icons/INV_Drink_19',
        [132807] = 'Interface/Icons/INV_Drink_20',
        [132808] = 'Interface/Icons/INV_Drink_21',
        [132809] = 'Interface/Icons/INV_Drink_22',
        [132810] = 'Interface/Icons/INV_Drink_23',
        [132815] = 'Interface/Icons/INV_Drink_Milk_01',
        [132816] = 'Interface/Icons/INV_Drink_Milk_02',
        [132817] = 'Interface/Icons/INV_Drink_Milk_03',
        [132818] = 'Interface/Icons/INV_Drink_Milk_04',
        [132819] = 'Interface/Icons/INV_Drink_Milk_05',
        [132820] = 'Interface/Icons/INV_Drink_Waterskin_01',
        [132821] = 'Interface/Icons/INV_Drink_Waterskin_02',
        [132822] = 'Interface/Icons/INV_Drink_Waterskin_03',
        [132823] = 'Interface/Icons/INV_Drink_Waterskin_04',
        [132824] = 'Interface/Icons/INV_Drink_Waterskin_05',
        [132825] = 'Interface/Icons/INV_Drink_Waterskin_06',
        [132826] = 'Interface/Icons/INV_Drink_Waterskin_07',
        [132827] = 'Interface/Icons/INV_Drink_Waterskin_08',
        [132828] = 'Interface/Icons/INV_Drink_Waterskin_09',
        [132829] = 'Interface/Icons/INV_Drink_Waterskin_10',
        [132830] = 'Interface/Icons/INV_Drink_Waterskin_11',
        [132831] = 'Interface/Icons/INV_Drink_Waterskin_12'
    },
    Egg = {
        [132832] = 'Interface/Icons/INV_Egg_01',
        [132833] = 'Interface/Icons/INV_Egg_02',
        [132834] = 'Interface/Icons/INV_Egg_03',
        [132835] = 'Interface/Icons/INV_Egg_04',
        [132836] = 'Interface/Icons/INV_Egg_05'
    },
    Elemental = {
        [132837] = 'Interface/Icons/INV_Elemental_Mote_Air01',
        [132838] = 'Interface/Icons/INV_Elemental_Mote_Earth01',
        [132839] = 'Interface/Icons/INV_Elemental_Mote_Fire01',
        [132840] = 'Interface/Icons/INV_Elemental_Mote_Life01',
        [132841] = 'Interface/Icons/INV_Elemental_Mote_Mana',
        [132842] = 'Interface/Icons/INV_Elemental_Mote_Nether',
        [132843] = 'Interface/Icons/INV_Elemental_Mote_Shadow01',
        [132844] = 'Interface/Icons/INV_Elemental_Mote_Water01',
        [132845] = 'Interface/Icons/INV_Elemental_Primal_Air',
        [132846] = 'Interface/Icons/INV_Elemental_Primal_Earth',
        [132847] = 'Interface/Icons/INV_Elemental_Primal_Fire',
        [132848] = 'Interface/Icons/INV_Elemental_Primal_Life',
        [132849] = 'Interface/Icons/INV_Elemental_Primal_Mana',
        [132850] = 'Interface/Icons/INV_Elemental_Primal_Nether',
        [132851] = 'Interface/Icons/INV_Elemental_Primal_Shadow',
        [132852] = 'Interface/Icons/INV_Elemental_Primal_Water',
        [133007] = 'Interface/Icons/INV_Gizmo_ElementalBlastingPowder',
        [134486] = 'Interface/Icons/INV_MISC_TICKET_TAROT_ELEMENTAL_01'
    },
    Enchant = {
        [132853] = 'Interface/Icons/INV_Enchant_Disenchant',
        [132854] = 'Interface/Icons/INV_Enchant_DustArcane',
        [132855] = 'Interface/Icons/INV_Enchant_DustDream',
        [132856] = 'Interface/Icons/INV_Enchant_DustIllusion',
        [132857] = 'Interface/Icons/INV_Enchant_DustSoul',
        [132858] = 'Interface/Icons/INV_Enchant_DustStrange',
        [132859] = 'Interface/Icons/INV_Enchant_DustVision',
        [132860] = 'Interface/Icons/INV_Enchant_EssenceArcaneLarge',
        [132861] = 'Interface/Icons/INV_Enchant_EssenceArcaneSmall',
        [132862] = 'Interface/Icons/INV_Enchant_EssenceAstralLarge',
        [132863] = 'Interface/Icons/INV_Enchant_EssenceAstralSmall',
        [132864] = 'Interface/Icons/INV_Enchant_EssenceEternalLarge',
        [132865] = 'Interface/Icons/INV_Enchant_EssenceEternalSmall',
        [132866] = 'Interface/Icons/INV_Enchant_EssenceMagicLarge',
        [132867] = 'Interface/Icons/INV_Enchant_EssenceMagicSmall',
        [132868] = 'Interface/Icons/INV_Enchant_EssenceMysticalLarge',
        [132869] = 'Interface/Icons/INV_Enchant_EssenceMysticalSmall',
        [132870] = 'Interface/Icons/INV_Enchant_EssenceNetherLarge',
        [132871] = 'Interface/Icons/INV_Enchant_EssenceNetherSmall',
        [132872] = 'Interface/Icons/INV_Enchant_PrismaticSphere',
        [132873] = 'Interface/Icons/INV_Enchant_ShardBrilliantLarge',
        [132874] = 'Interface/Icons/INV_Enchant_ShardBrilliantSmall',
        [132875] = 'Interface/Icons/INV_Enchant_ShardGleamingSmall',
        [132876] = 'Interface/Icons/INV_Enchant_ShardGlimmeringLarge',
        [132877] = 'Interface/Icons/INV_Enchant_ShardGlimmeringSmall',
        [132878] = 'Interface/Icons/INV_Enchant_ShardGlowingLarge',
        [132879] = 'Interface/Icons/INV_Enchant_ShardGlowingSmall',
        [132880] = 'Interface/Icons/INV_Enchant_ShardNexusLarge',
        [132881] = 'Interface/Icons/INV_Enchant_ShardPrismaticLarge',
        [132882] = 'Interface/Icons/INV_Enchant_ShardPrismaticSmall',
        [132883] = 'Interface/Icons/INV_Enchant_ShardRadientLarge',
        [132884] = 'Interface/Icons/INV_Enchant_ShardRadientSmall',
        [132885] = 'Interface/Icons/INV_Enchant_VoidCrystal',
        [132886] = 'Interface/Icons/INV_Enchant_VoidSphere',
        [133665] = 'Interface/Icons/INV_Misc_Bag_EnchantedMageweave',
        [133666] = 'Interface/Icons/INV_Misc_Bag_EnchantedRunecloth',
        [134922] = 'Interface/Icons/INV_Rod_EnchantedAdamantite',
        [134923] = 'Interface/Icons/INV_Rod_EnchantedEternium',
        [134924] = 'Interface/Icons/INV_Rod_EnchantedFelsteel'
    },
    Fabric = {
        [132887] = 'Interface/Icons/INV_Fabric_Felcloth_Ebon',
        [132888] = 'Interface/Icons/INV_Fabric_FelRag',
        [132889] = 'Interface/Icons/INV_Fabric_Linen_01',
        [132890] = 'Interface/Icons/INV_Fabric_Linen_02',
        [132891] = 'Interface/Icons/INV_Fabric_Linen_03',
        [132892] = 'Interface/Icons/INV_Fabric_Mageweave_01',
        [132893] = 'Interface/Icons/INV_Fabric_Mageweave_02',
        [132894] = 'Interface/Icons/INV_Fabric_Mageweave_03',
        [132895] = 'Interface/Icons/INV_Fabric_MoonRag_01',
        [132896] = 'Interface/Icons/INV_Fabric_MoonRag_02',
        [132897] = 'Interface/Icons/INV_Fabric_MoonRag_Primal',
        [132898] = 'Interface/Icons/INV_Fabric_Netherweave',
        [132899] = 'Interface/Icons/INV_Fabric_Netherweave_Bolt',
        [132900] = 'Interface/Icons/INV_Fabric_Netherweave_Bolt_Imbued',
        [132901] = 'Interface/Icons/INV_Fabric_Purple_01',
        [132902] = 'Interface/Icons/INV_Fabric_Purple_02',
        [132903] = 'Interface/Icons/INV_Fabric_PurpleFire_01',
        [132904] = 'Interface/Icons/INV_Fabric_PurpleFire_02',
        [132905] = 'Interface/Icons/INV_Fabric_Silk_01',
        [132906] = 'Interface/Icons/INV_Fabric_Silk_02',
        [132907] = 'Interface/Icons/INV_Fabric_Silk_03',
        [132908] = 'Interface/Icons/INV_Fabric_Soulcloth',
        [132909] = 'Interface/Icons/INV_Fabric_Soulcloth_Bolt',
        [132910] = 'Interface/Icons/INV_Fabric_Spellfire',
        [132911] = 'Interface/Icons/INV_Fabric_Wool_01',
        [132912] = 'Interface/Icons/INV_Fabric_Wool_02',
        [132913] = 'Interface/Icons/INV_Fabric_Wool_03'
    },
    Feather = {
        [132914] = 'Interface/Icons/INV_Feather_01',
        [132915] = 'Interface/Icons/INV_Feather_02',
        [132916] = 'Interface/Icons/INV_Feather_03',
        [132917] = 'Interface/Icons/INV_Feather_04',
        [132918] = 'Interface/Icons/INV_Feather_05',
        [132919] = 'Interface/Icons/INV_Feather_06',
        [132920] = 'Interface/Icons/INV_Feather_07',
        [132921] = 'Interface/Icons/INV_Feather_08',
        [132922] = 'Interface/Icons/INV_Feather_09',
        [132923] = 'Interface/Icons/INV_Feather_10',
        [132924] = 'Interface/Icons/INV_Feather_11',
        [132925] = 'Interface/Icons/INV_Feather_12',
        [132926] = 'Interface/Icons/INV_Feather_13',
        [132927] = 'Interface/Icons/INV_Feather_14',
        [132928] = 'Interface/Icons/INV_Feather_15',
        [132929] = 'Interface/Icons/INV_Feather_16'
    },
    Fishing = {
        [132930] = 'Interface/Icons/INV_FISHINGCHAIR',
        [132931] = 'Interface/Icons/INV_Fishingpole_01',
        [132932] = 'Interface/Icons/INV_Fishingpole_02'
    },
    Food = {
        [132934] = 'Interface/Icons/INV_Food_ChristmasFruitCake_01',
        [133943] = 'Interface/Icons/INV_Misc_Food_01',
        [133944] = 'Interface/Icons/INV_Misc_Food_02',
        [133945] = 'Interface/Icons/INV_Misc_Food_03',
        [133946] = 'Interface/Icons/INV_Misc_Food_04',
        [133947] = 'Interface/Icons/INV_Misc_Food_05',
        [133948] = 'Interface/Icons/INV_MISC_FOOD_06',
        [133949] = 'Interface/Icons/INV_Misc_Food_07',
        [133950] = 'Interface/Icons/INV_Misc_Food_08',
        [133951] = 'Interface/Icons/INV_Misc_Food_09',
        [133952] = 'Interface/Icons/INV_Misc_Food_10',
        [133953] = 'Interface/Icons/INV_Misc_Food_100',
        [133964] = 'Interface/Icons/INV_MISC_FOOD_11',
        [133968] = 'Interface/Icons/INV_Misc_Food_12',
        [133969] = 'Interface/Icons/INV_Misc_Food_13',
        [133970] = 'Interface/Icons/INV_Misc_Food_14',
        [133971] = 'Interface/Icons/INV_Misc_Food_15',
        [133972] = 'Interface/Icons/INV_MISC_FOOD_16',
        [133973] = 'Interface/Icons/INV_Misc_Food_17',
        [133974] = 'Interface/Icons/INV_Misc_Food_18',
        [133975] = 'Interface/Icons/INV_Misc_Food_19',
        [133976] = 'Interface/Icons/INV_Misc_Food_20',
        [133977] = 'Interface/Icons/INV_Misc_Food_21',
        [133978] = 'Interface/Icons/INV_Misc_Food_22',
        [133979] = 'Interface/Icons/INV_Misc_Food_23',
        [133980] = 'Interface/Icons/INV_Misc_Food_24',
        [133981] = 'Interface/Icons/INV_Misc_Food_25',
        [133982] = 'Interface/Icons/INV_MISC_FOOD_26',
        [133983] = 'Interface/Icons/INV_Misc_Food_27',
        [133984] = 'Interface/Icons/INV_Misc_Food_28',
        [133985] = 'Interface/Icons/INV_Misc_Food_29',
        [133986] = 'Interface/Icons/INV_Misc_Food_30',
        [133987] = 'Interface/Icons/INV_Misc_Food_31',
        [133988] = 'Interface/Icons/INV_Misc_Food_32',
        [133989] = 'Interface/Icons/INV_Misc_Food_33',
        [133990] = 'Interface/Icons/INV_Misc_Food_34',
        [133991] = 'Interface/Icons/INV_Misc_Food_35',
        [133992] = 'Interface/Icons/INV_Misc_Food_36',
        [133993] = 'Interface/Icons/INV_Misc_Food_37',
        [133994] = 'Interface/Icons/INV_Misc_Food_38',
        [133995] = 'Interface/Icons/INV_Misc_Food_39',
        [133996] = 'Interface/Icons/INV_Misc_Food_40',
        [133997] = 'Interface/Icons/INV_Misc_Food_41',
        [133998] = 'Interface/Icons/INV_Misc_Food_42',
        [133999] = 'Interface/Icons/INV_Misc_Food_43',
        [134000] = 'Interface/Icons/INV_Misc_Food_44',
        [134001] = 'Interface/Icons/INV_Misc_Food_45',
        [134002] = 'Interface/Icons/INV_Misc_Food_46',
        [134003] = 'Interface/Icons/INV_Misc_Food_47',
        [134004] = 'Interface/Icons/INV_Misc_Food_48',
        [134005] = 'Interface/Icons/INV_Misc_Food_49',
        [134006] = 'Interface/Icons/INV_Misc_Food_50',
        [134007] = 'Interface/Icons/INV_Misc_Food_51',
        [134008] = 'Interface/Icons/INV_Misc_Food_52',
        [134009] = 'Interface/Icons/INV_Misc_Food_53',
        [134010] = 'Interface/Icons/INV_Misc_Food_54',
        [134011] = 'Interface/Icons/INV_Misc_Food_55',
        [134012] = 'Interface/Icons/INV_Misc_Food_56',
        [134013] = 'Interface/Icons/INV_Misc_Food_57',
        [134014] = 'Interface/Icons/INV_Misc_Food_58',
        [134015] = 'Interface/Icons/INV_Misc_Food_59',
        [134016] = 'Interface/Icons/INV_Misc_Food_60',
        [134017] = 'Interface/Icons/INV_Misc_Food_61',
        [134018] = 'Interface/Icons/INV_Misc_Food_62',
        [134019] = 'Interface/Icons/INV_Misc_Food_63',
        [134020] = 'Interface/Icons/INV_Misc_Food_64',
        [134021] = 'Interface/Icons/INV_Misc_Food_65',
        [134022] = 'Interface/Icons/INV_Misc_Food_66',
        [134023] = 'Interface/Icons/INV_Misc_Food_67',
        [134024] = 'Interface/Icons/INV_Misc_Food_68',
        [134025] = 'Interface/Icons/INV_Misc_Food_69',
        [134026] = 'Interface/Icons/INV_Misc_Food_70',
        [134027] = 'Interface/Icons/INV_Misc_Food_71',
        [134028] = 'Interface/Icons/INV_Misc_Food_72',
        [134029] = 'Interface/Icons/INV_Misc_Food_73CinnamonRoll',
        [134030] = 'Interface/Icons/INV_Misc_Food_74',
        [134031] = 'Interface/Icons/INV_Misc_Food_75',
        [134032] = 'Interface/Icons/INV_Misc_Food_76',
        [134033] = 'Interface/Icons/INV_Misc_Food_77',
        [134034] = 'Interface/Icons/INV_Misc_Food_78',
        [134035] = 'Interface/Icons/INV_Misc_Food_79',
        [134036] = 'Interface/Icons/INV_MISC_FOOD_80',
        [134037] = 'Interface/Icons/INV_MISC_FOOD_81',
        [134038] = 'Interface/Icons/INV_MISC_FOOD_82',
        [134039] = 'Interface/Icons/INV_MISC_FOOD_83_TALBUKSTEAK',
        [134040] = 'Interface/Icons/INV_Misc_Food_84_RoastClefthoof',
        [134041] = 'Interface/Icons/INV_Misc_Food_85_StegadonBite',
        [134042] = 'Interface/Icons/INV_Misc_Food_86_Basilisk',
        [134043] = 'Interface/Icons/INV_Misc_Food_87_SporelingSnack',
        [134044] = 'Interface/Icons/INV_Misc_Food_88_RavagerNuggets',
        [134045] = 'Interface/Icons/INV_Misc_Food_89',
        [134046] = 'Interface/Icons/INV_Misc_Food_90',
        [134047] = 'Interface/Icons/INV_Misc_Food_91',
        [134048] = 'Interface/Icons/INV_Misc_Food_92_Lobster',
        [134049] = 'Interface/Icons/INV_Misc_Food_93_SkethylBerries ',
        [134050] = 'Interface/Icons/INV_Misc_Food_94_GaradarSharp ',
        [134051] = 'Interface/Icons/INV_Misc_Food_95_Grainbread',
        [134052] = 'Interface/Icons/INV_Misc_Food_96_ZangarCaps',
        [134053] = 'Interface/Icons/INV_Misc_Food_97_SunspringCarp',
        [134054] = 'Interface/Icons/INV_Misc_Food_98_Talbuk',
        [134055] = 'Interface/Icons/INV_Misc_Food_99',
        [134056] = 'Interface/Icons/INV_Misc_Food_DimSum',
        [134058] = 'Interface/Icons/INV_Misc_Food_Wheat_01',
        [134059] = 'Interface/Icons/INV_Misc_Food_Wheat_02'
    },
    Gauntlets = {
        [132935] = 'Interface/Icons/INV_Gauntlets_01',
        [132936] = 'Interface/Icons/INV_Gauntlets_02',
        [132937] = 'Interface/Icons/INV_Gauntlets_03',
        [132938] = 'Interface/Icons/INV_Gauntlets_04',
        [132939] = 'Interface/Icons/INV_Gauntlets_05',
        [132940] = 'Interface/Icons/INV_Gauntlets_06',
        [132941] = 'Interface/Icons/INV_Gauntlets_07',
        [132942] = 'Interface/Icons/INV_Gauntlets_08',
        [132943] = 'Interface/Icons/INV_Gauntlets_09',
        [132944] = 'Interface/Icons/INV_Gauntlets_10',
        [132945] = 'Interface/Icons/INV_Gauntlets_11',
        [132946] = 'Interface/Icons/INV_Gauntlets_12',
        [132947] = 'Interface/Icons/INV_Gauntlets_13',
        [132948] = 'Interface/Icons/INV_Gauntlets_14',
        [132949] = 'Interface/Icons/INV_Gauntlets_15',
        [132950] = 'Interface/Icons/INV_Gauntlets_16',
        [132951] = 'Interface/Icons/INV_Gauntlets_17',
        [132952] = 'Interface/Icons/INV_Gauntlets_18',
        [132953] = 'Interface/Icons/INV_Gauntlets_19',
        [132954] = 'Interface/Icons/INV_Gauntlets_20',
        [132955] = 'Interface/Icons/INV_Gauntlets_21',
        [132956] = 'Interface/Icons/INV_Gauntlets_22',
        [132957] = 'Interface/Icons/INV_Gauntlets_23',
        [132958] = 'Interface/Icons/INV_Gauntlets_24',
        [132959] = 'Interface/Icons/INV_Gauntlets_25',
        [132960] = 'Interface/Icons/INV_Gauntlets_26',
        [132961] = 'Interface/Icons/INV_Gauntlets_27',
        [132962] = 'Interface/Icons/INV_Gauntlets_28',
        [132963] = 'Interface/Icons/INV_Gauntlets_29',
        [132964] = 'Interface/Icons/INV_Gauntlets_30',
        [132965] = 'Interface/Icons/INV_Gauntlets_31',
        [132966] = 'Interface/Icons/INV_Gauntlets_32',
        [132967] = 'Interface/Icons/INV_Gauntlets_40',
        [132968] = 'Interface/Icons/INV_Gauntlets_41',
        [132969] = 'Interface/Icons/INV_Gauntlets_44',
        [132970] = 'Interface/Icons/INV_Gauntlets_47',
        [132971] = 'Interface/Icons/INV_Gauntlets_48',
        [132972] = 'Interface/Icons/INV_Gauntlets_49',
        [132973] = 'Interface/Icons/INV_Gauntlets_50',
        [132974] = 'Interface/Icons/INV_Gauntlets_51',
        [132975] = 'Interface/Icons/INV_Gauntlets_52',
        [132976] = 'Interface/Icons/INV_Gauntlets_53',
        [132977] = 'Interface/Icons/INV_Gauntlets_54',
        [132978] = 'Interface/Icons/INV_Gauntlets_55',
        [132979] = 'Interface/Icons/INV_Gauntlets_56',
        [132980] = 'Interface/Icons/INV_Gauntlets_57',
        [132981] = 'Interface/Icons/INV_GAUNTLETS_58',
        [132982] = 'Interface/Icons/INV_GAUNTLETS_59',
        [132983] = 'Interface/Icons/INV_GAUNTLETS_60',
        [132984] = 'Interface/Icons/INV_GAUNTLETS_61',
        [132985] = 'Interface/Icons/INV_GAUNTLETS_62',
        [132986] = 'Interface/Icons/INV_Gauntlets_63',
        [132987] = 'Interface/Icons/INV_Gauntlets_64',
        [132988] = 'Interface/Icons/INV_GAUNTLETS_65',
        [132989] = 'Interface/Icons/INV_GAUNTLETS_66',
        [132990] = 'Interface/Icons/INV_Gauntlets_67',
        [132991] = 'Interface/Icons/INV_Gauntlets_68',
        [132992] = 'Interface/Icons/INV_Gauntlets_69'
    },
    Gizmo = {
        [132995] = 'Interface/Icons/INV_Gizmo_01',
        [132996] = 'Interface/Icons/INV_Gizmo_02',
        [132997] = 'Interface/Icons/INV_Gizmo_03',
        [132998] = 'Interface/Icons/INV_Gizmo_04',
        [132999] = 'Interface/Icons/INV_Gizmo_05',
        [133000] = 'Interface/Icons/INV_Gizmo_06',
        [133001] = 'Interface/Icons/INV_Gizmo_07',
        [133002] = 'Interface/Icons/INV_Gizmo_08',
        [133003] = 'Interface/Icons/INV_Gizmo_09',
        [133004] = 'Interface/Icons/INV_Gizmo_AdamantiteFrame',
        [133005] = 'Interface/Icons/INV_Gizmo_AdamantiteShells',
        [133006] = 'Interface/Icons/INV_Gizmo_BronzeFramework_01',
        [133008] = 'Interface/Icons/INV_Gizmo_FelIronBolts',
        [133009] = 'Interface/Icons/INV_Gizmo_FelIronBomb',
        [133010] = 'Interface/Icons/INV_Gizmo_FelIronCasing',
        [133011] = 'Interface/Icons/INV_Gizmo_FelIronShell',
        [133012] = 'Interface/Icons/INV_Gizmo_FelStabilizer',
        [133013] = 'Interface/Icons/INV_Gizmo_GnomishFlameTurret',
        [133014] = 'Interface/Icons/INV_Gizmo_GoblinBoomBox_01',
        [133015] = 'Interface/Icons/INV_Gizmo_GoblingTonkController',
        [133016] = 'Interface/Icons/INV_Gizmo_HardenedAdamantiteTube',
        [133017] = 'Interface/Icons/INV_Gizmo_HealthPotionPack',
        [133018] = 'Interface/Icons/INV_Gizmo_KhoriumPowerCore',
        [133019] = 'Interface/Icons/INV_GIZMO_MANAPOTIONPACK',
        [133020] = 'Interface/Icons/INV_Gizmo_ManaSyphon',
        [133021] = 'Interface/Icons/INV_Gizmo_MithrilCasing_01',
        [133022] = 'Interface/Icons/INV_Gizmo_MithrilCasing_02',
        [133023] = 'Interface/Icons/INV_Gizmo_NewGoggles',
        [133024] = 'Interface/Icons/INV_Gizmo_Pipe_01',
        [133025] = 'Interface/Icons/INV_Gizmo_Pipe_02',
        [133026] = 'Interface/Icons/INV_Gizmo_Pipe_03',
        [133027] = 'Interface/Icons/INV_Gizmo_Pipe_04',
        [133028] = 'Interface/Icons/INV_Gizmo_Poltryiser_01',
        [133029] = 'Interface/Icons/INV_Gizmo_RocketBoot_01',
        [133030] = 'Interface/Icons/INV_Gizmo_RocketBoot_Destroyed_02',
        [133031] = 'Interface/Icons/INV_Gizmo_RocketBootExtreme',
        [133032] = 'Interface/Icons/INV_Gizmo_RocketLauncher',
        [133033] = 'Interface/Icons/INV_Gizmo_Scope01',
        [133034] = 'Interface/Icons/INV_Gizmo_Scope02',
        [133035] = 'Interface/Icons/INV_Gizmo_SuperSapperCharge',
        [133036] = 'Interface/Icons/INV_Gizmo_TheBiggerOne',
        [133037] = 'Interface/Icons/INV_Gizmo_ZapThrottleGasCollector'
    },
    Hammer = {
        [133038] = 'Interface/Icons/INV_Hammer_01',
        [133039] = 'Interface/Icons/INV_Hammer_02',
        [133040] = 'Interface/Icons/INV_Hammer_03',
        [133041] = 'Interface/Icons/INV_Hammer_04',
        [133042] = 'Interface/Icons/INV_Hammer_05',
        [133043] = 'Interface/Icons/INV_Hammer_06',
        [133044] = 'Interface/Icons/INV_Hammer_07',
        [133045] = 'Interface/Icons/INV_Hammer_08',
        [133046] = 'Interface/Icons/INV_Hammer_09',
        [133047] = 'Interface/Icons/INV_Hammer_10',
        [133048] = 'Interface/Icons/INV_Hammer_11',
        [133049] = 'Interface/Icons/INV_Hammer_12',
        [133050] = 'Interface/Icons/INV_Hammer_13',
        [133051] = 'Interface/Icons/INV_Hammer_14',
        [133052] = 'Interface/Icons/INV_Hammer_15',
        [133053] = 'Interface/Icons/INV_Hammer_16',
        [133054] = 'Interface/Icons/INV_Hammer_17',
        [133055] = 'Interface/Icons/INV_Hammer_18',
        [133056] = 'Interface/Icons/INV_Hammer_19',
        [133057] = 'Interface/Icons/INV_Hammer_20',
        [133058] = 'Interface/Icons/INV_Hammer_21',
        [133059] = 'Interface/Icons/INV_Hammer_22',
        [133060] = 'Interface/Icons/INV_Hammer_23',
        [133061] = 'Interface/Icons/INV_Hammer_24',
        [133062] = 'Interface/Icons/INV_Hammer_25',
        [133063] = 'Interface/Icons/INV_Hammer_26',
        [133064] = 'Interface/Icons/INV_Hammer_27',
        [133065] = 'Interface/Icons/INV_Hammer_28',
        [133066] = 'Interface/Icons/INV_Hammer_Unique_Sulfuras'
    },
    Helmet = {
        [133068] = 'Interface/Icons/INV_Helmet128',
        [133069] = 'Interface/Icons/INV_Helmet_01',
        [133070] = 'Interface/Icons/INV_Helmet_02',
        [133071] = 'Interface/Icons/INV_Helmet_03',
        [133072] = 'Interface/Icons/INV_Helmet_04',
        [133073] = 'Interface/Icons/INV_Helmet_05',
        [133074] = 'Interface/Icons/INV_Helmet_06',
        [133075] = 'Interface/Icons/INV_Helmet_07',
        [133076] = 'Interface/Icons/INV_Helmet_08',
        [133077] = 'Interface/Icons/INV_Helmet_09',
        [133078] = 'Interface/Icons/INV_Helmet_10',
        [133079] = 'Interface/Icons/INV_HELMET_100',
        [133081] = 'Interface/Icons/INV_HELMET_101',
        [133082] = 'Interface/Icons/INV_HELMET_102',
        [133083] = 'Interface/Icons/INV_HELMET_103',
        [133090] = 'Interface/Icons/INV_Helmet_11',
        [133092] = 'Interface/Icons/INV_Helmet_111',
        [133093] = 'Interface/Icons/INV_Helmet_112',
        [133094] = 'Interface/Icons/INV_Helmet_113',
        [133095] = 'Interface/Icons/INV_Helmet_114',
        [133097] = 'Interface/Icons/INV_Helmet_116',
        [133098] = 'Interface/Icons/INV_Helmet_117',
        [133099] = 'Interface/Icons/INV_Helmet_118',
        [133100] = 'Interface/Icons/INV_Helmet_119',
        [133101] = 'Interface/Icons/INV_Helmet_12',
        [133102] = 'Interface/Icons/INV_Helmet_120',
        [133108] = 'Interface/Icons/INV_Helmet_126',
        [133109] = 'Interface/Icons/INV_HELMET_127',
        [133110] = 'Interface/Icons/INV_Helmet_129',
        [133111] = 'Interface/Icons/INV_Helmet_13',
        [133114] = 'Interface/Icons/INV_Helmet_132',
        [133116] = 'Interface/Icons/INV_Helmet_14',
        [133117] = 'Interface/Icons/INV_Helmet_15',
        [133118] = 'Interface/Icons/INV_Helmet_16',
        [133119] = 'Interface/Icons/INV_Helmet_17',
        [133120] = 'Interface/Icons/INV_Helmet_18',
        [133121] = 'Interface/Icons/INV_Helmet_19',
        [133122] = 'Interface/Icons/INV_Helmet_20',
        [133123] = 'Interface/Icons/INV_Helmet_21',
        [133124] = 'Interface/Icons/INV_Helmet_22',
        [133125] = 'Interface/Icons/INV_Helmet_23',
        [133126] = 'Interface/Icons/INV_Helmet_24',
        [133127] = 'Interface/Icons/INV_Helmet_25',
        [133128] = 'Interface/Icons/INV_Helmet_26',
        [133129] = 'Interface/Icons/INV_Helmet_27',
        [133130] = 'Interface/Icons/INV_Helmet_28',
        [133131] = 'Interface/Icons/INV_Helmet_29',
        [133132] = 'Interface/Icons/INV_Helmet_30',
        [133133] = 'Interface/Icons/INV_Helmet_31',
        [133134] = 'Interface/Icons/INV_Helmet_32',
        [133135] = 'Interface/Icons/INV_Helmet_33',
        [133136] = 'Interface/Icons/INV_Helmet_34',
        [133137] = 'Interface/Icons/INV_Helmet_35',
        [133138] = 'Interface/Icons/INV_Helmet_36',
        [133139] = 'Interface/Icons/INV_Helmet_37',
        [133140] = 'Interface/Icons/INV_Helmet_38',
        [133141] = 'Interface/Icons/INV_Helmet_39',
        [133142] = 'Interface/Icons/INV_Helmet_40',
        [133143] = 'Interface/Icons/INV_Helmet_41',
        [133144] = 'Interface/Icons/INV_Helmet_42',
        [133145] = 'Interface/Icons/INV_Helmet_43',
        [133146] = 'Interface/Icons/INV_Helmet_44',
        [133147] = 'Interface/Icons/INV_Helmet_45',
        [133148] = 'Interface/Icons/INV_Helmet_46',
        [133149] = 'Interface/Icons/INV_Helmet_47',
        [133150] = 'Interface/Icons/INV_Helmet_48',
        [133151] = 'Interface/Icons/INV_Helmet_49',
        [133152] = 'Interface/Icons/INV_Helmet_50',
        [133153] = 'Interface/Icons/INV_Helmet_51',
        [133154] = 'Interface/Icons/INV_Helmet_52',
        [133155] = 'Interface/Icons/INV_Helmet_53',
        [133156] = 'Interface/Icons/INV_Helmet_54',
        [133157] = 'Interface/Icons/INV_Helmet_55',
        [133158] = 'Interface/Icons/INV_Helmet_56',
        [133159] = 'Interface/Icons/INV_Helmet_57',
        [133160] = 'Interface/Icons/INV_Helmet_58',
        [133161] = 'Interface/Icons/INV_Helmet_59',
        [133162] = 'Interface/Icons/INV_Helmet_60',
        [133163] = 'Interface/Icons/INV_Helmet_61',
        [133164] = 'Interface/Icons/INV_Helmet_62',
        [133165] = 'Interface/Icons/INV_Helmet_63',
        [133166] = 'Interface/Icons/INV_Helmet_64',
        [133167] = 'Interface/Icons/INV_Helmet_65',
        [133168] = 'Interface/Icons/INV_Helmet_66',
        [133169] = 'Interface/Icons/INV_Helmet_67',
        [133170] = 'Interface/Icons/INV_Helmet_68',
        [133171] = 'Interface/Icons/INV_Helmet_69',
        [133172] = 'Interface/Icons/INV_Helmet_70',
        [133173] = 'Interface/Icons/INV_Helmet_71',
        [133174] = 'Interface/Icons/INV_Helmet_72',
        [133175] = 'Interface/Icons/INV_Helmet_73',
        [133176] = 'Interface/Icons/INV_Helmet_74',
        [133177] = 'Interface/Icons/INV_Helmet_77',
        [133178] = 'Interface/Icons/INV_Helmet_78',
        [133179] = 'Interface/Icons/INV_Helmet_81',
        [133180] = 'Interface/Icons/INV_Helmet_84',
        [133181] = 'Interface/Icons/INV_Helmet_85',
        [133182] = 'Interface/Icons/INV_Helmet_86',
        [133183] = 'Interface/Icons/INV_HELMET_87',
        [133184] = 'Interface/Icons/INV_Helmet_88',
        [133185] = 'Interface/Icons/INV_Helmet_89',
        [133186] = 'Interface/Icons/INV_Helmet_90',
        [133187] = 'Interface/Icons/INV_Helmet_91',
        [133188] = 'Interface/Icons/INV_Helmet_92',
        [133189] = 'Interface/Icons/INV_HELMET_93',
        [133190] = 'Interface/Icons/INV_HELMET_94',
        [133191] = 'Interface/Icons/INV_HELMET_95',
        [133192] = 'Interface/Icons/INV_HELMET_96',
        [133193] = 'Interface/Icons/INV_HELMET_97',
        [133194] = 'Interface/Icons/INV_HELMET_98',
        [133195] = 'Interface/Icons/INV_HELMET_99'
    },
    Holiday = {
        [133196] = 'Interface/Icons/INV_Holiday_BeerfestPretzel01',
        [133197] = 'Interface/Icons/INV_Holiday_BeerfestSausage01',
        [133198] = 'Interface/Icons/INV_Holiday_BeerfestSausage02',
        [133199] = 'Interface/Icons/INV_Holiday_BeerfestSausage03',
        [133200] = 'Interface/Icons/INV_Holiday_BeerfestSausage04',
        [133201] = 'Interface/Icons/INV_Holiday_BrewfestBuff_01',
        [133202] = 'Interface/Icons/INV_Holiday_Christmas_Present_01',
        [133203] = 'Interface/Icons/INV_Holiday_Christmas_Present_02',
        [133204] = 'Interface/Icons/INV_Holiday_Christmas_Present_03',
        [133205] = 'Interface/Icons/INV_Holiday_Christmas_Wrapping_01',
        [133206] = 'Interface/Icons/INV_Holiday_Christmas_Wrapping_02',
        [133207] = 'Interface/Icons/INV_Holiday_Christmas_Wrapping_03',
        [133208] = 'Interface/Icons/INV_Holiday_Summerfest_Petals',
        [133209] = 'Interface/Icons/INV_Holiday_ToW_SpiceBandage',
        [133210] = 'Interface/Icons/INV_Holiday_ToW_SpiceBowl',
        [133211] = 'Interface/Icons/INV_Holiday_ToW_SpiceBrownie',
        [133212] = 'Interface/Icons/INV_Holiday_ToW_SpicePotion01',
        [133213] = 'Interface/Icons/INV_Holiday_ToW_SpicePotion02',
        [133214] = 'Interface/Icons/INV_Holiday_ToW_SpicePotion03'
    },
    Ingot = {
        [133215] = 'Interface/Icons/INV_Ingot_01',
        [133216] = 'Interface/Icons/INV_Ingot_02',
        [133217] = 'Interface/Icons/INV_Ingot_03',
        [133218] = 'Interface/Icons/INV_Ingot_04',
        [133219] = 'Interface/Icons/INV_Ingot_05',
        [133220] = 'Interface/Icons/INV_Ingot_06',
        [133221] = 'Interface/Icons/INV_Ingot_07',
        [133222] = 'Interface/Icons/INV_Ingot_08',
        [133223] = 'Interface/Icons/INV_Ingot_09',
        [133224] = 'Interface/Icons/INV_Ingot_10',
        [133225] = 'Interface/Icons/INV_Ingot_11',
        [133226] = 'Interface/Icons/INV_Ingot_Adamantite',
        [133227] = 'Interface/Icons/INV_Ingot_Bronze',
        [133229] = 'Interface/Icons/INV_Ingot_Eternium',
        [133230] = 'Interface/Icons/INV_Ingot_FelIron',
        [133231] = 'Interface/Icons/INV_Ingot_Felsteel',
        [133232] = 'Interface/Icons/INV_Ingot_Iron',
        [133233] = 'Interface/Icons/INV_Ingot_Mithril',
        [133234] = 'Interface/Icons/INV_Ingot_Steel',
        [133235] = 'Interface/Icons/INV_Ingot_Thorium'
    },
    Jewelcrafting = {
        [133236] = 'Interface/Icons/INV_Jewelcrafting_BlackPearlPanther',
        [133237] = 'Interface/Icons/INV_Jewelcrafting_BronzeSetting',
        [133238] = 'Interface/Icons/INV_Jewelcrafting_CrimsonSpinel_01',
        [133239] = 'Interface/Icons/INV_Jewelcrafting_CrimsonSpinel_02',
        [133240] = 'Interface/Icons/INV_Jewelcrafting_Dawnstone_01',
        [133241] = 'Interface/Icons/INV_Jewelcrafting_Dawnstone_02',
        [133242] = 'Interface/Icons/INV_Jewelcrafting_Dawnstone_03',
        [133243] = 'Interface/Icons/INV_Jewelcrafting_DelicateCopperWire',
        [133244] = 'Interface/Icons/INV_Jewelcrafting_EmpyreanSapphire_01',
        [133245] = 'Interface/Icons/INV_Jewelcrafting_EmpyreanSapphire_02',
        [133246] = 'Interface/Icons/INV_Jewelcrafting_GoldenHare',
        [133247] = 'Interface/Icons/INV_Jewelcrafting_JadeOwl',
        [133248] = 'Interface/Icons/INV_Jewelcrafting_Lionseye_01',
        [133249] = 'Interface/Icons/INV_Jewelcrafting_Lionseye_02',
        [133250] = 'Interface/Icons/INV_Jewelcrafting_LivingRuby_01',
        [133251] = 'Interface/Icons/INV_Jewelcrafting_LivingRuby_02',
        [133252] = 'Interface/Icons/INV_Jewelcrafting_LivingRuby_03',
        [133253] = 'Interface/Icons/INV_Jewelcrafting_MithrilFiligree',
        [133254] = 'Interface/Icons/INV_Jewelcrafting_Nightseye_01',
        [133255] = 'Interface/Icons/INV_Jewelcrafting_Nightseye_02',
        [133256] = 'Interface/Icons/INV_Jewelcrafting_Nightseye_03',
        [133257] = 'Interface/Icons/INV_Jewelcrafting_NobleTopaz_01',
        [133258] = 'Interface/Icons/INV_Jewelcrafting_NobleTopaz_02',
        [133259] = 'Interface/Icons/INV_Jewelcrafting_NobleTopaz_03',
        [133260] = 'Interface/Icons/INV_Jewelcrafting_Pyrestone_01',
        [133261] = 'Interface/Icons/INV_Jewelcrafting_Pyrestone_02',
        [133262] = 'Interface/Icons/INV_Jewelcrafting_RubySerpent',
        [133263] = 'Interface/Icons/INV_Jewelcrafting_SeasprayEmerald_01',
        [133264] = 'Interface/Icons/INV_Jewelcrafting_SeasprayEmerald_02',
        [133265] = 'Interface/Icons/INV_Jewelcrafting_ShadowsongAmethyst_01',
        [133266] = 'Interface/Icons/INV_Jewelcrafting_ShadowsongAmethyst_02',
        [133267] = 'Interface/Icons/INV_Jewelcrafting_StarOfElune_01',
        [133268] = 'Interface/Icons/INV_Jewelcrafting_StarOfElune_02',
        [133269] = 'Interface/Icons/INV_Jewelcrafting_StarOfElune_03',
        [133270] = 'Interface/Icons/INV_Jewelcrafting_Talasite_01',
        [133271] = 'Interface/Icons/INV_Jewelcrafting_Talasite_02',
        [133272] = 'Interface/Icons/INV_Jewelcrafting_Talasite_03',
        [133273] = 'Interface/Icons/INV_Jewelcrafting_ThoriumSetting',
        [133274] = 'Interface/Icons/INV_Jewelcrafting_TruesilverBoar',
        [133275] = 'Interface/Icons/INV_Jewelcrafting_TruesilverCrab'
    },
    Jewelry = {
        [133276] = 'Interface/Icons/INV_Jewelry_Amulet_01',
        [133277] = 'Interface/Icons/INV_Jewelry_Amulet_02',
        [133278] = 'Interface/Icons/INV_Jewelry_Amulet_03',
        [133279] = 'Interface/Icons/INV_Jewelry_Amulet_04',
        [133280] = 'Interface/Icons/INV_Jewelry_Amulet_05',
        [133281] = 'Interface/Icons/INV_Jewelry_Amulet_06',
        [133282] = 'Interface/Icons/INV_Jewelry_Amulet_07',
        [133283] = 'Interface/Icons/INV_Jewelry_FrostwolfTrinket_01',
        [133284] = 'Interface/Icons/INV_Jewelry_FrostwolfTrinket_02',
        [133285] = 'Interface/Icons/INV_Jewelry_FrostwolfTrinket_03',
        [133286] = 'Interface/Icons/INV_Jewelry_FrostwolfTrinket_04',
        [133287] = 'Interface/Icons/INV_Jewelry_FrostwolfTrinket_05',
        [133288] = 'Interface/Icons/INV_Jewelry_Necklace_01',
        [133289] = 'Interface/Icons/INV_Jewelry_Necklace_02',
        [133290] = 'Interface/Icons/INV_Jewelry_Necklace_03',
        [133291] = 'Interface/Icons/INV_Jewelry_Necklace_04',
        [133292] = 'Interface/Icons/INV_Jewelry_Necklace_05',
        [133293] = 'Interface/Icons/INV_Jewelry_Necklace_06',
        [133294] = 'Interface/Icons/INV_Jewelry_Necklace_07',
        [133295] = 'Interface/Icons/INV_Jewelry_Necklace_08',
        [133296] = 'Interface/Icons/INV_Jewelry_Necklace_09',
        [133297] = 'Interface/Icons/INV_Jewelry_Necklace_10',
        [133298] = 'Interface/Icons/INV_Jewelry_Necklace_11',
        [133299] = 'Interface/Icons/INV_Jewelry_Necklace_12',
        [133300] = 'Interface/Icons/INV_Jewelry_Necklace_13',
        [133301] = 'Interface/Icons/INV_Jewelry_Necklace_14',
        [133302] = 'Interface/Icons/INV_JEWELRY_NECKLACE_15',
        [133303] = 'Interface/Icons/INV_Jewelry_Necklace_16',
        [133304] = 'Interface/Icons/INV_Jewelry_Necklace_17',
        [133305] = 'Interface/Icons/INV_Jewelry_Necklace_18',
        [133306] = 'Interface/Icons/INV_Jewelry_Necklace_19',
        [133307] = 'Interface/Icons/INV_Jewelry_Necklace_20',
        [133308] = 'Interface/Icons/INV_Jewelry_Necklace_21',
        [133309] = 'Interface/Icons/INV_Jewelry_Necklace_22',
        [133310] = 'Interface/Icons/INV_Jewelry_Necklace_23',
        [133311] = 'Interface/Icons/INV_Jewelry_Necklace_24',
        [133312] = 'Interface/Icons/INV_Jewelry_Necklace_25',
        [133313] = 'Interface/Icons/INV_Jewelry_Necklace_26',
        [133314] = 'Interface/Icons/INV_Jewelry_Necklace_27',
        [133315] = 'Interface/Icons/INV_Jewelry_Necklace_27Naxxramas',
        [133316] = 'Interface/Icons/INV_Jewelry_Necklace_28',
        [133317] = 'Interface/Icons/INV_Jewelry_Necklace_28Naxxramas',
        [133318] = 'Interface/Icons/INV_Jewelry_Necklace_29',
        [133319] = 'Interface/Icons/INV_Jewelry_Necklace_29Naxxramas',
        [133320] = 'Interface/Icons/INV_Jewelry_Necklace_30',
        [133321] = 'Interface/Icons/INV_Jewelry_Necklace_30Naxxramas',
        [133322] = 'Interface/Icons/INV_Jewelry_Necklace_31',
        [133323] = 'Interface/Icons/INV_Jewelry_Necklace_32',
        [133324] = 'Interface/Icons/INV_Jewelry_Necklace_33',
        [133325] = 'Interface/Icons/INV_Jewelry_Necklace_34',
        [133326] = 'Interface/Icons/INV_Jewelry_Necklace_35',
        [133327] = 'Interface/Icons/INV_Jewelry_Necklace_36',
        [133328] = 'Interface/Icons/INV_Jewelry_Necklace_37',
        [133329] = 'Interface/Icons/INV_Jewelry_Necklace_38',
        [133330] = 'Interface/Icons/INV_Jewelry_Necklace_39',
        [133331] = 'Interface/Icons/INV_Jewelry_Necklace_40',
        [133332] = 'Interface/Icons/INV_Jewelry_Necklace_41',
        [133333] = 'Interface/Icons/INV_Jewelry_Necklace_42',
        [133334] = 'Interface/Icons/INV_Jewelry_Necklace_43',
        [133335] = 'Interface/Icons/INV_Jewelry_Necklace_44',
        [133336] = 'Interface/Icons/INV_Jewelry_Necklace_45',
        [133337] = 'Interface/Icons/INV_Jewelry_Necklace_46',
        [133338] = 'Interface/Icons/INV_Jewelry_Necklace_47',
        [133339] = 'Interface/Icons/INV_Jewelry_Necklace_AhnQiraj_01',
        [133340] = 'Interface/Icons/INV_Jewelry_Necklace_AhnQiraj_02',
        [133341] = 'Interface/Icons/INV_Jewelry_Necklace_AhnQiraj_03',
        [133342] = 'Interface/Icons/INV_Jewelry_Necklace_AhnQiraj_04',
        [133343] = 'Interface/Icons/INV_Jewelry_Ring_01',
        [133344] = 'Interface/Icons/INV_Jewelry_Ring_02',
        [133345] = 'Interface/Icons/INV_Jewelry_Ring_03',
        [133346] = 'Interface/Icons/INV_Jewelry_Ring_04',
        [133347] = 'Interface/Icons/INV_Jewelry_Ring_05',
        [133348] = 'Interface/Icons/INV_Jewelry_Ring_06',
        [133349] = 'Interface/Icons/INV_Jewelry_Ring_07',
        [133350] = 'Interface/Icons/INV_Jewelry_Ring_08',
        [133351] = 'Interface/Icons/INV_Jewelry_Ring_09',
        [133352] = 'Interface/Icons/INV_Jewelry_Ring_10',
        [133353] = 'Interface/Icons/INV_Jewelry_Ring_11',
        [133354] = 'Interface/Icons/INV_Jewelry_Ring_12',
        [133355] = 'Interface/Icons/INV_Jewelry_Ring_13',
        [133356] = 'Interface/Icons/INV_Jewelry_Ring_14',
        [133357] = 'Interface/Icons/INV_Jewelry_Ring_15',
        [133358] = 'Interface/Icons/INV_Jewelry_Ring_16',
        [133359] = 'Interface/Icons/INV_Jewelry_Ring_17',
        [133360] = 'Interface/Icons/INV_Jewelry_Ring_18',
        [133361] = 'Interface/Icons/INV_Jewelry_Ring_19',
        [133362] = 'Interface/Icons/INV_Jewelry_Ring_20',
        [133363] = 'Interface/Icons/INV_Jewelry_Ring_21',
        [133364] = 'Interface/Icons/INV_Jewelry_Ring_22',
        [133365] = 'Interface/Icons/INV_Jewelry_Ring_23',
        [133366] = 'Interface/Icons/INV_Jewelry_Ring_24',
        [133367] = 'Interface/Icons/INV_Jewelry_Ring_25',
        [133368] = 'Interface/Icons/INV_Jewelry_Ring_26',
        [133369] = 'Interface/Icons/INV_Jewelry_Ring_27',
        [133370] = 'Interface/Icons/INV_Jewelry_Ring_28',
        [133371] = 'Interface/Icons/INV_Jewelry_Ring_29',
        [133372] = 'Interface/Icons/INV_Jewelry_Ring_30',
        [133373] = 'Interface/Icons/INV_Jewelry_Ring_31',
        [133374] = 'Interface/Icons/INV_Jewelry_Ring_32',
        [133375] = 'Interface/Icons/INV_Jewelry_Ring_33',
        [133376] = 'Interface/Icons/INV_Jewelry_Ring_34',
        [133377] = 'Interface/Icons/INV_Jewelry_Ring_35',
        [133378] = 'Interface/Icons/INV_Jewelry_Ring_36',
        [133379] = 'Interface/Icons/INV_Jewelry_Ring_37',
        [133380] = 'Interface/Icons/INV_Jewelry_Ring_38',
        [133381] = 'Interface/Icons/INV_Jewelry_Ring_39',
        [133382] = 'Interface/Icons/INV_Jewelry_Ring_40',
        [133383] = 'Interface/Icons/INV_Jewelry_Ring_41',
        [133384] = 'Interface/Icons/INV_Jewelry_Ring_42',
        [133385] = 'Interface/Icons/INV_Jewelry_Ring_43',
        [133386] = 'Interface/Icons/INV_Jewelry_Ring_44',
        [133387] = 'Interface/Icons/INV_Jewelry_Ring_45',
        [133388] = 'Interface/Icons/INV_Jewelry_Ring_46',
        [133389] = 'Interface/Icons/INV_Jewelry_Ring_47',
        [133390] = 'Interface/Icons/INV_Jewelry_Ring_48Naxxramas',
        [133391] = 'Interface/Icons/INV_Jewelry_Ring_49Naxxramas',
        [133392] = 'Interface/Icons/INV_Jewelry_Ring_50Naxxramas',
        [133393] = 'Interface/Icons/INV_Jewelry_Ring_51Naxxramas',
        [133394] = 'Interface/Icons/INV_Jewelry_Ring_52Naxxramas',
        [133395] = 'Interface/Icons/INV_Jewelry_Ring_53Naxxramas',
        [133396] = 'Interface/Icons/INV_Jewelry_Ring_54',
        [133397] = 'Interface/Icons/INV_Jewelry_Ring_55',
        [133398] = 'Interface/Icons/INV_Jewelry_Ring_56',
        [133399] = 'Interface/Icons/INV_Jewelry_Ring_57',
        [133400] = 'Interface/Icons/INV_Jewelry_Ring_58',
        [133401] = 'Interface/Icons/INV_Jewelry_Ring_59',
        [133402] = 'Interface/Icons/INV_Jewelry_Ring_60',
        [133403] = 'Interface/Icons/INV_Jewelry_Ring_61',
        [133404] = 'Interface/Icons/INV_Jewelry_Ring_62',
        [133405] = 'Interface/Icons/INV_Jewelry_Ring_63',
        [133406] = 'Interface/Icons/INV_Jewelry_Ring_64',
        [133407] = 'Interface/Icons/INV_Jewelry_Ring_65',
        [133408] = 'Interface/Icons/INV_Jewelry_Ring_66',
        [133409] = 'Interface/Icons/INV_Jewelry_Ring_67',
        [133410] = 'Interface/Icons/INV_Jewelry_Ring_68',
        [133411] = 'Interface/Icons/INV_Jewelry_Ring_69',
        [133412] = 'Interface/Icons/INV_Jewelry_Ring_70',
        [133413] = 'Interface/Icons/INV_Jewelry_Ring_71',
        [133414] = 'Interface/Icons/INV_Jewelry_Ring_72',
        [133415] = 'Interface/Icons/INV_JEWELRY_RING_73',
        [133416] = 'Interface/Icons/INV_JEWELRY_RING_74',
        [133417] = 'Interface/Icons/INV_JEWELRY_RING_75',
        [133418] = 'Interface/Icons/INV_JEWELRY_RING_76',
        [133419] = 'Interface/Icons/INV_JEWELRY_RING_77',
        [133420] = 'Interface/Icons/INV_JEWELRY_RING_78',
        [133421] = 'Interface/Icons/INV_JEWELRY_RING_79',
        [133422] = 'Interface/Icons/INV_JEWELRY_RING_80',
        [133423] = 'Interface/Icons/INV_Jewelry_Ring_AhnQiraj_01',
        [133424] = 'Interface/Icons/INV_Jewelry_Ring_AhnQiraj_02',
        [133425] = 'Interface/Icons/INV_Jewelry_Ring_AhnQiraj_03',
        [133426] = 'Interface/Icons/INV_Jewelry_Ring_AhnQiraj_04',
        [133427] = 'Interface/Icons/INV_Jewelry_Ring_AhnQiraj_05',
        [133428] = 'Interface/Icons/INV_Jewelry_Ring_AhnQiraj_06',
        [133429] = 'Interface/Icons/INV_Jewelry_StormPikeTrinket_01',
        [133430] = 'Interface/Icons/INV_Jewelry_StormPikeTrinket_02',
        [133431] = 'Interface/Icons/INV_Jewelry_StormPikeTrinket_03',
        [133432] = 'Interface/Icons/INV_Jewelry_StormPikeTrinket_04',
        [133433] = 'Interface/Icons/INV_Jewelry_StormPikeTrinket_05',
        [133434] = 'Interface/Icons/INV_Jewelry_Talisman_01',
        [133435] = 'Interface/Icons/INV_Jewelry_Talisman_02',
        [133436] = 'Interface/Icons/INV_Jewelry_Talisman_03',
        [133437] = 'Interface/Icons/INV_Jewelry_Talisman_04',
        [133438] = 'Interface/Icons/INV_Jewelry_Talisman_05',
        [133439] = 'Interface/Icons/INV_Jewelry_Talisman_06',
        [133440] = 'Interface/Icons/INV_Jewelry_Talisman_07',
        [133441] = 'Interface/Icons/INV_Jewelry_Talisman_08',
        [133442] = 'Interface/Icons/INV_Jewelry_Talisman_09',
        [133443] = 'Interface/Icons/INV_Jewelry_Talisman_10',
        [133444] = 'Interface/Icons/INV_Jewelry_Talisman_11',
        [133445] = 'Interface/Icons/INV_Jewelry_Talisman_12',
        [133446] = 'Interface/Icons/INV_Jewelry_Talisman_13',
        [133447] = 'Interface/Icons/INV_Jewelry_Talisman_14',
        [133448] = 'Interface/Icons/INV_Jewelry_Talisman_15',
        [133449] = 'Interface/Icons/INV_Jewelry_Talisman_16',
        [133450] = 'Interface/Icons/INV_Jewelry_Talisman_17',
        [133451] = 'Interface/Icons/INV_Jewelry_Talisman_18',
        [133452] = 'Interface/Icons/INV_Jewelry_TrinketPVP_01',
        [133453] = 'Interface/Icons/INV_Jewelry_TrinketPVP_02'
    },
    Letter = {
        [133457] = 'Interface/Icons/INV_Letter_01',
        [133458] = 'Interface/Icons/INV_Letter_02',
        [133459] = 'Interface/Icons/INV_Letter_03',
        [133460] = 'Interface/Icons/INV_Letter_04',
        [133461] = 'Interface/Icons/INV_Letter_05',
        [133462] = 'Interface/Icons/INV_Letter_06',
        [133463] = 'Interface/Icons/INV_Letter_07',
        [133464] = 'Interface/Icons/INV_Letter_08',
        [133465] = 'Interface/Icons/INV_Letter_09',
        [133466] = 'Interface/Icons/INV_Letter_10',
        [133467] = 'Interface/Icons/INV_Letter_11',
        [133468] = 'Interface/Icons/INV_Letter_12',
        [133469] = 'Interface/Icons/INV_Letter_13',
        [133470] = 'Interface/Icons/INV_Letter_14',
        [133471] = 'Interface/Icons/INV_Letter_15',
        [133472] = 'Interface/Icons/INV_Letter_16',
        [133473] = 'Interface/Icons/INV_Letter_17'
    },
    Mace = {
        [133474] = 'Interface/Icons/INV_Mace22',
        [133476] = 'Interface/Icons/INV_Mace_01',
        [133477] = 'Interface/Icons/INV_Mace_02',
        [133478] = 'Interface/Icons/INV_Mace_03',
        [133479] = 'Interface/Icons/INV_Mace_04',
        [133480] = 'Interface/Icons/INV_Mace_05',
        [133481] = 'Interface/Icons/INV_Mace_06',
        [133482] = 'Interface/Icons/INV_Mace_07',
        [133483] = 'Interface/Icons/INV_Mace_08',
        [133484] = 'Interface/Icons/INV_Mace_09',
        [133485] = 'Interface/Icons/INV_Mace_10',
        [133486] = 'Interface/Icons/INV_Mace_11',
        [133487] = 'Interface/Icons/INV_Mace_12',
        [133488] = 'Interface/Icons/INV_Mace_13',
        [133489] = 'Interface/Icons/INV_Mace_14',
        [133490] = 'Interface/Icons/INV_Mace_15',
        [133491] = 'Interface/Icons/INV_Mace_16',
        [133492] = 'Interface/Icons/INV_Mace_17',
        [133493] = 'Interface/Icons/INV_MACE_18',
        [133494] = 'Interface/Icons/INV_Mace_19',
        [133497] = 'Interface/Icons/INV_Mace_20',
        [133498] = 'Interface/Icons/INV_Mace_21',
        [133500] = 'Interface/Icons/INV_Mace_23',
        [133501] = 'Interface/Icons/INV_Mace_24',
        [133502] = 'Interface/Icons/INV_Mace_25',
        [133503] = 'Interface/Icons/INV_Mace_26',
        [133504] = 'Interface/Icons/INV_Mace_27',
        [133505] = 'Interface/Icons/INV_Mace_28',
        [133506] = 'Interface/Icons/INV_Mace_29',
        [133510] = 'Interface/Icons/INV_Mace_30',
        [133511] = 'Interface/Icons/INV_Mace_31',
        [133512] = 'Interface/Icons/INV_Mace_32',
        [133513] = 'Interface/Icons/INV_Mace_33',
        [133514] = 'Interface/Icons/INV_Mace_34',
        [133515] = 'Interface/Icons/INV_Mace_35',
        [133516] = 'Interface/Icons/INV_Mace_36',
        [133517] = 'Interface/Icons/INV_Mace_37',
        [133518] = 'Interface/Icons/INV_Mace_38',
        [133519] = 'Interface/Icons/INV_Mace_39',
        [133520] = 'Interface/Icons/INV_Mace_40',
        [133521] = 'Interface/Icons/INV_Mace_41',
        [133522] = 'Interface/Icons/INV_MACE_42',
        [133523] = 'Interface/Icons/INV_Mace_43',
        [133524] = 'Interface/Icons/INV_Mace_44',
        [133525] = 'Interface/Icons/INV_Mace_45',
        [133526] = 'Interface/Icons/INV_Mace_46',
        [133527] = 'Interface/Icons/INV_Mace_47',
        [133528] = 'Interface/Icons/INV_Mace_48',
        [133529] = 'Interface/Icons/INV_Mace_49',
        [133530] = 'Interface/Icons/INV_Mace_50',
        [133531] = 'Interface/Icons/INV_Mace_51',
        [133532] = 'Interface/Icons/INV_Mace_52',
        [133533] = 'Interface/Icons/INV_Mace_53',
        [133534] = 'Interface/Icons/INV_Mace_54',
        [133535] = 'Interface/Icons/INV_Mace_55',
        [133536] = 'Interface/Icons/INV_Mace_56',
        [133537] = 'Interface/Icons/INV_Mace_57',
        [133546] = 'Interface/Icons/INV_MACE_66',
        [133551] = 'Interface/Icons/INV_Mace_71',
        [133552] = 'Interface/Icons/INV_Mace_72',
        [133553] = 'Interface/Icons/INV_Mace_73',
        [133554] = 'Interface/Icons/INV_Mace_74',
        [133562] = 'Interface/Icons/INV_Mace_82'
    },
    Mask = {
        [133067] = 'Interface/Icons/Inv_Helm_Mask_ZulGurub_D_01',
        [133564] = 'Interface/Icons/INV_Mask_01',
        [133565] = 'Interface/Icons/INV_Mask_02',
        [133566] = 'Interface/Icons/INV_Mask_03',
        [133567] = 'Interface/Icons/INV_Mask_04',
        [133568] = 'Interface/Icons/INV_Mask_05',
        [133569] = 'Interface/Icons/INV_Mask_06'
    },
    ['Misc - Trinkets/Apexis'] = {
        [133570] = 'Interface/Icons/INV_Misc_AhnQirajTrinket_01',
        [133571] = 'Interface/Icons/INV_Misc_AhnQirajTrinket_02',
        [133572] = 'Interface/Icons/INV_Misc_AhnQirajTrinket_03',
        [133573] = 'Interface/Icons/INV_Misc_AhnQirajTrinket_04',
        [133574] = 'Interface/Icons/INV_Misc_AhnQirajTrinket_05',
        [133575] = 'Interface/Icons/INV_Misc_AhnQirajTrinket_06',
        [133594] = 'Interface/Icons/INV_Misc_Apexis_Crystal',
        [133595] = 'Interface/Icons/INV_Misc_Apexis_Shard',
    },
    ['Misc - Bag'] = {
        [133622] = 'Interface/Icons/INV_Misc_Bag_01',
        [133623] = 'Interface/Icons/INV_Misc_Bag_02',
        [133624] = 'Interface/Icons/INV_Misc_Bag_03',
        [133625] = 'Interface/Icons/INV_Misc_Bag_04',
        [133626] = 'Interface/Icons/INV_Misc_Bag_05',
        [133627] = 'Interface/Icons/INV_Misc_Bag_06',
        [133628] = 'Interface/Icons/INV_Misc_Bag_07',
        [133629] = 'Interface/Icons/INV_Misc_Bag_07_Black',
        [133630] = 'Interface/Icons/INV_Misc_Bag_07_Blue',
        [133631] = 'Interface/Icons/INV_Misc_Bag_07_Green',
        [133632] = 'Interface/Icons/INV_Misc_Bag_07_Red',
        [133633] = 'Interface/Icons/INV_Misc_Bag_08',
        [133634] = 'Interface/Icons/INV_MISC_BAG_09',
        [133635] = 'Interface/Icons/INV_Misc_Bag_09_Black',
        [133636] = 'Interface/Icons/INV_Misc_Bag_09_Blue',
        [133637] = 'Interface/Icons/INV_Misc_Bag_09_Green',
        [133638] = 'Interface/Icons/INV_Misc_Bag_09_Red',
        [133639] = 'Interface/Icons/INV_Misc_Bag_10',
        [133640] = 'Interface/Icons/INV_Misc_Bag_10_Black',
        [133641] = 'Interface/Icons/INV_MISC_BAG_10_BLUE',
        [133642] = 'Interface/Icons/INV_Misc_Bag_10_Green',
        [133643] = 'Interface/Icons/INV_Misc_Bag_10_Red',
        [133644] = 'Interface/Icons/INV_Misc_Bag_11',
        [133645] = 'Interface/Icons/INV_Misc_Bag_12',
        [133646] = 'Interface/Icons/INV_Misc_Bag_13',
        [133647] = 'Interface/Icons/INV_Misc_Bag_14',
        [133648] = 'Interface/Icons/INV_Misc_Bag_15',
        [133649] = 'Interface/Icons/INV_Misc_Bag_16',
        [133650] = 'Interface/Icons/INV_Misc_Bag_17',
        [133651] = 'Interface/Icons/INV_Misc_Bag_18',
        [133652] = 'Interface/Icons/INV_Misc_Bag_19',
        [133653] = 'Interface/Icons/INV_Misc_Bag_20',
        [133654] = 'Interface/Icons/INV_Misc_Bag_21',
        [133655] = 'Interface/Icons/INV_Misc_Bag_22',
        [133656] = 'Interface/Icons/INV_Misc_Bag_23_Netherweave',
        [133657] = 'Interface/Icons/INV_Misc_Bag_24_Netherweave_Imbued',
        [133658] = 'Interface/Icons/INV_Misc_Bag_25_Mooncloth',
        [133659] = 'Interface/Icons/INV_Misc_Bag_26_Spellfire',
        [133660] = 'Interface/Icons/INV_Misc_Bag_27',
        [133661] = 'Interface/Icons/INV_Misc_Bag_28_Halloween',
        [133662] = 'Interface/Icons/INV_Misc_Bag_BigBagofEnchantments',
        [133663] = 'Interface/Icons/INV_Misc_Bag_CenarionHerbBag',
        [133664] = 'Interface/Icons/INV_Misc_Bag_CoreFelclothBag',
        [133667] = 'Interface/Icons/INV_Misc_Bag_FelclothBag',
        [133668] = 'Interface/Icons/INV_Misc_Bag_HerbPouch',
        [133669] = 'Interface/Icons/INV_Misc_Bag_SatchelofCenarius',
        [133670] = 'Interface/Icons/INV_Misc_Bag_Soulbag',
    },
    ['Misc - Bandana/Basket/Birdbeck'] = {
        [133693] = 'Interface/Icons/INV_Misc_Bandana_01',
        [133694] = 'Interface/Icons/INV_Misc_Bandana_03',
        [133695] = 'Interface/Icons/INV_Misc_Basket_01',
        [133706] = 'Interface/Icons/INV_Misc_Bell_01',
        [133707] = 'Interface/Icons/INV_Misc_Birdbeck_01',
        [133708] = 'Interface/Icons/INV_Misc_Birdbeck_02',
    },
    ['Misc - Bandage/Beer/Bomb'] = {
        [133671] = 'Interface/Icons/INV_Misc_Bandage_01',
        [133672] = 'Interface/Icons/INV_Misc_Bandage_02',
        [133673] = 'Interface/Icons/INV_Misc_Bandage_03',
        [133674] = 'Interface/Icons/INV_Misc_Bandage_04',
        [133675] = 'Interface/Icons/INV_Misc_Bandage_05',
        [133676] = 'Interface/Icons/INV_Misc_Bandage_06',
        [133677] = 'Interface/Icons/INV_Misc_Bandage_07',
        [133678] = 'Interface/Icons/INV_Misc_Bandage_08',
        [133679] = 'Interface/Icons/INV_Misc_Bandage_09',
        [133680] = 'Interface/Icons/INV_Misc_Bandage_10',
        [133681] = 'Interface/Icons/INV_Misc_Bandage_11',
        [133682] = 'Interface/Icons/INV_Misc_Bandage_12',
        [133683] = 'Interface/Icons/INV_Misc_Bandage_13',
        [133684] = 'Interface/Icons/INV_Misc_Bandage_14',
        [133685] = 'Interface/Icons/INV_Misc_Bandage_15',
        [133686] = 'Interface/Icons/INV_Misc_Bandage_16',
        [133687] = 'Interface/Icons/INV_Misc_Bandage_17',
        [133688] = 'Interface/Icons/INV_Misc_Bandage_18',
        [133689] = 'Interface/Icons/INV_Misc_Bandage_19',
        [133690] = 'Interface/Icons/INV_Misc_Bandage_20',
        [133691] = 'Interface/Icons/INV_Misc_Bandage_Netherweave',
        [133692] = 'Interface/Icons/INV_Misc_Bandage_Netherweave_Heavy',
        [133696] = 'Interface/Icons/INV_Misc_Beer_01',
        [133697] = 'Interface/Icons/INV_MISC_BEER_02',
        [133698] = 'Interface/Icons/INV_Misc_Beer_03',
        [133699] = 'Interface/Icons/INV_Misc_Beer_04',
        [133700] = 'Interface/Icons/INV_Misc_Beer_05',
        [133701] = 'Interface/Icons/INV_Misc_Beer_06',
        [133702] = 'Interface/Icons/INV_Misc_Beer_07',
        [133703] = 'Interface/Icons/INV_Misc_Beer_08',
        [133704] = 'Interface/Icons/INV_Misc_Beer_09',
        [133705] = 'Interface/Icons/INV_Misc_Beer_10',
        [133709] = 'Interface/Icons/INV_Misc_Bomb_01',
        [133710] = 'Interface/Icons/INV_Misc_Bomb_02',
        [133711] = 'Interface/Icons/INV_Misc_Bomb_03',
        [133712] = 'Interface/Icons/INV_Misc_Bomb_04',
        [133713] = 'Interface/Icons/INV_Misc_Bomb_05',
        [133714] = 'Interface/Icons/INV_Misc_Bomb_06',
        [133715] = 'Interface/Icons/INV_Misc_Bomb_07',
        [133716] = 'Interface/Icons/INV_Misc_Bomb_08',
        [133717] = 'Interface/Icons/INV_Misc_Bomb_09',
    },
    ['Misc - Bone/Book/Branch'] = {
        [133718] = 'Interface/Icons/INV_Misc_Bone_01',
        [133719] = 'Interface/Icons/INV_Misc_Bone_02',
        [133720] = 'Interface/Icons/INV_Misc_Bone_03',
        [133721] = 'Interface/Icons/INV_Misc_Bone_04',
        [133722] = 'Interface/Icons/INV_Misc_Bone_05',
        [133723] = 'Interface/Icons/INV_Misc_Bone_06',
        [133724] = 'Interface/Icons/INV_Misc_Bone_07',
        [133725] = 'Interface/Icons/INV_Misc_Bone_08',
        [133726] = 'Interface/Icons/INV_Misc_Bone_09',
        [133727] = 'Interface/Icons/INV_Misc_Bone_10',
        [133728] = 'Interface/Icons/INV_Misc_Bone_DwarfSkull_01',
        [133729] = 'Interface/Icons/INV_Misc_Bone_ElfSkull_01',
        [133730] = 'Interface/Icons/INV_Misc_Bone_HumanSkull_01',
        [133731] = 'Interface/Icons/INV_Misc_Bone_OrcSkull_01',
        [133732] = 'Interface/Icons/INV_Misc_Bone_TaurenSkull_01',
        [133733] = 'Interface/Icons/INV_Misc_Book_01',
        [133734] = 'Interface/Icons/INV_Misc_Book_02',
        [133735] = 'Interface/Icons/INV_Misc_Book_03',
        [133736] = 'Interface/Icons/INV_Misc_Book_04',
        [133737] = 'Interface/Icons/INV_Misc_Book_05',
        [133738] = 'Interface/Icons/INV_Misc_Book_06',
        [133739] = 'Interface/Icons/INV_Misc_Book_07',
        [133740] = 'Interface/Icons/INV_Misc_Book_08',
        [133741] = 'Interface/Icons/INV_Misc_Book_09',
        [133742] = 'Interface/Icons/INV_Misc_Book_10',
        [133743] = 'Interface/Icons/INV_Misc_Book_11',
        [133744] = 'Interface/Icons/INV_Misc_Book_12',
        [133745] = 'Interface/Icons/INV_Misc_Book_13',
        [133746] = 'Interface/Icons/INV_Misc_Book_14',
        [133747] = 'Interface/Icons/INV_Misc_Book_15',
        [133749] = 'Interface/Icons/INV_Misc_Branch_01',
    },
    ['Misc - Candle-Cape'] = {
        [133750] = 'Interface/Icons/INV_Misc_Candle_01',
        [133751] = 'Interface/Icons/INV_Misc_Candle_02',
        [133752] = 'Interface/Icons/INV_Misc_Candle_03',
        [133753] = 'Interface/Icons/INV_Misc_Cape_01',
        [133754] = 'Interface/Icons/INV_Misc_Cape_02',
        [133755] = 'Interface/Icons/INV_Misc_Cape_03',
        [133756] = 'Interface/Icons/INV_Misc_Cape_04',
        [133757] = 'Interface/Icons/INV_Misc_Cape_05',
        [133758] = 'Interface/Icons/INV_Misc_Cape_06',
        [133759] = 'Interface/Icons/INV_Misc_Cape_07',
        [133760] = 'Interface/Icons/INV_Misc_Cape_08',
        [133761] = 'Interface/Icons/INV_Misc_Cape_09',
        [133762] = 'Interface/Icons/INV_Misc_Cape_10',
        [133763] = 'Interface/Icons/INV_Misc_Cape_11',
        [133764] = 'Interface/Icons/INV_Misc_Cape_12',
        [133765] = 'Interface/Icons/INV_Misc_Cape_13',
        [133766] = 'Interface/Icons/INV_Misc_Cape_14',
        [133767] = 'Interface/Icons/INV_Misc_Cape_15',
        [133768] = 'Interface/Icons/INV_Misc_Cape_16',
        [133769] = 'Interface/Icons/INV_Misc_Cape_17',
        [133770] = 'Interface/Icons/INV_Misc_Cape_18',
        [133771] = 'Interface/Icons/INV_Misc_Cape_19',
        [133772] = 'Interface/Icons/INV_Misc_Cape_20',
        [133773] = 'Interface/Icons/INV_Misc_Cape_21',
        [133774] = 'Interface/Icons/INV_Misc_Cape_22',
        [133775] = 'Interface/Icons/INV_Misc_Cape_Naxxramas_01',
        [133776] = 'Interface/Icons/INV_Misc_Cape_Naxxramas_02',
        [133777] = 'Interface/Icons/INV_Misc_Cape_Naxxramas_03',
    },
    ['Misc - Cauldron-Coin'] = {
        [133778] = 'Interface/Icons/INV_Misc_Cauldron_Arcane',
        [133779] = 'Interface/Icons/INV_Misc_Cauldron_Fire',
        [133780] = 'Interface/Icons/INV_Misc_Cauldron_Frost',
        [133781] = 'Interface/Icons/INV_Misc_Cauldron_Nature',
        [133782] = 'Interface/Icons/INV_Misc_Cauldron_Shadow',
        [133783] = 'Interface/Icons/INV_Misc_CelebrationCake_01',
        [133784] = 'Interface/Icons/INV_Misc_Coin_01',
        [133785] = 'Interface/Icons/INV_Misc_Coin_02',
        [133786] = 'Interface/Icons/INV_Misc_Coin_03',
        [133787] = 'Interface/Icons/INV_Misc_Coin_04',
        [133788] = 'Interface/Icons/INV_Misc_Coin_05',
        [133789] = 'Interface/Icons/INV_Misc_Coin_06',
        [133790] = 'Interface/Icons/INV_Misc_Coin_07',
        [133791] = 'Interface/Icons/INV_Misc_Coin_08',
        [133792] = 'Interface/Icons/INV_Misc_Coin_09',
        [133793] = 'Interface/Icons/INV_Misc_Coin_10',
        [133794] = 'Interface/Icons/INV_Misc_Coin_11',
        [133795] = 'Interface/Icons/INV_Misc_Coin_12',
        [133796] = 'Interface/Icons/INV_Misc_Coin_13',
        [133797] = 'Interface/Icons/INV_Misc_Coin_14',
        [133798] = 'Interface/Icons/INV_Misc_Coin_15',
    },
    ['Misc - Comb-DragonKite'] = {
        [133800] = 'Interface/Icons/INV_Misc_Comb_01',
        [133801] = 'Interface/Icons/INV_Misc_Comb_02',
        [133802] = 'Interface/Icons/INV_Misc_Crop_01',
        [133803] = 'Interface/Icons/INV_Misc_Crop_02',
        [133804] = 'Interface/Icons/INV_Misc_Desecrated_ClothBelt',
        [133805] = 'Interface/Icons/INV_Misc_Desecrated_ClothBoots',
        [133806] = 'Interface/Icons/INV_Misc_Desecrated_ClothBracer',
        [133807] = 'Interface/Icons/INV_Misc_Desecrated_ClothChest',
        [133808] = 'Interface/Icons/INV_Misc_Desecrated_ClothGlove',
        [133809] = 'Interface/Icons/INV_Misc_Desecrated_ClothHelm',
        [133810] = 'Interface/Icons/INV_Misc_Desecrated_ClothPants',
        [133811] = 'Interface/Icons/INV_Misc_Desecrated_ClothShoulder',
        [133812] = 'Interface/Icons/INV_Misc_Desecrated_LeatherBelt',
        [133813] = 'Interface/Icons/INV_Misc_Desecrated_LeatherBoots',
        [133814] = 'Interface/Icons/INV_Misc_Desecrated_LeatherBracer',
        [133815] = 'Interface/Icons/INV_Misc_Desecrated_LeatherChest',
        [133816] = 'Interface/Icons/INV_MISC_DESECRATED_LEATHERGLOVE',
        [133817] = 'Interface/Icons/INV_Misc_Desecrated_LeatherHelm',
        [133818] = 'Interface/Icons/INV_Misc_Desecrated_LeatherPants',
        [133819] = 'Interface/Icons/INV_Misc_Desecrated_LeatherShoulder',
        [133820] = 'Interface/Icons/INV_Misc_Desecrated_MailBelt',
        [133821] = 'Interface/Icons/INV_Misc_Desecrated_MailBoots',
        [133822] = 'Interface/Icons/INV_Misc_Desecrated_MailBracer',
        [133823] = 'Interface/Icons/INV_Misc_Desecrated_MailChest',
        [133824] = 'Interface/Icons/INV_Misc_Desecrated_MailGlove',
        [133825] = 'Interface/Icons/INV_Misc_Desecrated_MailHelm',
        [133826] = 'Interface/Icons/INV_Misc_Desecrated_MailPants',
        [133827] = 'Interface/Icons/INV_Misc_Desecrated_MailShoulder',
        [133828] = 'Interface/Icons/INV_Misc_Desecrated_PlateBelt',
        [133829] = 'Interface/Icons/INV_Misc_Desecrated_PlateBoots',
        [133830] = 'Interface/Icons/INV_Misc_Desecrated_PlateBracer',
        [133831] = 'Interface/Icons/INV_Misc_Desecrated_PlateChest',
        [133832] = 'Interface/Icons/INV_Misc_Desecrated_PlateGloves',
        [133833] = 'Interface/Icons/INV_Misc_Desecrated_PlateHelm',
        [133834] = 'Interface/Icons/INV_Misc_Desecrated_PlatePants',
        [133835] = 'Interface/Icons/INV_Misc_Desecrated_PlateShoulder',
        [133836] = 'Interface/Icons/INV_Misc_DiscoBall_01',
        [133837] = 'Interface/Icons/INV_Misc_DragonKite_01',
        [133838] = 'Interface/Icons/INV_Misc_DragonKite_02',
        [133839] = 'Interface/Icons/INV_Misc_DragonKite_03',
        [133840] = 'Interface/Icons/INV_Misc_DragonKite_04',
    },
    ['Misc - Drum-Fish'] = {
        [133841] = 'Interface/Icons/INV_Misc_Drum_01',
        [133842] = 'Interface/Icons/INV_Misc_Drum_02',
        [133843] = 'Interface/Icons/INV_Misc_Drum_03',
        [133844] = 'Interface/Icons/INV_Misc_Drum_04',
        [133845] = 'Interface/Icons/INV_Misc_Drum_05',
        [133846] = 'Interface/Icons/INV_Misc_Drum_06',
        [133847] = 'Interface/Icons/INV_Misc_Drum_07',
        [133848] = 'Interface/Icons/INV_Misc_Dust_01',
        [133849] = 'Interface/Icons/INV_Misc_Dust_02',
        [133850] = 'Interface/Icons/INV_MISC_DUST_03',
        [133851] = 'Interface/Icons/INV_MISC_DUST_04',
        [133852] = 'Interface/Icons/INV_MISC_DUST_05',
        [133853] = 'Interface/Icons/INV_MISC_DUST_06',
        [133854] = 'Interface/Icons/INV_Misc_Ear_Human_01',
        [133855] = 'Interface/Icons/INV_Misc_Ear_Human_02',
        [133856] = 'Interface/Icons/INV_Misc_Ear_NightElf_01',
        [133857] = 'Interface/Icons/INV_Misc_Ear_NightElf_02',
        [133858] = 'Interface/Icons/INV_Misc_ElvenCoins',
        [133859] = 'Interface/Icons/INV_Misc_EngGizmos_01',
        [133860] = 'Interface/Icons/INV_Misc_EngGizmos_02',
        [133861] = 'Interface/Icons/INV_Misc_EngGizmos_03',
        [133862] = 'Interface/Icons/INV_Misc_EngGizmos_04',
        [133863] = 'Interface/Icons/INV_Misc_EngGizmos_05',
        [133864] = 'Interface/Icons/INV_Misc_EngGizmos_06',
        [133865] = 'Interface/Icons/INV_Misc_EngGizmos_07',
        [133866] = 'Interface/Icons/INV_Misc_EngGizmos_08',
        [133867] = 'Interface/Icons/INV_Misc_EngGizmos_09',
        [133868] = 'Interface/Icons/INV_Misc_EngGizmos_10',
        [133869] = 'Interface/Icons/INV_Misc_EngGizmos_11',
        [133870] = 'Interface/Icons/INV_Misc_EngGizmos_12',
        [133871] = 'Interface/Icons/INV_Misc_EngGizmos_13',
        [133872] = 'Interface/Icons/INV_Misc_EngGizmos_14',
        [133873] = 'Interface/Icons/INV_Misc_EngGizmos_15',
        [133874] = 'Interface/Icons/INV_Misc_EngGizmos_16',
        [133875] = 'Interface/Icons/INV_Misc_EngGizmos_17',
        [133876] = 'Interface/Icons/INV_Misc_EngGizmos_18',
        [133877] = 'Interface/Icons/INV_Misc_EngGizmos_19',
        [133878] = 'Interface/Icons/INV_Misc_EngGizmos_20',
        [133879] = 'Interface/Icons/INV_Misc_EngGizmos_21',
        [133880] = 'Interface/Icons/INV_Misc_EngGizmos_23',
        [133881] = 'Interface/Icons/INV_Misc_EngGizmos_24',
        [133882] = 'Interface/Icons/INV_Misc_EngGizmos_EssenceDistiller',
        [133883] = 'Interface/Icons/INV_Misc_EngGizmos_RocketChicken',
        [133884] = 'Interface/Icons/INV_Misc_Eye_01',
        [133885] = 'Interface/Icons/INV_MISC_FILM_01',
        [133886] = 'Interface/Icons/INV_Misc_FireDancer_01',
        [133887] = 'Interface/Icons/INV_Misc_Fish_01',
        [133888] = 'Interface/Icons/INV_Misc_Fish_02',
        [133889] = 'Interface/Icons/INV_Misc_Fish_03',
        [133890] = 'Interface/Icons/INV_Misc_Fish_04',
        [133891] = 'Interface/Icons/INV_Misc_Fish_05',
        [133892] = 'Interface/Icons/INV_Misc_Fish_06',
        [133893] = 'Interface/Icons/INV_Misc_Fish_07',
        [133894] = 'Interface/Icons/INV_Misc_Fish_08',
        [133895] = 'Interface/Icons/INV_Misc_Fish_09',
        [133896] = 'Interface/Icons/INV_Misc_Fish_10',
        [133897] = 'Interface/Icons/INV_Misc_Fish_11',
        [133898] = 'Interface/Icons/INV_Misc_Fish_12',
        [133899] = 'Interface/Icons/INV_Misc_Fish_13',
        [133900] = 'Interface/Icons/INV_Misc_Fish_14',
        [133901] = 'Interface/Icons/INV_Misc_Fish_15',
        [133902] = 'Interface/Icons/INV_Misc_Fish_16',
        [133903] = 'Interface/Icons/INV_Misc_Fish_17',
        [133904] = 'Interface/Icons/INV_Misc_Fish_18',
        [133905] = 'Interface/Icons/INV_Misc_Fish_19',
        [133906] = 'Interface/Icons/INV_Misc_Fish_20',
        [133907] = 'Interface/Icons/INV_Misc_Fish_21',
        [133908] = 'Interface/Icons/INV_Misc_Fish_22',
        [133909] = 'Interface/Icons/INV_Misc_Fish_23',
        [133910] = 'Interface/Icons/INV_Misc_Fish_24',
        [133911] = 'Interface/Icons/INV_Misc_Fish_25',
        [133912] = 'Interface/Icons/INV_Misc_Fish_26',
        [133913] = 'Interface/Icons/INV_Misc_Fish_27',
        [133914] = 'Interface/Icons/INV_Misc_Fish_28',
        [133915] = 'Interface/Icons/INV_Misc_Fish_29',
        [133916] = 'Interface/Icons/INV_Misc_Fish_30',
        [133917] = 'Interface/Icons/INV_Misc_Fish_31',
        [133918] = 'Interface/Icons/INV_Misc_Fish_32',
        [133919] = 'Interface/Icons/INV_Misc_Fish_33',
        [133920] = 'Interface/Icons/INV_Misc_Fish_34',
        [133921] = 'Interface/Icons/INV_Misc_Fish_35',
        [133922] = 'Interface/Icons/INV_Misc_Fish_36',
        [133923] = 'Interface/Icons/INV_Misc_Fish_37',
        [133924] = 'Interface/Icons/INV_Misc_Fish_38',
        [133925] = 'Interface/Icons/INV_Misc_Fish_39',
        [133926] = 'Interface/Icons/INV_Misc_Fish_40',
        [133927] = 'Interface/Icons/INV_Misc_Fish_41',
        [133928] = 'Interface/Icons/INV_Misc_Fish_42',
        [133929] = 'Interface/Icons/INV_Misc_Fish_43',
        [133930] = 'Interface/Icons/INV_Misc_Fish_44',
        [133931] = 'Interface/Icons/INV_Misc_Fish_45',
        [133935] = 'Interface/Icons/INV_Misc_Fish_Turtle_01',
        [133936] = 'Interface/Icons/INV_Misc_Fish_Turtle_02',
        [133937] = 'Interface/Icons/INV_Misc_Fish_Turtle_03',
    },
    ['Misc - Flower-Gem'] = {
        [133938] = 'Interface/Icons/INV_Misc_Flower_01',
        [133939] = 'Interface/Icons/INV_Misc_Flower_02',
        [133940] = 'Interface/Icons/INV_Misc_Flower_03',
        [133941] = 'Interface/Icons/INV_Misc_Flower_04',
        [133942] = 'Interface/Icons/INV_Misc_Flute_01',
        [134060] = 'Interface/Icons/INV_Misc_Foot_Centaur',
        [134061] = 'Interface/Icons/INV_Misc_Foot_Kodo',
        [134062] = 'Interface/Icons/INV_Misc_Fork&Knife',
        [134063] = 'Interface/Icons/INV_Misc_Gear_01',
        [134064] = 'Interface/Icons/INV_Misc_Gear_02',
        [134065] = 'Interface/Icons/INV_Misc_Gear_03',
        [134066] = 'Interface/Icons/INV_Misc_Gear_04',
        [134067] = 'Interface/Icons/INV_Misc_Gear_05',
        [134068] = 'Interface/Icons/INV_Misc_Gear_06',
        [134069] = 'Interface/Icons/INV_Misc_Gear_07',
        [134070] = 'Interface/Icons/INV_Misc_Gear_08',
        [134071] = 'Interface/Icons/INV_Misc_Gem_01',
        [134072] = 'Interface/Icons/INV_Misc_Gem_02',
        [134073] = 'Interface/Icons/INV_Misc_Gem_03',
        [134074] = 'Interface/Icons/INV_Misc_Gem_Amethyst_01',
        [134075] = 'Interface/Icons/INV_Misc_Gem_Amethyst_02',
        [134076] = 'Interface/Icons/INV_MISC_GEM_AMETHYST_03',
        [134077] = 'Interface/Icons/INV_Misc_Gem_AmethystRough_01',
        [134078] = 'Interface/Icons/INV_Misc_Gem_AzureDraenite_01',
        [134079] = 'Interface/Icons/INV_Misc_Gem_AzureDraenite_02',
        [134080] = 'Interface/Icons/INV_Misc_Gem_AzureDraenite_03',
        [134081] = 'Interface/Icons/INV_Misc_Gem_BloodGem_01',
        [134082] = 'Interface/Icons/INV_Misc_Gem_BloodGem_02',
        [134083] = 'Interface/Icons/INV_Misc_Gem_BloodGem_03',
        [134084] = 'Interface/Icons/INV_Misc_Gem_Bloodstone_01',
        [134085] = 'Interface/Icons/INV_MISC_GEM_BLOODSTONE_02',
        [134086] = 'Interface/Icons/INV_Misc_Gem_Bloodstone_03',
        [134087] = 'Interface/Icons/INV_Misc_Gem_Crystal_01',
        [134088] = 'Interface/Icons/INV_Misc_Gem_Crystal_02',
        [134089] = 'Interface/Icons/INV_Misc_Gem_Crystal_03',
        [134090] = 'Interface/Icons/INV_Misc_Gem_CrystalCut_01',
        [134091] = 'Interface/Icons/INV_Misc_Gem_DeepPeridot_01',
        [134092] = 'Interface/Icons/INV_Misc_Gem_DeepPeridot_02',
        [134093] = 'Interface/Icons/INV_Misc_Gem_DeepPeridot_03',
        [134094] = 'Interface/Icons/INV_Misc_Gem_Diamond_01',
        [134095] = 'Interface/Icons/INV_Misc_Gem_Diamond_02',
        [134096] = 'Interface/Icons/INV_Misc_Gem_Diamond_03',
        [134097] = 'Interface/Icons/INV_Misc_Gem_Diamond_04',
        [134098] = 'Interface/Icons/INV_Misc_Gem_Diamond_05',
        [134099] = 'Interface/Icons/INV_Misc_Gem_Diamond_06',
        [134100] = 'Interface/Icons/INV_Misc_Gem_Diamond_07',
        [134101] = 'Interface/Icons/INV_Misc_Gem_EbonDraenite_01',
        [134102] = 'Interface/Icons/INV_Misc_Gem_EbonDraenite_02',
        [134103] = 'Interface/Icons/INV_Misc_Gem_EbonDraenite_03',
        [134104] = 'Interface/Icons/INV_Misc_Gem_Emerald_01',
        [134105] = 'Interface/Icons/INV_Misc_Gem_Emerald_02',
        [134106] = 'Interface/Icons/INV_Misc_Gem_Emerald_03',
        [134107] = 'Interface/Icons/INV_Misc_Gem_EmeraldRough_01',
        [134108] = 'Interface/Icons/INV_Misc_Gem_EmeraldRough_02',
        [134109] = 'Interface/Icons/INV_Misc_Gem_FlameSpessarite_01',
        [134110] = 'Interface/Icons/INV_Misc_Gem_FlameSpessarite_02',
        [134111] = 'Interface/Icons/INV_Misc_Gem_FlameSpessarite_03',
        [134112] = 'Interface/Icons/INV_Misc_Gem_GoldenDraenite_01',
        [134113] = 'Interface/Icons/INV_Misc_Gem_GoldenDraenite_02',
        [134114] = 'Interface/Icons/INV_Misc_Gem_GoldenDraenite_03',
        [134115] = 'Interface/Icons/INV_Misc_Gem_LionsEye_01',
        [134116] = 'Interface/Icons/INV_Misc_Gem_Opal_01',
        [134117] = 'Interface/Icons/INV_Misc_Gem_Opal_02',
        [134118] = 'Interface/Icons/INV_Misc_Gem_Opal_03',
        [134119] = 'Interface/Icons/INV_Misc_Gem_OpalRough_01',
        [134120] = 'Interface/Icons/INV_Misc_Gem_Pearl_01',
        [134121] = 'Interface/Icons/INV_Misc_Gem_Pearl_02',
        [134122] = 'Interface/Icons/INV_Misc_Gem_Pearl_03',
        [134123] = 'Interface/Icons/INV_Misc_Gem_Pearl_04',
        [134124] = 'Interface/Icons/INV_Misc_Gem_Pearl_05',
        [134125] = 'Interface/Icons/INV_Misc_Gem_Pearl_06',
        [134126] = 'Interface/Icons/INV_Misc_Gem_Pearl_07',
        [134127] = 'Interface/Icons/INV_Misc_Gem_Pearl_08',
        [134128] = 'Interface/Icons/INV_Misc_Gem_Ruby_01',
        [134129] = 'Interface/Icons/INV_Misc_Gem_Ruby_02',
        [134130] = 'Interface/Icons/INV_Misc_Gem_Ruby_03',
        [134131] = 'Interface/Icons/INV_Misc_Gem_Sapphire_01',
        [134132] = 'Interface/Icons/INV_Misc_Gem_Sapphire_02',
        [134133] = 'Interface/Icons/INV_Misc_Gem_Sapphire_03',
        [134134] = 'Interface/Icons/INV_Misc_Gem_Stone_01',
        [134135] = 'Interface/Icons/INV_Misc_Gem_Topaz_01',
        [134136] = 'Interface/Icons/INV_Misc_Gem_Topaz_02',
        [134137] = 'Interface/Icons/INV_Misc_Gem_Topaz_03',
        [134138] = 'Interface/Icons/INV_Misc_Gem_Variety_01',
        [134139] = 'Interface/Icons/INV_Misc_Gem_Variety_02',
    },
    ['Misc - Gift-Herb'] = {
        [134140] = 'Interface/Icons/INV_Misc_Gift_01',
        [134141] = 'Interface/Icons/INV_Misc_Gift_02',
        [134142] = 'Interface/Icons/INV_Misc_Gift_03',
        [134143] = 'Interface/Icons/INV_Misc_Gift_04',
        [134144] = 'Interface/Icons/INV_Misc_Gift_05',
        [134145] = 'Interface/Icons/INV_Misc_GiftWrap_01',
        [134146] = 'Interface/Icons/INV_Misc_GiftWrap_02',
        [134147] = 'Interface/Icons/INV_Misc_GiftWrap_03',
        [134148] = 'Interface/Icons/INV_Misc_GroupLooking',
        [134149] = 'Interface/Icons/INV_Misc_GroupNeedMore',
        [134150] = 'Interface/Icons/INV_Misc_Head_02',
        [134151] = 'Interface/Icons/INV_Misc_Head_Centaur_01',
        [134153] = 'Interface/Icons/INV_Misc_Head_Dragon_01',
        [134154] = 'Interface/Icons/INV_Misc_Head_Dragon_Black',
        [134155] = 'Interface/Icons/INV_Misc_Head_Dragon_Blue',
        [134156] = 'Interface/Icons/INV_Misc_Head_Dragon_Bronze',
        [134157] = 'Interface/Icons/INV_Misc_Head_Dragon_Green',
        [134158] = 'Interface/Icons/INV_Misc_Head_Dragon_Red',
        [134159] = 'Interface/Icons/INV_Misc_Head_Dwarf_01',
        [134160] = 'Interface/Icons/INV_Misc_Head_Dwarf_02',
        [134161] = 'Interface/Icons/INV_Misc_Head_Elf_01',
        [134162] = 'Interface/Icons/INV_Misc_Head_Elf_02',
        [134163] = 'Interface/Icons/INV_Misc_Head_Gnoll_01',
        [134164] = 'Interface/Icons/INV_Misc_Head_Gnome_01',
        [134165] = 'Interface/Icons/INV_Misc_Head_Gnome_02',
        [134166] = 'Interface/Icons/INV_Misc_Head_Human_01',
        [134167] = 'Interface/Icons/INV_Misc_Head_Human_02',
        [134168] = 'Interface/Icons/INV_Misc_Head_Kobold_01',
        [134169] = 'Interface/Icons/INV_Misc_Head_Murloc_01',
        [134170] = 'Interface/Icons/INV_Misc_Head_Orc_01',
        [134171] = 'Interface/Icons/INV_Misc_Head_Orc_02',
        [134172] = 'Interface/Icons/INV_Misc_Head_Quillboar_01',
        [134173] = 'Interface/Icons/INV_Misc_Head_Scourge_01',
        [134174] = 'Interface/Icons/INV_Misc_Head_Tauren_01',
        [134175] = 'Interface/Icons/INV_Misc_Head_Tauren_02',
        [134176] = 'Interface/Icons/INV_Misc_Head_Tiger_01',
        [134177] = 'Interface/Icons/INV_Misc_Head_Troll_01',
        [134178] = 'Interface/Icons/INV_Misc_Head_Troll_02',
        [134179] = 'Interface/Icons/INV_Misc_Head_Undead_01',
        [134180] = 'Interface/Icons/INV_Misc_Head_Undead_02',
        [134181] = 'Interface/Icons/INV_MISC_HERB_01',
        [134182] = 'Interface/Icons/INV_Misc_Herb_02',
        [134183] = 'Interface/Icons/INV_Misc_Herb_03',
        [134184] = 'Interface/Icons/INV_Misc_Herb_04',
        [134185] = 'Interface/Icons/INV_Misc_Herb_05',
        [134186] = 'Interface/Icons/INV_MISC_HERB_06',
        [134187] = 'Interface/Icons/INV_Misc_Herb_07',
        [134188] = 'Interface/Icons/INV_Misc_Herb_08',
        [134189] = 'Interface/Icons/INV_Misc_Herb_09',
        [134190] = 'Interface/Icons/INV_Misc_Herb_10',
        [134191] = 'Interface/Icons/INV_Misc_Herb_11',
        [134192] = 'Interface/Icons/INV_Misc_Herb_11a',
        [134193] = 'Interface/Icons/INV_Misc_Herb_12',
        [134194] = 'Interface/Icons/INV_Misc_Herb_13',
        [134195] = 'Interface/Icons/INV_Misc_Herb_14',
        [134196] = 'Interface/Icons/INV_Misc_Herb_15',
        [134197] = 'Interface/Icons/INV_Misc_Herb_16',
        [134198] = 'Interface/Icons/INV_Misc_Herb_17',
        [134199] = 'Interface/Icons/INV_Misc_Herb_18',
        [134200] = 'Interface/Icons/INV_Misc_Herb_19',
        [134201] = 'Interface/Icons/INV_MISC_HERB_ANCIENTLICHEN',
        [134202] = 'Interface/Icons/INV_Misc_Herb_BlackLotus',
        [134204] = 'Interface/Icons/INV_Misc_Herb_DreamFoil',
        [134205] = 'Interface/Icons/INV_Misc_Herb_Dreamingglory',
        [134206] = 'Interface/Icons/INV_Misc_Herb_Felblossom',
        [134207] = 'Interface/Icons/INV_Misc_Herb_FelLotus',
        [134208] = 'Interface/Icons/INV_Misc_Herb_Felweed',
        [134209] = 'Interface/Icons/INV_Misc_Herb_Flamecap',
        [134212] = 'Interface/Icons/INV_Misc_Herb_IceCap',
        [134214] = 'Interface/Icons/INV_Misc_Herb_Manathistle',
        [134215] = 'Interface/Icons/INV_Misc_Herb_MountainSilverSage',
        [134216] = 'Interface/Icons/INV_Misc_Herb_Netherbloom',
        [134217] = 'Interface/Icons/INV_Misc_Herb_Nightmareseed',
        [134218] = 'Interface/Icons/INV_Misc_Herb_Nightmarevine',
        [134219] = 'Interface/Icons/INV_Misc_Herb_PlagueBloom',
        [134220] = 'Interface/Icons/INV_Misc_Herb_Ragveil',
        [134221] = 'Interface/Icons/INV_Misc_Herb_SansamRoot',
        [134223] = 'Interface/Icons/INV_Misc_Herb_Terrocone',
    },
    ['Misc - Hook-Missile'] = {
        [134226] = 'Interface/Icons/INV_MISC_HOOK_01',
        [134227] = 'Interface/Icons/INV_Misc_Horn_01',
        [134228] = 'Interface/Icons/INV_Misc_Horn_02',
        [134229] = 'Interface/Icons/INV_Misc_Horn_03',
        [134230] = 'Interface/Icons/INV_Misc_Idol_01',
        [134231] = 'Interface/Icons/INV_Misc_Idol_02',
        [134232] = 'Interface/Icons/INV_Misc_Idol_03',
        [134233] = 'Interface/Icons/INV_Misc_Idol_04',
        [134234] = 'Interface/Icons/INV_MISC_IDOL_05',
        [134235] = 'Interface/Icons/INV_Misc_Key_01',
        [134236] = 'Interface/Icons/INV_Misc_Key_02',
        [134237] = 'Interface/Icons/INV_Misc_Key_03',
        [134238] = 'Interface/Icons/INV_Misc_Key_04',
        [134239] = 'Interface/Icons/INV_Misc_Key_05',
        [134240] = 'Interface/Icons/INV_Misc_Key_06',
        [134241] = 'Interface/Icons/INV_Misc_Key_07',
        [134242] = 'Interface/Icons/INV_Misc_Key_08',
        [134243] = 'Interface/Icons/INV_Misc_Key_09',
        [134244] = 'Interface/Icons/INV_Misc_Key_10',
        [134245] = 'Interface/Icons/INV_Misc_Key_11',
        [134246] = 'Interface/Icons/INV_Misc_Key_12',
        [134247] = 'Interface/Icons/INV_MISC_KEY_13',
        [134248] = 'Interface/Icons/INV_Misc_Key_14',
        [134249] = 'Interface/Icons/INV_Misc_Lantern_01',
        [134250] = 'Interface/Icons/INV_Misc_LeatherScrap_01',
        [134251] = 'Interface/Icons/INV_Misc_LeatherScrap_02',
        [134252] = 'Interface/Icons/INV_Misc_LeatherScrap_03',
        [134253] = 'Interface/Icons/INV_Misc_LeatherScrap_04',
        [134254] = 'Interface/Icons/INV_Misc_LeatherScrap_05',
        [134255] = 'Interface/Icons/INV_Misc_LeatherScrap_06',
        [134256] = 'Interface/Icons/INV_Misc_LeatherScrap_07',
        [134257] = 'Interface/Icons/INV_Misc_LeatherScrap_08',
        [134258] = 'Interface/Icons/INV_Misc_LeatherScrap_09',
        [134259] = 'Interface/Icons/INV_Misc_LeatherScrap_10',
        [134260] = 'Interface/Icons/INV_Misc_LeatherScrap_11',
        [134261] = 'Interface/Icons/INV_Misc_LeatherScrap_12',
        [134262] = 'Interface/Icons/INV_Misc_LeatherScrap_13',
        [134263] = 'Interface/Icons/INV_Misc_LeatherScrap_14',
        [134268] = 'Interface/Icons/INV_Misc_LuckyMoneyEnvelope',
        [134269] = 'Interface/Icons/INV_Misc_Map_01',
        [134270] = 'Interface/Icons/INV_Misc_MissileLarge_Blue',
        [134271] = 'Interface/Icons/INV_Misc_MissileLarge_Green',
        [134272] = 'Interface/Icons/INV_Misc_MissileLarge_Purple',
        [134273] = 'Interface/Icons/INV_Misc_MissileLarge_Red',
        [134274] = 'Interface/Icons/INV_Misc_MissileLarge_White',
        [134275] = 'Interface/Icons/INV_Misc_MissileLarge_Yellow',
        [134276] = 'Interface/Icons/INV_Misc_MissileLargeCluster_Blue',
        [134277] = 'Interface/Icons/INV_Misc_MissileLargeCluster_Green',
        [134278] = 'Interface/Icons/INV_Misc_MissileLargeCluster_Purple',
        [134279] = 'Interface/Icons/INV_Misc_MissileLargeCluster_Red',
        [134280] = 'Interface/Icons/INV_Misc_MissileLargeCluster_White',
        [134281] = 'Interface/Icons/INV_Misc_MissileLargeCluster_Yellow',
        [134282] = 'Interface/Icons/INV_Misc_MissileSmall_Blue',
        [134283] = 'Interface/Icons/INV_Misc_MissileSmall_Green',
        [134284] = 'Interface/Icons/INV_Misc_MissileSmall_Purple',
        [134285] = 'Interface/Icons/INV_Misc_MissileSmall_Red',
        [134286] = 'Interface/Icons/INV_Misc_MissileSmall_White',
        [134287] = 'Interface/Icons/INV_Misc_MissileSmall_Yellow',
        [134288] = 'Interface/Icons/INV_Misc_MissileSmallCluster_Blue',
        [134289] = 'Interface/Icons/INV_Misc_MissileSmallCluster_Green',
        [134290] = 'Interface/Icons/INV_Misc_MissileSmallCluster_Purple',
        [134291] = 'Interface/Icons/INV_Misc_MissileSmallCluster_Red',
        [134292] = 'Interface/Icons/INV_Misc_MissileSmallCluster_White',
        [134293] = 'Interface/Icons/INV_Misc_MissileSmallCluster_Yellow',
    },
    ['Misc - MonsterClaw-OrnateBox'] = {
        [134294] = 'Interface/Icons/INV_Misc_MonsterClaw_01',
        [134295] = 'Interface/Icons/INV_Misc_MonsterClaw_02',
        [134296] = 'Interface/Icons/INV_Misc_MonsterClaw_03',
        [134297] = 'Interface/Icons/INV_Misc_MonsterClaw_04',
        [134298] = 'Interface/Icons/INV_Misc_MonsterFang_01',
        [134299] = 'Interface/Icons/INV_Misc_MonsterHead_01',
        [134300] = 'Interface/Icons/INV_Misc_MonsterHead_02',
        [134301] = 'Interface/Icons/INV_Misc_MonsterHead_03',
        [134302] = 'Interface/Icons/INV_Misc_MonsterHead_04',
        [134303] = 'Interface/Icons/INV_Misc_MonsterScales_01',
        [134304] = 'Interface/Icons/INV_Misc_MonsterScales_02',
        [134305] = 'Interface/Icons/INV_Misc_MonsterScales_03',
        [134306] = 'Interface/Icons/INV_Misc_MonsterScales_04',
        [134307] = 'Interface/Icons/INV_Misc_MonsterScales_05',
        [134308] = 'Interface/Icons/INV_Misc_MonsterScales_06',
        [134309] = 'Interface/Icons/INV_Misc_MonsterScales_07',
        [134310] = 'Interface/Icons/INV_Misc_MonsterScales_08',
        [134311] = 'Interface/Icons/INV_Misc_MonsterScales_09',
        [134312] = 'Interface/Icons/INV_Misc_MonsterScales_10',
        [134313] = 'Interface/Icons/INV_Misc_MonsterScales_11',
        [134314] = 'Interface/Icons/INV_Misc_MonsterScales_12',
        [134315] = 'Interface/Icons/INV_MISC_MONSTERSCALES_13',
        [134316] = 'Interface/Icons/INV_Misc_MonsterScales_14',
        [134317] = 'Interface/Icons/INV_Misc_MonsterScales_15',
        [134318] = 'Interface/Icons/INV_Misc_MonsterScales_16',
        [134319] = 'Interface/Icons/INV_Misc_MonsterScales_17',
        [134320] = 'Interface/Icons/INV_Misc_MonsterScales_18',
        [134321] = 'Interface/Icons/INV_Misc_MonsterSpiderCarapace_01',
        [134322] = 'Interface/Icons/INV_Misc_MonsterTail_01',
        [134323] = 'Interface/Icons/INV_Misc_MonsterTail_02',
        [134324] = 'Interface/Icons/INV_Misc_MonsterTail_03',
        [134325] = 'Interface/Icons/INV_Misc_Net_01',
        [134326] = 'Interface/Icons/INV_Misc_Noose_01',
        [134327] = 'Interface/Icons/INV_Misc_Note_01',
        [134328] = 'Interface/Icons/INV_MISC_NOTE_02',
        [134329] = 'Interface/Icons/INV_Misc_Note_03',
        [134330] = 'Interface/Icons/INV_Misc_Note_04',
        [134331] = 'Interface/Icons/INV_Misc_Note_05',
        [134332] = 'Interface/Icons/INV_MISC_NOTE_06',
        [134333] = 'Interface/Icons/INV_Misc_Orb_01',
        [134334] = 'Interface/Icons/INV_Misc_Orb_02',
        [134335] = 'Interface/Icons/INV_Misc_Orb_03',
        [134336] = 'Interface/Icons/INV_Misc_Orb_04',
        [134337] = 'Interface/Icons/INV_Misc_Orb_05',
        [134338] = 'Interface/Icons/INV_Misc_Organ_01',
        [134339] = 'Interface/Icons/INV_Misc_Organ_02',
        [134340] = 'Interface/Icons/INV_Misc_Organ_03',
        [134341] = 'Interface/Icons/INV_Misc_Organ_04',
        [134342] = 'Interface/Icons/INV_Misc_Organ_05',
        [134343] = 'Interface/Icons/INV_Misc_Organ_06',
        [134344] = 'Interface/Icons/INV_Misc_OrnateBox',
    },
    ['Misc - Pelt-Quiver'] = {
        [134345] = 'Interface/Icons/INV_Misc_Pelt_01',
        [134346] = 'Interface/Icons/INV_Misc_Pelt_02',
        [134347] = 'Interface/Icons/INV_Misc_Pelt_03',
        [134348] = 'Interface/Icons/INV_Misc_Pelt_04',
        [134349] = 'Interface/Icons/INV_Misc_Pelt_05',
        [134350] = 'Interface/Icons/INV_Misc_Pelt_06',
        [134353] = 'Interface/Icons/INV_Misc_Pelt_Bear_01',
        [134354] = 'Interface/Icons/INV_Misc_Pelt_Bear_02',
        [134355] = 'Interface/Icons/INV_Misc_Pelt_Bear_03',
        [134356] = 'Interface/Icons/INV_Misc_Pelt_Bear_Ruin_01',
        [134357] = 'Interface/Icons/INV_Misc_Pelt_Bear_Ruin_02',
        [134358] = 'Interface/Icons/INV_Misc_Pelt_Bear_Ruin_03',
        [134359] = 'Interface/Icons/INV_Misc_Pelt_Bear_Ruin_04',
        [134360] = 'Interface/Icons/INV_Misc_Pelt_Bear_Ruin_05',
        [134361] = 'Interface/Icons/INV_Misc_Pelt_Boar_01',
        [134362] = 'Interface/Icons/INV_Misc_Pelt_Boar_02',
        [134363] = 'Interface/Icons/INV_Misc_Pelt_Boar_Ruin_01',
        [134364] = 'Interface/Icons/INV_Misc_Pelt_Boar_Ruin_02',
        [134365] = 'Interface/Icons/INV_Misc_Pelt_Boar_Ruin_03',
        [134366] = 'Interface/Icons/INV_Misc_Pelt_Wolf_01',
        [134367] = 'Interface/Icons/INV_Misc_Pelt_Wolf_02',
        [134368] = 'Interface/Icons/INV_Misc_Pelt_Wolf_Ruin_01',
        [134369] = 'Interface/Icons/INV_Misc_Pelt_Wolf_Ruin_02',
        [134370] = 'Interface/Icons/INV_Misc_Pelt_Wolf_Ruin_03',
        [134371] = 'Interface/Icons/INV_Misc_Pelt_Wolf_Ruin_04',
        [134372] = 'Interface/Icons/INV_Misc_Petbiscuit_01',
        [134373] = 'Interface/Icons/INV_Misc_PheonixPet_01',
        [134374] = 'Interface/Icons/INV_Misc_Pipe_01',
        [134375] = 'Interface/Icons/INV_Misc_Platnumdisks',
        [134376] = 'Interface/Icons/INV_Misc_PocketWatch_01',
        [134377] = 'Interface/Icons/INV_Misc_PocketWatch_02',
        [134378] = 'Interface/Icons/INV_Misc_PocketWatch_03',
        [134379] = 'Interface/Icons/INV_Misc_Powder_Adamantite',
        [134380] = 'Interface/Icons/INV_Misc_Powder_Black',
        [134381] = 'Interface/Icons/INV_MISC_POWDER_BLUE',
        [134382] = 'Interface/Icons/INV_Misc_Powder_Copper',
        [134383] = 'Interface/Icons/INV_Misc_Powder_Feliron',
        [134384] = 'Interface/Icons/INV_Misc_Powder_Green',
        [134385] = 'Interface/Icons/INV_Misc_Powder_Iron',
        [134386] = 'Interface/Icons/INV_Misc_Powder_Mithril',
        [134387] = 'Interface/Icons/INV_Misc_Powder_Purple',
        [134388] = 'Interface/Icons/INV_Misc_Powder_Thorium',
        [134389] = 'Interface/Icons/INV_Misc_Powder_Tin',
        [134390] = 'Interface/Icons/INV_Misc_PunchCards_Blue',
        [134391] = 'Interface/Icons/INV_Misc_PunchCards_Prismatic',
        [134392] = 'Interface/Icons/INV_Misc_PunchCards_Red',
        [134393] = 'Interface/Icons/INV_Misc_PunchCards_White',
        [134394] = 'Interface/Icons/INV_Misc_PunchCards_Yellow',
        [134395] = 'Interface/Icons/INV_Misc_QirajiCrystal_01',
        [134396] = 'Interface/Icons/INV_Misc_QirajiCrystal_02',
        [134397] = 'Interface/Icons/INV_Misc_QirajiCrystal_03',
        [134398] = 'Interface/Icons/INV_Misc_QirajiCrystal_04',
        [134399] = 'Interface/Icons/INV_Misc_QirajiCrystal_05',
        [134400] = 'Interface/Icons/INV_Misc_QuestionMark',
        [134401] = 'Interface/Icons/INV_Misc_Quiver_01',
        [134402] = 'Interface/Icons/INV_Misc_Quiver_02',
        [134403] = 'Interface/Icons/INV_Misc_Quiver_03',
        [134404] = 'Interface/Icons/INV_Misc_Quiver_04',
        [134405] = 'Interface/Icons/INV_MISC_QUIVER_05',
        [134406] = 'Interface/Icons/INV_Misc_Quiver_06',
        [134407] = 'Interface/Icons/INV_Misc_Quiver_07',
        [134408] = 'Interface/Icons/INV_Misc_Quiver_08',
        [134409] = 'Interface/Icons/INV_Misc_Quiver_09',
        [134410] = 'Interface/Icons/INV_Misc_Quiver_10',
    },
    ['Misc - Ribbon-Wrench'] = {
        [134411] = 'Interface/Icons/INV_Misc_Ribbon_01',
        [134412] = 'Interface/Icons/INV_Misc_Root_01',
        [134413] = 'Interface/Icons/INV_Misc_Root_02',
        [134414] = 'Interface/Icons/INV_MISC_RUNE_01',
        [134415] = 'Interface/Icons/INV_Misc_Rune_02',
        [134416] = 'Interface/Icons/INV_Misc_Rune_03',
        [134417] = 'Interface/Icons/INV_Misc_Rune_04',
        [134418] = 'Interface/Icons/INV_MISC_RUNE_05',
        [134419] = 'Interface/Icons/INV_Misc_Rune_06',
        [134420] = 'Interface/Icons/INV_Misc_Rune_07',
        [134421] = 'Interface/Icons/INV_MISC_RUNE_08',
        [134422] = 'Interface/Icons/INV_Misc_Rune_09',
        [134423] = 'Interface/Icons/INV_Misc_Rune_10',
        [134424] = 'Interface/Icons/INV_Misc_Rune_11',
        [134425] = 'Interface/Icons/INV_Misc_Rune_12',
        [134426] = 'Interface/Icons/INV_Misc_Rune_13',
        [134428] = 'Interface/Icons/INV_Misc_ScrewDriver_01',
        [134429] = 'Interface/Icons/INV_Misc_ScrewDriver_02',
        [134430] = 'Interface/Icons/INV_Misc_ShadowEgg',
        [134431] = 'Interface/Icons/INV_Misc_Shell_01',
        [134432] = 'Interface/Icons/INV_Misc_Shell_02',
        [134433] = 'Interface/Icons/INV_Misc_Shell_03',
        [134434] = 'Interface/Icons/INV_Misc_Shell_04',
        [134435] = 'Interface/Icons/INV_Misc_Shovel_01',
        [134436] = 'Interface/Icons/INV_Misc_Shovel_02',
        [134437] = 'Interface/Icons/INV_Misc_Slime_01',
        [134439] = 'Interface/Icons/INV_Misc_SpineLeaf _01',
        [134440] = 'Interface/Icons/INV_Misc_Spyglass_01',
        [134441] = 'Interface/Icons/INV_Misc_Spyglass_02',
        [134442] = 'Interface/Icons/INV_Misc_Spyglass_03',
        [134443] = 'Interface/Icons/INV_Misc_Statue_01',
        [134444] = 'Interface/Icons/INV_Misc_Statue_02',
        [134445] = 'Interface/Icons/INV_Misc_Statue_03',
        [134446] = 'Interface/Icons/INV_Misc_Statue_04',
        [134447] = 'Interface/Icons/INV_Misc_Statue_05',
        [134448] = 'Interface/Icons/INV_Misc_Statue_06',
        [134449] = 'Interface/Icons/INV_Misc_Statue_07',
        [134450] = 'Interface/Icons/INV_Misc_Statue_08',
        [134451] = 'Interface/Icons/INV_Misc_Statue_09',
        [134452] = 'Interface/Icons/INV_Misc_Statue_10',
        [134455] = 'Interface/Icons/INV_Misc_StoneTablet_01',
        [134456] = 'Interface/Icons/INV_Misc_StoneTablet_02',
        [134457] = 'Interface/Icons/INV_Misc_StoneTablet_03',
        [134458] = 'Interface/Icons/INV_Misc_StoneTablet_04',
        [134459] = 'Interface/Icons/INV_Misc_StoneTablet_05',
        [134460] = 'Interface/Icons/INV_Misc_StoneTablet_06',
        [134461] = 'Interface/Icons/INV_Misc_StoneTablet_07',
        [134462] = 'Interface/Icons/INV_Misc_StoneTablet_08',
        [134463] = 'Interface/Icons/INV_Misc_StoneTablet_09',
        [134464] = 'Interface/Icons/INV_Misc_StoneTablet_10',
        [134465] = 'Interface/Icons/INV_Misc_StoneTablet_11',
        [134466] = 'Interface/Icons/Inv_Misc_SummerFest_BrazierBlue',
        [134467] = 'Interface/Icons/Inv_Misc_SummerFest_BrazierGreen',
        [134468] = 'Interface/Icons/Inv_Misc_SummerFest_BrazierOrange',
        [134469] = 'Interface/Icons/Inv_Misc_SummerFest_BrazierRed',
        [134470] = 'Interface/Icons/INV_Misc_SurgeonGlove_01',
        [134471] = 'Interface/Icons/INV_Misc_SymbolofKings_01',
        [134472] = 'Interface/Icons/INV_Misc_TabardPVP_01',
        [134473] = 'Interface/Icons/INV_Misc_TabardPVP_02',
        [134474] = 'Interface/Icons/INV_Misc_TabardPVP_03',
        [134475] = 'Interface/Icons/INV_Misc_TabardPVP_04',
        [134476] = 'Interface/Icons/INV_MISC_TABARDSUMMER01',
        [134477] = 'Interface/Icons/INV_Misc_TabardSummer02',
        [134478] = 'Interface/Icons/INV_Misc_TheGoldenCheep',
        [134479] = 'Interface/Icons/INV_Misc_Thread_01',
        [134480] = 'Interface/Icons/INV_Misc_ThrowingBall_01',
        [134481] = 'Interface/Icons/INV_Misc_Ticket_Darkmoon_01',
        [134482] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Beasts_01',
        [134483] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Blessings',
        [134484] = 'Interface/Icons/INV_Misc_Ticket_Tarot_BlueDragon_01',
        [134485] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Crusade',
        [134487] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Furies',
        [134488] = 'Interface/Icons/INV_MISC_TICKET_TAROT_HEROISM_01',
        [134489] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Lunacy',
        [134490] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Madness',
        [134491] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Maelstrom_01',
        [134492] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Portal_01',
        [134493] = 'Interface/Icons/INV_MISC_TICKET_TAROT_STACK_01',
        [134494] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Storms',
        [134495] = 'Interface/Icons/INV_Misc_Ticket_Tarot_TwistingNether_01',
        [134496] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Vengeance',
        [134497] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Warlord_01',
        [134498] = 'Interface/Icons/INV_Misc_Ticket_Tarot_Wrath',
        [134499] = 'Interface/Icons/INV_Misc_Token_ArgentDawn',
        [134500] = 'Interface/Icons/INV_Misc_Token_ArgentDawn2',
        [134501] = 'Interface/Icons/INV_Misc_Token_ArgentDawn3',
        [134502] = 'Interface/Icons/INV_Misc_Token_HonorHold',
        [134503] = 'Interface/Icons/INV_Misc_Token_ScarletCrusade',
        [134504] = 'Interface/Icons/INV_Misc_Token_Thrallmar',
        [134505] = 'Interface/Icons/INV_Misc_Toy_01',
        [134506] = 'Interface/Icons/INV_Misc_Toy_02',
        [134507] = 'Interface/Icons/INV_Misc_Toy_03',
        [134508] = 'Interface/Icons/INV_Misc_Toy_04',
        [134509] = 'Interface/Icons/INV_Misc_Toy_05',
        [134510] = 'Interface/Icons/INV_Misc_Toy_06',
        [134511] = 'Interface/Icons/INV_Misc_Toy_07',
        [134512] = 'Interface/Icons/INV_Misc_Toy_08',
        [134513] = 'Interface/Icons/INV_Misc_Toy_09',
        [134514] = 'Interface/Icons/INV_Misc_Urn_01',
        [134515] = 'Interface/Icons/INV_Misc_WartornScrap_Chain',
        [134516] = 'Interface/Icons/INV_Misc_WartornScrap_Cloth',
        [134517] = 'Interface/Icons/INV_Misc_WartornScrap_Leather',
        [134518] = 'Interface/Icons/INV_Misc_WartornScrap_Plate',
        [134519] = 'Interface/Icons/INV_Misc_Weathermachine_01',
        [134520] = 'Interface/Icons/INV_Misc_Wrench_01',
        [134521] = 'Interface/Icons/INV_Misc_Wrench_02'
    },
    Mushroom = {
        [134522] = 'Interface/Icons/INV_Mushroom_01',
        [134523] = 'Interface/Icons/INV_Mushroom_02',
        [134524] = 'Interface/Icons/INV_Mushroom_03',
        [134525] = 'Interface/Icons/INV_Mushroom_04',
        [134526] = 'Interface/Icons/INV_Mushroom_05',
        [134527] = 'Interface/Icons/INV_Mushroom_06',
        [134528] = 'Interface/Icons/INV_Mushroom_07',
        [134529] = 'Interface/Icons/INV_Mushroom_08',
        [134530] = 'Interface/Icons/INV_Mushroom_09',
        [134531] = 'Interface/Icons/INV_Mushroom_10',
        [134532] = 'Interface/Icons/INV_Mushroom_11',
        [134533] = 'Interface/Icons/INV_Mushroom_12',
        [134534] = 'Interface/Icons/INV_Mushroom_13'
    },
    Musket = {
        [134535] = 'Interface/Icons/INV_Musket_01',
        [134536] = 'Interface/Icons/INV_Musket_02',
        [134537] = 'Interface/Icons/INV_Musket_03',
        [134538] = 'Interface/Icons/INV_Musket_04'
    },
    Netherwhelp = {
        [134539] = 'Interface/Icons/INV_Netherwhelp'
    },
    Offhand = {
        [134540] = 'Interface/Icons/INV_Offhand_Blood_01',
        [134541] = 'Interface/Icons/INV_Offhand_Blood_02',
        [134542] = 'Interface/Icons/INV_Offhand_Draenei_A_01',
        [134543] = 'Interface/Icons/INV_Offhand_Draenei_A_02',
        [134544] = 'Interface/Icons/INV_Offhand_Hyjal_D_01',
        [134545] = 'Interface/Icons/INV_Offhand_Naxxramas_02',
        [134546] = 'Interface/Icons/INV_Offhand_Naxxramas_03',
        [134547] = 'Interface/Icons/INV_Offhand_Naxxramas_04',
        [134548] = 'Interface/Icons/INV_Offhand_Naxxramas_D_01',
        [134549] = 'Interface/Icons/INV_Offhand_OutlandRaid_01',
        [134550] = 'Interface/Icons/INV_Offhand_OutlandRaid_02',
        [134551] = 'Interface/Icons/INV_Offhand_OutlandRaid_03blue',
        [134552] = 'Interface/Icons/INV_Offhand_OutlandRaid_03orange',
        [134553] = 'Interface/Icons/INV_Offhand_OutlandRaid_03white',
        [134554] = 'Interface/Icons/INV_Offhand_Stratholme_A_01',
        [134555] = 'Interface/Icons/INV_Offhand_Stratholme_A_02',
        [134556] = 'Interface/Icons/INV_Offhand_Sunwell_D_01',
        [134557] = 'Interface/Icons/INV_Offhand_Sunwell_D_02',
        [134559] = 'Interface/Icons/INV_Offhand_ZulAman_D_01',
        [134560] = 'Interface/Icons/INV_Offhand_ZulAman_D_02'
    },
    Ore = {
        [134561] = 'Interface/Icons/INV_Ore_Adamantium',
        [134562] = 'Interface/Icons/INV_Ore_Adamantium_01',
        [134563] = 'Interface/Icons/INV_Ore_Arcanite_01',
        [134564] = 'Interface/Icons/INV_Ore_Arcanite_02',
        [134566] = 'Interface/Icons/INV_Ore_Copper_01',
        [134567] = 'Interface/Icons/INV_Ore_Eternium',
        [134568] = 'Interface/Icons/INV_Ore_Ethernium_01',
        [134569] = 'Interface/Icons/INV_Ore_FelIron',
        [134570] = 'Interface/Icons/INV_Ore_FelIron_01',
        [134571] = 'Interface/Icons/INV_Ore_Gold_01',
        [134572] = 'Interface/Icons/INV_Ore_Iron_01',
        [134573] = 'Interface/Icons/INV_Ore_Khorium',
        [134574] = 'Interface/Icons/INV_Ore_Khorium_01',
        [134575] = 'Interface/Icons/INV_Ore_Mithril_01',
        [134576] = 'Interface/Icons/INV_Ore_Mithril_02',
        [134577] = 'Interface/Icons/INV_Ore_Thorium_01',
        [134578] = 'Interface/Icons/INV_Ore_Thorium_02',
        [134579] = 'Interface/Icons/INV_Ore_Tin_01',
        [134580] = 'Interface/Icons/INV_Ore_TrueSilver_01'
    },
    Pants = {
        [134581] = 'Interface/Icons/INV_Pants_01',
        [134582] = 'Interface/Icons/INV_Pants_02',
        [134583] = 'Interface/Icons/INV_Pants_03',
        [134584] = 'Interface/Icons/INV_Pants_04',
        [134585] = 'Interface/Icons/INV_Pants_05',
        [134586] = 'Interface/Icons/INV_Pants_06',
        [134587] = 'Interface/Icons/INV_Pants_07',
        [134588] = 'Interface/Icons/INV_Pants_08',
        [134589] = 'Interface/Icons/INV_Pants_09',
        [134590] = 'Interface/Icons/INV_Pants_10',
        [134591] = 'Interface/Icons/INV_Pants_11',
        [134592] = 'Interface/Icons/INV_Pants_12',
        [134593] = 'Interface/Icons/INV_Pants_13',
        [134594] = 'Interface/Icons/INV_Pants_14',
        [134595] = 'Interface/Icons/INV_Pants_Cloth_01',
        [134596] = 'Interface/Icons/INV_Pants_Cloth_02',
        [134597] = 'Interface/Icons/INV_Pants_Cloth_03',
        [134598] = 'Interface/Icons/INV_Pants_Cloth_04',
        [134599] = 'Interface/Icons/INV_Pants_Cloth_05',
        [134600] = 'Interface/Icons/INV_Pants_Cloth_06',
        [134601] = 'Interface/Icons/INV_Pants_Cloth_07',
        [134602] = 'Interface/Icons/INV_Pants_Cloth_08',
        [134603] = 'Interface/Icons/INV_Pants_Cloth_09',
        [134604] = 'Interface/Icons/INV_Pants_Cloth_10',
        [134605] = 'Interface/Icons/INV_Pants_Cloth_11',
        [134606] = 'Interface/Icons/INV_Pants_Cloth_12',
        [134607] = 'Interface/Icons/INV_Pants_Cloth_13',
        [134608] = 'Interface/Icons/INV_Pants_Cloth_14',
        [134609] = 'Interface/Icons/INV_Pants_Cloth_15',
        [134610] = 'Interface/Icons/INV_Pants_Cloth_16',
        [134611] = 'Interface/Icons/INV_Pants_Cloth_17',
        [134612] = 'Interface/Icons/INV_Pants_Cloth_18',
        [134613] = 'Interface/Icons/INV_Pants_Cloth_19',
        [134614] = 'Interface/Icons/INV_Pants_Cloth_20',
        [134615] = 'Interface/Icons/INV_Pants_Cloth_21',
        [134616] = 'Interface/Icons/INV_Pants_Cloth_22',
        [134617] = 'Interface/Icons/INV_Pants_Cloth_23',
        [134618] = 'Interface/Icons/INV_Pants_Cloth_24',
        [134619] = 'Interface/Icons/INV_Pants_Cloth_25',
        [134620] = 'Interface/Icons/INV_Pants_Cloth_26',
        [134621] = 'Interface/Icons/INV_Pants_Cloth_27',
        [134622] = 'Interface/Icons/INV_Pants_Cloth_28',
        [134623] = 'Interface/Icons/INV_PANTS_CLOTH_29',
        [134626] = 'Interface/Icons/INV_Pants_Leather_01',
        [134627] = 'Interface/Icons/INV_Pants_Leather_02',
        [134628] = 'Interface/Icons/INV_Pants_Leather_03',
        [134629] = 'Interface/Icons/INV_Pants_Leather_04',
        [134630] = 'Interface/Icons/INV_Pants_Leather_05',
        [134631] = 'Interface/Icons/INV_Pants_Leather_06',
        [134632] = 'Interface/Icons/INV_Pants_Leather_07',
        [134633] = 'Interface/Icons/INV_Pants_Leather_08',
        [134634] = 'Interface/Icons/INV_Pants_Leather_09',
        [134635] = 'Interface/Icons/INV_Pants_Leather_10',
        [134636] = 'Interface/Icons/INV_Pants_Leather_11',
        [134637] = 'Interface/Icons/INV_Pants_Leather_12',
        [134638] = 'Interface/Icons/INV_Pants_Leather_13',
        [134639] = 'Interface/Icons/INV_Pants_Leather_14',
        [134640] = 'Interface/Icons/INV_Pants_Leather_15',
        [134641] = 'Interface/Icons/INV_Pants_Leather_16',
        [134642] = 'Interface/Icons/INV_Pants_Leather_17',
        [134643] = 'Interface/Icons/INV_Pants_Leather_18',
        [134644] = 'Interface/Icons/INV_Pants_Leather_19',
        [134645] = 'Interface/Icons/INV_Pants_Leather_20',
        [134646] = 'Interface/Icons/INV_Pants_Leather_21',
        [134647] = 'Interface/Icons/INV_Pants_Leather_22',
        [134648] = 'Interface/Icons/INV_Pants_Leather_23',
        [134649] = 'Interface/Icons/INV_Pants_Leather_24',
        [134650] = 'Interface/Icons/INV_Pants_Leather_25',
        [134651] = 'Interface/Icons/INV_PANTS_LEATHER_26',
        [134652] = 'Interface/Icons/INV_PANTS_LEATHER_27',
        [134653] = 'Interface/Icons/INV_Pants_Mail_01',
        [134654] = 'Interface/Icons/INV_Pants_Mail_02',
        [134655] = 'Interface/Icons/INV_Pants_Mail_03',
        [134656] = 'Interface/Icons/INV_Pants_Mail_04',
        [134657] = 'Interface/Icons/INV_Pants_Mail_05',
        [134658] = 'Interface/Icons/INV_Pants_Mail_06',
        [134659] = 'Interface/Icons/INV_Pants_Mail_07',
        [134660] = 'Interface/Icons/INV_Pants_Mail_08',
        [134661] = 'Interface/Icons/INV_Pants_Mail_09',
        [134662] = 'Interface/Icons/INV_Pants_Mail_10',
        [134663] = 'Interface/Icons/INV_Pants_Mail_11',
        [134664] = 'Interface/Icons/INV_Pants_Mail_12',
        [134665] = 'Interface/Icons/INV_Pants_Mail_13',
        [134666] = 'Interface/Icons/INV_Pants_Mail_14',
        [134667] = 'Interface/Icons/INV_Pants_Mail_15',
        [134668] = 'Interface/Icons/INV_Pants_Mail_16',
        [134669] = 'Interface/Icons/INV_Pants_Mail_17',
        [134670] = 'Interface/Icons/INV_Pants_Mail_18',
        [134671] = 'Interface/Icons/INV_Pants_Mail_19',
        [134672] = 'Interface/Icons/INV_Pants_Mail_20',
        [134673] = 'Interface/Icons/INV_Pants_Mail_21',
        [134674] = 'Interface/Icons/INV_PANTS_MAIL_24',
        [134675] = 'Interface/Icons/INV_PANTS_MAIL_25',
        [134676] = 'Interface/Icons/INV_Pants_Mail_26',
        [134677] = 'Interface/Icons/INV_Pants_Plate_01',
        [134678] = 'Interface/Icons/INV_Pants_Plate_02',
        [134679] = 'Interface/Icons/INV_Pants_Plate_03',
        [134680] = 'Interface/Icons/INV_Pants_Plate_04',
        [134681] = 'Interface/Icons/INV_Pants_Plate_05',
        [134682] = 'Interface/Icons/INV_Pants_Plate_06',
        [134683] = 'Interface/Icons/INV_Pants_Plate_07',
        [134684] = 'Interface/Icons/INV_Pants_Plate_08',
        [134685] = 'Interface/Icons/INV_Pants_Plate_09',
        [134686] = 'Interface/Icons/INV_Pants_Plate_10',
        [134687] = 'Interface/Icons/INV_Pants_Plate_11',
        [134688] = 'Interface/Icons/INV_Pants_Plate_12',
        [134689] = 'Interface/Icons/INV_Pants_Plate_13',
        [134690] = 'Interface/Icons/INV_Pants_Plate_14',
        [134691] = 'Interface/Icons/INV_Pants_Plate_15',
        [134692] = 'Interface/Icons/INV_Pants_Plate_16',
        [134693] = 'Interface/Icons/INV_Pants_Plate_17',
        [134694] = 'Interface/Icons/INV_Pants_Plate_18',
        [134695] = 'Interface/Icons/INV_Pants_Plate_19',
        [134696] = 'Interface/Icons/INV_Pants_Plate_20',
        [134697] = 'Interface/Icons/INV_Pants_Plate_21',
        [134698] = 'Interface/Icons/INV_Pants_Plate_22',
        [134699] = 'Interface/Icons/INV_Pants_Plate_23',
        [134700] = 'Interface/Icons/INV_Pants_Plate_24',
        [134701] = 'Interface/Icons/INV_Pants_Plate_25',
        [134702] = 'Interface/Icons/INV_PANTS_PLATE_26',
        [134703] = 'Interface/Icons/INV_PANTS_PLATE_27',
        [134704] = 'Interface/Icons/INV_Pants_Plate_28',
        [134705] = 'Interface/Icons/INV_Pants_Plate_29',
        [134706] = 'Interface/Icons/INV_Pants_Wolf'
    },
    Pick = {
        [134707] = 'Interface/Icons/INV_Pick_01',
        [134708] = 'Interface/Icons/INV_Pick_02',
        [134709] = 'Interface/Icons/INV_Pick_03',
        [134710] = 'Interface/Icons/INV_Pick_05'
    },
    Poison = {
        [134711] = 'Interface/Icons/INV_Poison_MindNumbing'
    },
    Potion = {
        [134712] = 'Interface/Icons/INV_POTION_01',
        [134713] = 'Interface/Icons/INV_Potion_02',
        [134714] = 'Interface/Icons/INV_Potion_03',
        [134715] = 'Interface/Icons/INV_Potion_04',
        [134716] = 'Interface/Icons/INV_Potion_05',
        [134717] = 'Interface/Icons/INV_Potion_06',
        [134718] = 'Interface/Icons/INV_Potion_07',
        [134719] = 'Interface/Icons/INV_Potion_08',
        [134720] = 'Interface/Icons/INV_Potion_09',
        [134721] = 'Interface/Icons/INV_Potion_10',
        [134722] = 'Interface/Icons/INV_Potion_100',
        [134723] = 'Interface/Icons/INV_Potion_101',
        [134724] = 'Interface/Icons/INV_Potion_102',
        [134725] = 'Interface/Icons/INV_Potion_103',
        [134726] = 'Interface/Icons/INV_Potion_104',
        [134727] = 'Interface/Icons/INV_Potion_105',
        [134728] = 'Interface/Icons/INV_Potion_106',
        [134729] = 'Interface/Icons/INV_Potion_107',
        [134730] = 'Interface/Icons/INV_Potion_108',
        [134731] = 'Interface/Icons/INV_Potion_109',
        [134732] = 'Interface/Icons/INV_Potion_11',
        [134733] = 'Interface/Icons/INV_Potion_110',
        [134734] = 'Interface/Icons/INV_Potion_111',
        [134735] = 'Interface/Icons/INV_Potion_112',
        [134736] = 'Interface/Icons/INV_Potion_113',
        [134737] = 'Interface/Icons/INV_Potion_114',
        [134738] = 'Interface/Icons/INV_Potion_115',
        [134739] = 'Interface/Icons/INV_Potion_116',
        [134740] = 'Interface/Icons/INV_Potion_117',
        [134741] = 'Interface/Icons/INV_Potion_118',
        [134742] = 'Interface/Icons/INV_Potion_119',
        [134743] = 'Interface/Icons/INV_Potion_12',
        [134744] = 'Interface/Icons/INV_Potion_120',
        [134745] = 'Interface/Icons/INV_Potion_121',
        [134746] = 'Interface/Icons/INV_Potion_122',
        [134747] = 'Interface/Icons/INV_Potion_123',
        [134748] = 'Interface/Icons/INV_Potion_124',
        [134749] = 'Interface/Icons/INV_Potion_125',
        [134750] = 'Interface/Icons/INV_Potion_126',
        [134751] = 'Interface/Icons/INV_Potion_127',
        [134752] = 'Interface/Icons/INV_Potion_128',
        [134753] = 'Interface/Icons/INV_Potion_129',
        [134754] = 'Interface/Icons/INV_Potion_13',
        [134755] = 'Interface/Icons/INV_Potion_130',
        [134756] = 'Interface/Icons/INV_Potion_131',
        [134757] = 'Interface/Icons/INV_Potion_132',
        [134758] = 'Interface/Icons/INV_Potion_133',
        [134759] = 'Interface/Icons/INV_Potion_134',
        [134760] = 'Interface/Icons/INV_Potion_135',
        [134761] = 'Interface/Icons/INV_Potion_136',
        [134762] = 'Interface/Icons/INV_Potion_137',
        [134763] = 'Interface/Icons/INV_Potion_138',
        [134764] = 'Interface/Icons/INV_Potion_139',
        [134765] = 'Interface/Icons/INV_Potion_14',
        [134766] = 'Interface/Icons/INV_Potion_140',
        [134767] = 'Interface/Icons/INV_Potion_141',
        [134768] = 'Interface/Icons/INV_Potion_142',
        [134769] = 'Interface/Icons/INV_Potion_143',
        [134770] = 'Interface/Icons/INV_Potion_144',
        [134771] = 'Interface/Icons/INV_Potion_145',
        [134772] = 'Interface/Icons/INV_Potion_146',
        [134773] = 'Interface/Icons/INV_Potion_147',
        [134774] = 'Interface/Icons/INV_Potion_148',
        [134775] = 'Interface/Icons/INV_Potion_149',
        [134776] = 'Interface/Icons/INV_Potion_15',
        [134777] = 'Interface/Icons/INV_Potion_150',
        [134778] = 'Interface/Icons/INV_Potion_151',
        [134779] = 'Interface/Icons/INV_Potion_152',
        [134780] = 'Interface/Icons/INV_Potion_153',
        [134781] = 'Interface/Icons/INV_Potion_154',
        [134782] = 'Interface/Icons/INV_Potion_155',
        [134783] = 'Interface/Icons/INV_Potion_156',
        [134784] = 'Interface/Icons/INV_Potion_157',
        [134785] = 'Interface/Icons/INV_Potion_158',
        [134786] = 'Interface/Icons/INV_Potion_159',
        [134787] = 'Interface/Icons/INV_Potion_16',
        [134788] = 'Interface/Icons/INV_Potion_160',
        [134789] = 'Interface/Icons/INV_Potion_161',
        [134790] = 'Interface/Icons/INV_Potion_162',
        [134791] = 'Interface/Icons/INV_Potion_163',
        [134792] = 'Interface/Icons/INV_Potion_164',
        [134793] = 'Interface/Icons/INV_Potion_165',
        [134794] = 'Interface/Icons/INV_Potion_166',
        [134795] = 'Interface/Icons/INV_Potion_167',
        [134796] = 'Interface/Icons/INV_Potion_168',
        [134797] = 'Interface/Icons/INV_Potion_17',
        [134798] = 'Interface/Icons/INV_Potion_18',
        [134799] = 'Interface/Icons/INV_Potion_19',
        [134800] = 'Interface/Icons/INV_Potion_20',
        [134801] = 'Interface/Icons/INV_Potion_21',
        [134802] = 'Interface/Icons/INV_Potion_22',
        [134803] = 'Interface/Icons/INV_Potion_23',
        [134804] = 'Interface/Icons/INV_Potion_24',
        [134805] = 'Interface/Icons/INV_Potion_25',
        [134806] = 'Interface/Icons/INV_Potion_26',
        [134807] = 'Interface/Icons/INV_Potion_27',
        [134808] = 'Interface/Icons/INV_Potion_28',
        [134809] = 'Interface/Icons/INV_Potion_29',
        [134810] = 'Interface/Icons/INV_Potion_30',
        [134811] = 'Interface/Icons/INV_Potion_31',
        [134812] = 'Interface/Icons/INV_Potion_32',
        [134813] = 'Interface/Icons/INV_Potion_33',
        [134814] = 'Interface/Icons/INV_Potion_34',
        [134815] = 'Interface/Icons/INV_Potion_35',
        [134816] = 'Interface/Icons/INV_Potion_36',
        [134817] = 'Interface/Icons/INV_Potion_37',
        [134818] = 'Interface/Icons/INV_Potion_38',
        [134819] = 'Interface/Icons/INV_Potion_39',
        [134820] = 'Interface/Icons/INV_Potion_40',
        [134821] = 'Interface/Icons/INV_Potion_41',
        [134822] = 'Interface/Icons/INV_Potion_42',
        [134823] = 'Interface/Icons/INV_Potion_43',
        [134824] = 'Interface/Icons/INV_Potion_44',
        [134825] = 'Interface/Icons/INV_Potion_45',
        [134826] = 'Interface/Icons/INV_Potion_46',
        [134827] = 'Interface/Icons/INV_Potion_47',
        [134828] = 'Interface/Icons/INV_Potion_48',
        [134829] = 'Interface/Icons/INV_Potion_49',
        [134830] = 'Interface/Icons/INV_Potion_50',
        [134831] = 'Interface/Icons/INV_Potion_51',
        [134832] = 'Interface/Icons/INV_Potion_52',
        [134833] = 'Interface/Icons/INV_Potion_53',
        [134834] = 'Interface/Icons/INV_Potion_54',
        [134835] = 'Interface/Icons/INV_Potion_55',
        [134836] = 'Interface/Icons/INV_Potion_56',
        [134837] = 'Interface/Icons/INV_Potion_57',
        [134838] = 'Interface/Icons/INV_Potion_58',
        [134839] = 'Interface/Icons/INV_Potion_59',
        [134840] = 'Interface/Icons/INV_Potion_60',
        [134841] = 'Interface/Icons/INV_Potion_61',
        [134842] = 'Interface/Icons/INV_Potion_62',
        [134843] = 'Interface/Icons/INV_Potion_63',
        [134844] = 'Interface/Icons/INV_Potion_64',
        [134845] = 'Interface/Icons/INV_Potion_65',
        [134846] = 'Interface/Icons/INV_Potion_66',
        [134847] = 'Interface/Icons/INV_Potion_67',
        [134848] = 'Interface/Icons/INV_Potion_68',
        [134849] = 'Interface/Icons/INV_Potion_69',
        [134850] = 'Interface/Icons/INV_Potion_70',
        [134851] = 'Interface/Icons/INV_Potion_71',
        [134852] = 'Interface/Icons/INV_Potion_72',
        [134853] = 'Interface/Icons/INV_Potion_73',
        [134854] = 'Interface/Icons/INV_Potion_74',
        [134855] = 'Interface/Icons/INV_Potion_75',
        [134856] = 'Interface/Icons/INV_Potion_76',
        [134857] = 'Interface/Icons/INV_Potion_77',
        [134858] = 'Interface/Icons/INV_Potion_78',
        [134859] = 'Interface/Icons/INV_Potion_79',
        [134860] = 'Interface/Icons/INV_Potion_80',
        [134861] = 'Interface/Icons/INV_Potion_81',
        [134862] = 'Interface/Icons/INV_Potion_82',
        [134863] = 'Interface/Icons/INV_Potion_83',
        [134864] = 'Interface/Icons/INV_Potion_84',
        [134865] = 'Interface/Icons/INV_Potion_85',
        [134866] = 'Interface/Icons/INV_Potion_86',
        [134867] = 'Interface/Icons/INV_Potion_87',
        [134868] = 'Interface/Icons/INV_Potion_88',
        [134869] = 'Interface/Icons/INV_Potion_89',
        [134870] = 'Interface/Icons/INV_Potion_90',
        [134871] = 'Interface/Icons/INV_Potion_91',
        [134872] = 'Interface/Icons/INV_Potion_92',
        [134873] = 'Interface/Icons/INV_Potion_93',
        [134874] = 'Interface/Icons/INV_Potion_94',
        [134875] = 'Interface/Icons/INV_Potion_95',
        [134876] = 'Interface/Icons/INV_Potion_96',
        [134877] = 'Interface/Icons/INV_Potion_97',
        [134878] = 'Interface/Icons/INV_Potion_98',
        [134879] = 'Interface/Icons/INV_Potion_99'
    },
    Qiraj = {
        [134880] = 'Interface/Icons/INV_Qiraj_BindingsCommand',
        [134881] = 'Interface/Icons/INV_Qiraj_BindingsDominance',
        [134882] = 'Interface/Icons/INV_Qiraj_CarapaceOldGod',
        [134883] = 'Interface/Icons/INV_Qiraj_DrapeMartial',
        [134884] = 'Interface/Icons/INV_Qiraj_DrapeRegal',
        [134885] = 'Interface/Icons/INV_Qiraj_HiltOrnate',
        [134886] = 'Interface/Icons/INV_Qiraj_HiltSpiked',
        [134887] = 'Interface/Icons/INV_Qiraj_HuskOldGod',
        [134888] = 'Interface/Icons/INV_Qiraj_JewelBlessed',
        [134889] = 'Interface/Icons/INV_Qiraj_JewelEncased',
        [134890] = 'Interface/Icons/INV_Qiraj_JewelEngraved',
        [134891] = 'Interface/Icons/INV_Qiraj_JewelGlyphed',
        [134892] = 'Interface/Icons/INV_Qiraj_OuroHide',
        [134893] = 'Interface/Icons/INV_Qiraj_RingCeremonial',
        [134894] = 'Interface/Icons/INV_Qiraj_RingMagisterial',
        [134895] = 'Interface/Icons/INV_Qiraj_SkinSandworm',
        [134896] = 'Interface/Icons/INV_QirajIdol_Alabaster',
        [134897] = 'Interface/Icons/INV_QirajIdol_Amber',
        [134898] = 'Interface/Icons/INV_QirajIdol_Azure',
        [134899] = 'Interface/Icons/INV_QirajIdol_Death',
        [134900] = 'Interface/Icons/INV_QirajIdol_Jasper',
        [134901] = 'Interface/Icons/INV_QirajIdol_Lambent',
        [134902] = 'Interface/Icons/INV_QirajIdol_Life',
        [134903] = 'Interface/Icons/INV_QirajIdol_Night',
        [134904] = 'Interface/Icons/INV_QirajIdol_Obsidian',
        [134905] = 'Interface/Icons/INV_QirajIdol_Onyx',
        [134906] = 'Interface/Icons/INV_QirajIdol_Rebirth',
        [134907] = 'Interface/Icons/INV_QirajIdol_Sage',
        [134908] = 'Interface/Icons/INV_QirajIdol_Strife',
        [134909] = 'Interface/Icons/INV_QirajIdol_Sun',
        [134910] = 'Interface/Icons/INV_QirajIdol_Vermillion',
        [134911] = 'Interface/Icons/INV_QirajIdol_War'
    },
    Relics = {
        [134912] = 'Interface/Icons/INV_Relics_IdolofFerocity',
        [134913] = 'Interface/Icons/INV_Relics_IdolofHealth',
        [134914] = 'Interface/Icons/INV_Relics_IdolofRejuvenation',
        [134915] = 'Interface/Icons/INV_Relics_LibramofGrace',
        [134916] = 'Interface/Icons/INV_Relics_LibramofHope',
        [134917] = 'Interface/Icons/INV_Relics_LibramofTruth',
        [134918] = 'Interface/Icons/INV_Relics_TotemofLife',
        [134919] = 'Interface/Icons/INV_Relics_TotemofRage',
        [134920] = 'Interface/Icons/INV_Relics_TotemofRebirth'
    },
    Rod = {
        [134921] = 'Interface/Icons/INV_Rod_Adamantite',
        [134925] = 'Interface/Icons/INV_Rod_Eternium',
        [134926] = 'Interface/Icons/INV_Rod_Felsteel'
    },
    Rose = {
        [134927] = 'Interface/Icons/INV_RoseBouquet01',
        [134928] = 'Interface/Icons/INV_RosePotted01'
    },
    Scarab = {
        [134929] = 'Interface/Icons/INV_Scarab_Bone',
        [134930] = 'Interface/Icons/INV_Scarab_Bronze',
        [134931] = 'Interface/Icons/INV_Scarab_Clay',
        [134932] = 'Interface/Icons/INV_Scarab_Crystal',
        [134933] = 'Interface/Icons/INV_Scarab_Gold',
        [134935] = 'Interface/Icons/INV_Scarab_Silver',
        [134936] = 'Interface/Icons/INV_Scarab_Stone'
    },
    Scroll = {
        [134937] = 'Interface/Icons/INV_Scroll_01',
        [134938] = 'Interface/Icons/INV_Scroll_02',
        [134939] = 'Interface/Icons/INV_Scroll_03',
        [134940] = 'Interface/Icons/INV_Scroll_04',
        [134941] = 'Interface/Icons/INV_Scroll_05',
        [134942] = 'Interface/Icons/INV_Scroll_06',
        [134943] = 'Interface/Icons/INV_Scroll_07',
        [134944] = 'Interface/Icons/INV_Scroll_08',
        [134945] = 'Interface/Icons/INV_Scroll_09',
        [134946] = 'Interface/Icons/INV_Scroll_10'
    },
    Shield = {
        [134947] = 'Interface/Icons/INV_Shield_01',
        [134948] = 'Interface/Icons/INV_Shield_02',
        [134949] = 'Interface/Icons/INV_Shield_03',
        [134950] = 'Interface/Icons/INV_Shield_04',
        [134951] = 'Interface/Icons/INV_Shield_05',
        [134952] = 'Interface/Icons/INV_Shield_06',
        [134953] = 'Interface/Icons/INV_Shield_07',
        [134954] = 'Interface/Icons/INV_Shield_08',
        [134955] = 'Interface/Icons/INV_Shield_09',
        [134956] = 'Interface/Icons/INV_Shield_10',
        [134957] = 'Interface/Icons/INV_Shield_11',
        [134958] = 'Interface/Icons/INV_Shield_12',
        [134959] = 'Interface/Icons/INV_Shield_13',
        [134960] = 'Interface/Icons/INV_Shield_14',
        [134961] = 'Interface/Icons/INV_Shield_15',
        [134962] = 'Interface/Icons/INV_Shield_16',
        [134963] = 'Interface/Icons/INV_Shield_17',
        [134964] = 'Interface/Icons/INV_SHIELD_18',
        [134965] = 'Interface/Icons/INV_Shield_19',
        [134966] = 'Interface/Icons/INV_Shield_20',
        [134967] = 'Interface/Icons/INV_Shield_21',
        [134968] = 'Interface/Icons/INV_Shield_22',
        [134969] = 'Interface/Icons/INV_Shield_23',
        [134970] = 'Interface/Icons/INV_Shield_24',
        [134971] = 'Interface/Icons/INV_Shield_26',
        [134972] = 'Interface/Icons/INV_Shield_27',
        [134973] = 'Interface/Icons/INV_Shield_28',
        [134974] = 'Interface/Icons/INV_Shield_29',
        [134975] = 'Interface/Icons/INV_Shield_30',
        [134976] = 'Interface/Icons/INV_Shield_31',
        [134977] = 'Interface/Icons/INV_Shield_32',
        [134978] = 'Interface/Icons/INV_Shield_33',
        [134979] = 'Interface/Icons/INV_Shield_34',
        [134980] = 'Interface/Icons/INV_Shield_35',
        [134981] = 'Interface/Icons/INV_Shield_36',
        [134982] = 'Interface/Icons/INV_Shield_37',
        [134983] = 'Interface/Icons/INV_Shield_38',
        [134984] = 'Interface/Icons/INV_Shield_39',
        [134985] = 'Interface/Icons/INV_Shield_40',
        [134986] = 'Interface/Icons/INV_Shield_41',
        [134987] = 'Interface/Icons/INV_Shield_42',
        [134988] = 'Interface/Icons/INV_Shield_43',
        [134993] = 'Interface/Icons/INV_Shield_48',
        [134997] = 'Interface/Icons/INV_Shield_52',
        [134998] = 'Interface/Icons/INV_Shield_53',
        [134999] = 'Interface/Icons/INV_Shield_54'
    },
    Shirt = {
        [135005] = 'Interface/Icons/INV_Shirt_01',
        [135006] = 'Interface/Icons/INV_Shirt_02',
        [135007] = 'Interface/Icons/INV_Shirt_03',
        [135008] = 'Interface/Icons/INV_Shirt_04',
        [135009] = 'Interface/Icons/INV_Shirt_05',
        [135010] = 'Interface/Icons/INV_Shirt_06',
        [135011] = 'Interface/Icons/INV_Shirt_07',
        [135012] = 'Interface/Icons/INV_Shirt_08',
        [135013] = 'Interface/Icons/INV_Shirt_09',
        [135014] = 'Interface/Icons/INV_Shirt_10',
        [135015] = 'Interface/Icons/INV_Shirt_11',
        [135016] = 'Interface/Icons/INV_Shirt_12',
        [135017] = 'Interface/Icons/INV_Shirt_13',
        [135018] = 'Interface/Icons/INV_Shirt_14',
        [135019] = 'Interface/Icons/INV_Shirt_15',
        [135020] = 'Interface/Icons/INV_Shirt_16',
        [135021] = 'Interface/Icons/INV_Shirt_17',
        [135022] = 'Interface/Icons/INV_Shirt_Black_01',
        [135023] = 'Interface/Icons/INV_Shirt_Blue_01',
        [135024] = 'Interface/Icons/INV_Shirt_Green_01',
        [135025] = 'Interface/Icons/INV_Shirt_Grey_01',
        [135026] = 'Interface/Icons/INV_Shirt_GuildTabard_01',
        [135027] = 'Interface/Icons/INV_Shirt_Orange_01',
        [135028] = 'Interface/Icons/INV_Shirt_Purple_01',
        [135029] = 'Interface/Icons/INV_Shirt_Red_01',
        [135030] = 'Interface/Icons/INV_Shirt_White_01',
        [135031] = 'Interface/Icons/INV_Shirt_Yellow_01'
    },
    Shoulder = {
        [135032] = 'Interface/Icons/INV_Shoulder_01',
        [135033] = 'Interface/Icons/INV_Shoulder_02',
        [135034] = 'Interface/Icons/INV_Shoulder_03',
        [135035] = 'Interface/Icons/INV_Shoulder_04',
        [135036] = 'Interface/Icons/INV_Shoulder_05',
        [135037] = 'Interface/Icons/INV_Shoulder_06',
        [135038] = 'Interface/Icons/INV_Shoulder_07',
        [135039] = 'Interface/Icons/INV_Shoulder_08',
        [135040] = 'Interface/Icons/INV_Shoulder_09',
        [135041] = 'Interface/Icons/INV_Shoulder_10',
        [135042] = 'Interface/Icons/INV_Shoulder_11',
        [135043] = 'Interface/Icons/INV_Shoulder_12',
        [135044] = 'Interface/Icons/INV_Shoulder_13',
        [135045] = 'Interface/Icons/INV_Shoulder_14',
        [135046] = 'Interface/Icons/INV_Shoulder_15',
        [135047] = 'Interface/Icons/INV_Shoulder_16',
        [135048] = 'Interface/Icons/INV_Shoulder_17',
        [135049] = 'Interface/Icons/INV_Shoulder_18',
        [135050] = 'Interface/Icons/INV_Shoulder_19',
        [135051] = 'Interface/Icons/INV_Shoulder_20',
        [135052] = 'Interface/Icons/INV_Shoulder_21',
        [135053] = 'Interface/Icons/INV_Shoulder_22',
        [135054] = 'Interface/Icons/INV_Shoulder_23',
        [135055] = 'Interface/Icons/INV_Shoulder_24',
        [135056] = 'Interface/Icons/INV_Shoulder_25',
        [135057] = 'Interface/Icons/INV_Shoulder_26',
        [135058] = 'Interface/Icons/INV_Shoulder_27',
        [135059] = 'Interface/Icons/INV_Shoulder_28',
        [135060] = 'Interface/Icons/INV_Shoulder_29',
        [135061] = 'Interface/Icons/INV_Shoulder_30',
        [135062] = 'Interface/Icons/INV_Shoulder_31',
        [135063] = 'Interface/Icons/INV_Shoulder_32',
        [135064] = 'Interface/Icons/INV_Shoulder_33',
        [135065] = 'Interface/Icons/INV_Shoulder_34',
        [135066] = 'Interface/Icons/INV_Shoulder_35',
        [135067] = 'Interface/Icons/INV_Shoulder_36',
        [135068] = 'Interface/Icons/INV_Shoulder_37',
        [135069] = 'Interface/Icons/INV_Shoulder_40',
        [135070] = 'Interface/Icons/INV_Shoulder_41',
        [135071] = 'Interface/Icons/INV_Shoulder_44',
        [135072] = 'Interface/Icons/INV_Shoulder_47',
        [135073] = 'Interface/Icons/INV_Shoulder_48',
        [135074] = 'Interface/Icons/INV_Shoulder_49',
        [135075] = 'Interface/Icons/INV_Shoulder_50',
        [135076] = 'Interface/Icons/INV_Shoulder_51',
        [135077] = 'Interface/Icons/INV_Shoulder_52',
        [135078] = 'Interface/Icons/INV_Shoulder_53',
        [135079] = 'Interface/Icons/INV_Shoulder_54',
        [135080] = 'Interface/Icons/INV_Shoulder_55',
        [135081] = 'Interface/Icons/INV_Shoulder_56',
        [135082] = 'Interface/Icons/INV_Shoulder_57',
        [135083] = 'Interface/Icons/INV_SHOULDER_58',
        [135084] = 'Interface/Icons/INV_SHOULDER_59',
        [135085] = 'Interface/Icons/INV_SHOULDER_60',
        [135086] = 'Interface/Icons/INV_SHOULDER_61',
        [135087] = 'Interface/Icons/INV_SHOULDER_62',
        [135088] = 'Interface/Icons/INV_Shoulder_63',
        [135089] = 'Interface/Icons/INV_Shoulder_64',
        [135090] = 'Interface/Icons/INV_Shoulder_65',
        [135091] = 'Interface/Icons/INV_Shoulder_66',
        [135092] = 'Interface/Icons/INV_SHOULDER_67',
        [135093] = 'Interface/Icons/INV_SHOULDER_68',
        [135106] = 'Interface/Icons/INV_Shoulder_81',
        [135107] = 'Interface/Icons/INV_Shoulder_82',
        [135108] = 'Interface/Icons/INV_Shoulder_83',
        [135109] = 'Interface/Icons/INV_Shoulder_84',
        [135110] = 'Interface/Icons/INV_Shoulder_85',
        [135111] = 'Interface/Icons/INV_Shoulder_86',
        [135113] = 'Interface/Icons/INV_Shoulder_88',
        [135114] = 'Interface/Icons/INV_SHOULDER_89',
        [135115] = 'Interface/Icons/INV_Shoulder_90',
        [135116] = 'Interface/Icons/INV_Shoulder_91',
        [135121] = 'Interface/Icons/INV_SHOULDER_96',
        [135123] = 'Interface/Icons/INV_Shoulder_HaremMatron_D_01'
    },
    Spear = {
        [135124] = 'Interface/Icons/INV_Spear_01',
        [135125] = 'Interface/Icons/INV_Spear_02',
        [135126] = 'Interface/Icons/INV_Spear_03',
        [135127] = 'Interface/Icons/INV_Spear_04',
        [135128] = 'Interface/Icons/INV_Spear_05',
        [135129] = 'Interface/Icons/INV_Spear_06',
        [135130] = 'Interface/Icons/INV_Spear_07',
        [135131] = 'Interface/Icons/INV_Spear_08',
        [135132] = 'Interface/Icons/INV_Spear_09',
        [135133] = 'Interface/Icons/INV_Spear_10',
        [135134] = 'Interface/Icons/INV_Spear_11'
    },
    Staff = {
        [135138] = 'Interface/Icons/INV_Staff_01',
        [135139] = 'Interface/Icons/INV_Staff_02',
        [135140] = 'Interface/Icons/INV_Staff_03',
        [135141] = 'Interface/Icons/INV_Staff_04',
        [135142] = 'Interface/Icons/INV_Staff_05',
        [135143] = 'Interface/Icons/INV_Staff_06',
        [135144] = 'Interface/Icons/INV_Staff_07',
        [135145] = 'Interface/Icons/INV_Staff_08',
        [135146] = 'Interface/Icons/INV_Staff_09',
        [135147] = 'Interface/Icons/INV_Staff_10',
        [135148] = 'Interface/Icons/INV_Staff_11',
        [135149] = 'Interface/Icons/INV_Staff_12',
        [135150] = 'Interface/Icons/INV_Staff_13',
        [135151] = 'Interface/Icons/INV_Staff_14',
        [135152] = 'Interface/Icons/INV_Staff_15',
        [135153] = 'Interface/Icons/INV_Staff_16',
        [135154] = 'Interface/Icons/INV_Staff_17',
        [135155] = 'Interface/Icons/INV_Staff_18',
        [135156] = 'Interface/Icons/INV_Staff_19',
        [135157] = 'Interface/Icons/INV_Staff_20',
        [135158] = 'Interface/Icons/INV_Staff_21',
        [135159] = 'Interface/Icons/INV_Staff_22',
        [135160] = 'Interface/Icons/INV_Staff_23',
        [135161] = 'Interface/Icons/INV_Staff_24',
        [135162] = 'Interface/Icons/INV_Staff_25',
        [135163] = 'Interface/Icons/INV_Staff_26',
        [135164] = 'Interface/Icons/INV_Staff_27',
        [135165] = 'Interface/Icons/INV_Staff_28',
        [135166] = 'Interface/Icons/INV_Staff_29',
        [135167] = 'Interface/Icons/INV_Staff_30',
        [135168] = 'Interface/Icons/INV_Staff_31',
        [135169] = 'Interface/Icons/INV_Staff_32',
        [135170] = 'Interface/Icons/INV_Staff_33',
        [135171] = 'Interface/Icons/INV_Staff_34',
        [135172] = 'Interface/Icons/INV_Staff_35',
        [135173] = 'Interface/Icons/INV_Staff_36',
        [135174] = 'Interface/Icons/INV_Staff_37',
        [135175] = 'Interface/Icons/INV_Staff_38',
        [135176] = 'Interface/Icons/INV_Staff_39',
        [135177] = 'Interface/Icons/INV_Staff_40',
        [135178] = 'Interface/Icons/INV_Staff_41',
        [135179] = 'Interface/Icons/INV_Staff_42',
        [135180] = 'Interface/Icons/INV_Staff_43',
        [135181] = 'Interface/Icons/INV_Staff_45',
        [135182] = 'Interface/Icons/INV_Staff_46',
        [135183] = 'Interface/Icons/INV_Staff_47',
        [135184] = 'Interface/Icons/INV_Staff_48',
        [135185] = 'Interface/Icons/INV_Staff_49',
        [135186] = 'Interface/Icons/INV_Staff_50',
        [135187] = 'Interface/Icons/INV_Staff_51',
        [135188] = 'Interface/Icons/INV_Staff_52',
        [135189] = 'Interface/Icons/INV_Staff_53',
        [135190] = 'Interface/Icons/INV_Staff_54',
        [135191] = 'Interface/Icons/INV_Staff_55',
        [135192] = 'Interface/Icons/INV_Staff_56',
        [135193] = 'Interface/Icons/INV_Staff_57',
        [135194] = 'Interface/Icons/INV_Staff_58',
        [135195] = 'Interface/Icons/INV_Staff_59',
        [135196] = 'Interface/Icons/INV_Staff_60',
        [135197] = 'Interface/Icons/INV_Staff_61',
        [135198] = 'Interface/Icons/INV_Staff_63',
        [135199] = 'Interface/Icons/INV_Staff_64',
        [135200] = 'Interface/Icons/INV_Staff_65',
        [135208] = 'Interface/Icons/INV_Staff_73',
        [135209] = 'Interface/Icons/INV_Staff_74',
        [135213] = 'Interface/Icons/INV_Staff_78',
        [135214] = 'Interface/Icons/INV_Staff_79',
        [135222] = 'Interface/Icons/INV_Staff_Draenei_A_01',
        [135223] = 'Interface/Icons/INV_Staff_Draenei_A_02',
        [135224] = 'Interface/Icons/INV_Staff_Draenei_A_03',
        [135225] = 'Interface/Icons/INV_Staff_Goldfeathered_01',
        [135226] = 'Interface/Icons/INV_Staff_Medivh'
    },
    Stone = {
        [135227] = 'Interface/Icons/INV_Stone_01',
        [135228] = 'Interface/Icons/INV_Stone_02',
        [135229] = 'Interface/Icons/INV_Stone_03',
        [135230] = 'Interface/Icons/INV_Stone_04',
        [135231] = 'Interface/Icons/INV_Stone_05',
        [135232] = 'Interface/Icons/INV_Stone_06',
        [135233] = 'Interface/Icons/INV_Stone_07',
        [135234] = 'Interface/Icons/INV_Stone_08',
        [135235] = 'Interface/Icons/INV_Stone_09',
        [135236] = 'Interface/Icons/INV_Stone_10',
        [135237] = 'Interface/Icons/INV_Stone_11',
        [135238] = 'Interface/Icons/INV_Stone_12',
        [135239] = 'Interface/Icons/INV_Stone_13',
        [135240] = 'Interface/Icons/INV_Stone_14',
        [135241] = 'Interface/Icons/INV_Stone_15',
        [135242] = 'Interface/Icons/INV_Stone_16',
        [135243] = 'Interface/Icons/INV_Stone_GrindingStone_01',
        [135244] = 'Interface/Icons/INV_Stone_GrindingStone_02',
        [135245] = 'Interface/Icons/INV_Stone_GrindingStone_03',
        [135246] = 'Interface/Icons/INV_Stone_GrindingStone_04',
        [135247] = 'Interface/Icons/INV_Stone_GrindingStone_05',
        [135248] = 'Interface/Icons/INV_Stone_SharpeningStone_01',
        [135249] = 'Interface/Icons/INV_Stone_SharpeningStone_02',
        [135250] = 'Interface/Icons/INV_Stone_SharpeningStone_03',
        [135251] = 'Interface/Icons/INV_Stone_SharpeningStone_04',
        [135252] = 'Interface/Icons/INV_Stone_SharpeningStone_05',
        [135253] = 'Interface/Icons/INV_Stone_SharpeningStone_06',
        [135254] = 'Interface/Icons/INV_Stone_SharpeningStone_07',
        [135255] = 'Interface/Icons/INV_Stone_WeightStone_01',
        [135256] = 'Interface/Icons/INV_Stone_WeightStone_02',
        [135257] = 'Interface/Icons/INV_Stone_WeightStone_03',
        [135258] = 'Interface/Icons/INV_Stone_WeightStone_04',
        [135259] = 'Interface/Icons/INV_Stone_WeightStone_05',
        [135260] = 'Interface/Icons/INV_Stone_WeightStone_06',
        [135261] = 'Interface/Icons/INV_Stone_WeightStone_07'
    },
    SummerFest = {
        [135262] = 'Interface/Icons/INV_SummerFest_FireDrink',
        [135263] = 'Interface/Icons/INV_SummerFest_FireFlower',
        [135264] = 'Interface/Icons/INV_SummerFest_FirePotion',
        [135265] = 'Interface/Icons/INV_SummerFest_FireSpirit',
        [135266] = 'Interface/Icons/INV_SummerFest_GroundFlower',
        [135267] = 'Interface/Icons/INV_SummerFest_Smorc',
        [135268] = 'Interface/Icons/INV_SummerFest_Symbol_High',
        [135269] = 'Interface/Icons/INV_SummerFest_Symbol_Low',
        [135270] = 'Interface/Icons/INV_SummerFest_Symbol_Medium'
    },
    Sword = {
        [135271] = 'Interface/Icons/INV_Sword_01',
        [135272] = 'Interface/Icons/INV_Sword_02',
        [135273] = 'Interface/Icons/INV_Sword_03',
        [135274] = 'Interface/Icons/INV_Sword_04',
        [135275] = 'Interface/Icons/INV_Sword_05',
        [135276] = 'Interface/Icons/INV_Sword_06',
        [135277] = 'Interface/Icons/INV_Sword_07',
        [135278] = 'Interface/Icons/INV_Sword_08',
        [135279] = 'Interface/Icons/INV_Sword_09',
        [135280] = 'Interface/Icons/INV_Sword_10',
        [135288] = 'Interface/Icons/INV_SWORD_107',
        [135289] = 'Interface/Icons/INV_Sword_108',
        [135290] = 'Interface/Icons/INV_Sword_109',
        [135291] = 'Interface/Icons/INV_Sword_11',
        [135296] = 'Interface/Icons/INV_Sword_114',
        [135297] = 'Interface/Icons/INV_SWORD_115',
        [135298] = 'Interface/Icons/INV_Sword_116',
        [135300] = 'Interface/Icons/INV_Sword_118',
        [135302] = 'Interface/Icons/INV_Sword_12',
        [135311] = 'Interface/Icons/INV_Sword_13',
        [135312] = 'Interface/Icons/INV_Sword_14',
        [135313] = 'Interface/Icons/INV_Sword_15',
        [135314] = 'Interface/Icons/INV_Sword_16',
        [135315] = 'Interface/Icons/INV_Sword_17',
        [135316] = 'Interface/Icons/INV_Sword_18',
        [135317] = 'Interface/Icons/INV_Sword_19',
        [135321] = 'Interface/Icons/INV_Sword_20',
        [135322] = 'Interface/Icons/INV_Sword_21',
        [135323] = 'Interface/Icons/INV_Sword_22',
        [135324] = 'Interface/Icons/INV_Sword_23',
        [135325] = 'Interface/Icons/INV_Sword_24',
        [135326] = 'Interface/Icons/INV_Sword_25',
        [135327] = 'Interface/Icons/INV_Sword_26',
        [135328] = 'Interface/Icons/INV_Sword_27',
        [135329] = 'Interface/Icons/INV_Sword_28',
        [135330] = 'Interface/Icons/INV_Sword_29',
        [135340] = 'Interface/Icons/INV_Sword_30',
        [135341] = 'Interface/Icons/INV_Sword_31',
        [135342] = 'Interface/Icons/INV_Sword_32',
        [135343] = 'Interface/Icons/INV_Sword_33',
        [135344] = 'Interface/Icons/INV_Sword_34',
        [135345] = 'Interface/Icons/INV_Sword_35',
        [135346] = 'Interface/Icons/INV_Sword_36',
        [135347] = 'Interface/Icons/INV_Sword_37',
        [135348] = 'Interface/Icons/INV_Sword_38',
        [135349] = 'Interface/Icons/INV_Sword_39',
        [135350] = 'Interface/Icons/INV_Sword_40',
        [135351] = 'Interface/Icons/INV_Sword_41',
        [135352] = 'Interface/Icons/INV_Sword_42',
        [135353] = 'Interface/Icons/INV_Sword_43',
        [135354] = 'Interface/Icons/INV_Sword_44',
        [135355] = 'Interface/Icons/INV_Sword_45',
        [135356] = 'Interface/Icons/INV_Sword_46',
        [135357] = 'Interface/Icons/INV_Sword_47',
        [135358] = 'Interface/Icons/INV_Sword_48',
        [135359] = 'Interface/Icons/INV_Sword_49',
        [135360] = 'Interface/Icons/INV_Sword_50',
        [135361] = 'Interface/Icons/INV_Sword_51',
        [135362] = 'Interface/Icons/INV_SWORD_52',
        [135363] = 'Interface/Icons/INV_Sword_53',
        [135364] = 'Interface/Icons/INV_Sword_54',
        [135365] = 'Interface/Icons/INV_Sword_55',
        [135366] = 'Interface/Icons/INV_Sword_56',
        [135367] = 'Interface/Icons/INV_Sword_57',
        [135368] = 'Interface/Icons/INV_Sword_58',
        [135369] = 'Interface/Icons/INV_Sword_59',
        [135370] = 'Interface/Icons/INV_Sword_60',
        [135371] = 'Interface/Icons/INV_Sword_61',
        [135372] = 'Interface/Icons/INV_Sword_62',
        [135373] = 'Interface/Icons/INV_Sword_63',
        [135374] = 'Interface/Icons/INV_Sword_64',
        [135375] = 'Interface/Icons/INV_Sword_65',
        [135376] = 'Interface/Icons/INV_Sword_66',
        [135377] = 'Interface/Icons/INV_Sword_67',
        [135378] = 'Interface/Icons/INV_Sword_68',
        [135379] = 'Interface/Icons/INV_Sword_69',
        [135380] = 'Interface/Icons/INV_Sword_70',
        [135381] = 'Interface/Icons/INV_Sword_71',
        [135382] = 'Interface/Icons/INV_Sword_72',
        [135383] = 'Interface/Icons/INV_Sword_73',
        [135384] = 'Interface/Icons/INV_Sword_74',
        [135385] = 'Interface/Icons/INV_Sword_75',
        [135386] = 'Interface/Icons/INV_Sword_76',
        [135387] = 'Interface/Icons/INV_Sword_77',
        [135388] = 'Interface/Icons/INV_Sword_78',
        [135389] = 'Interface/Icons/INV_Sword_79',
        [135390] = 'Interface/Icons/INV_Sword_80',
        [135391] = 'Interface/Icons/INV_Sword_81',
        [135392] = 'Interface/Icons/INV_Sword_82',
        [135393] = 'Interface/Icons/INV_Sword_83',
        [135394] = 'Interface/Icons/INV_Sword_84',
        [135395] = 'Interface/Icons/INV_Sword_85',
        [135396] = 'Interface/Icons/INV_Sword_86',
        [135397] = 'Interface/Icons/INV_Sword_87',
        [135398] = 'Interface/Icons/INV_SWORD_88',
        [135399] = 'Interface/Icons/INV_Sword_89',
        [135400] = 'Interface/Icons/INV_Sword_90',
        [135401] = 'Interface/Icons/INV_Sword_91',
        [135402] = 'Interface/Icons/INV_Sword_92',
        [135403] = 'Interface/Icons/INV_Sword_93',
        [135404] = 'Interface/Icons/INV_Sword_94',
        [135410] = 'Interface/Icons/INV_Sword_BloodElf_03',
        [135411] = 'Interface/Icons/INV_Sword_Draenei_01',
        [135412] = 'Interface/Icons/INV_Sword_Draenei_02',
        [135413] = 'Interface/Icons/INV_Sword_draenei_03',
        [135414] = 'Interface/Icons/INV_Sword_draenei_04',
        [135415] = 'Interface/Icons/INV_Sword_Draenei_05',
        [135416] = 'Interface/Icons/INV_Sword_Draenei_06',
        [135417] = 'Interface/Icons/INV_Sword_Draenei_07',
        [135418] = 'Interface/Icons/INV_Sword_Draenei_08'
    },
    ThrowingAxe = {
        [135419] = 'Interface/Icons/INV_ThrowingAxe_01',
        [135420] = 'Interface/Icons/INV_ThrowingAxe_02',
        [135421] = 'Interface/Icons/INV_ThrowingAxe_03',
        [135422] = 'Interface/Icons/INV_ThrowingAxe_04',
        [135423] = 'Interface/Icons/INV_ThrowingAxe_05',
        [135424] = 'Interface/Icons/INV_ThrowingAxe_06'
    },
    ThrowingKnife = {
        [135425] = 'Interface/Icons/INV_ThrowingKnife_01',
        [135426] = 'Interface/Icons/INV_ThrowingKnife_02',
        [135427] = 'Interface/Icons/INV_ThrowingKnife_03',
        [135428] = 'Interface/Icons/INV_ThrowingKnife_04',
        [135429] = 'Interface/Icons/INV_ThrowingKnife_05',
        [135430] = 'Interface/Icons/INV_ThrowingKnife_06',
        [135431] = 'Interface/Icons/INV_ThrowingKnife_07'
    },
    Torch = {
        [135432] = 'Interface/Icons/INV_Torch_Lit',
        [135433] = 'Interface/Icons/INV_Torch_Thrown',
        [135434] = 'Interface/Icons/INV_Torch_Unlit'
    },
    TradeskillItem = {
        [135435] = 'Interface/Icons/INV_TradeskillItem_01',
        [135436] = 'Interface/Icons/INV_TradeskillItem_02',
        [135437] = 'Interface/Icons/INV_TradeskillItem_03'
    },
    Trinket = {
        [135438] = 'Interface/Icons/INV_Trinket_HonorHold',
        [135439] = 'Interface/Icons/INV_Trinket_Naxxramas01',
        [135440] = 'Interface/Icons/INV_Trinket_Naxxramas02',
        [135441] = 'Interface/Icons/INV_Trinket_Naxxramas03',
        [135442] = 'Interface/Icons/INV_Trinket_Naxxramas04',
        [135443] = 'Interface/Icons/INV_Trinket_Naxxramas05',
        [135444] = 'Interface/Icons/INV_Trinket_Naxxramas06',
        [135445] = 'Interface/Icons/INV_Trinket_Thrallmar'
    },
    Valentine = {
        [135446] = 'Interface/Icons/INV_ValentineCologneBottle',
        [135447] = 'Interface/Icons/INV_ValentinePerfumeBottle',
        [135448] = 'Interface/Icons/INV_ValentinePinkRocket',
        [135449] = 'Interface/Icons/INV_ValentinesBoxOfChocolates01',
        [135450] = 'Interface/Icons/INV_ValentinesBoxOfChocolates02',
        [135451] = 'Interface/Icons/INV_ValentinesCandy',
        [135452] = 'Interface/Icons/INV_ValentinesCandySack',
        [135453] = 'Interface/Icons/INV_ValentinesCard01',
        [135454] = 'Interface/Icons/INV_ValentinesCard02',
        [135455] = 'Interface/Icons/INV_ValentinesCardTornLeft',
        [135456] = 'Interface/Icons/INV_ValentinesCardTornRight',
        [135457] = 'Interface/Icons/INV_ValentinesChocolate01',
        [135458] = 'Interface/Icons/INV_ValentinesChocolate02',
        [135459] = 'Interface/Icons/INV_ValentinesChocolate03',
        [135460] = 'Interface/Icons/INV_ValentinesChocolate04'
    },
    Wand = {
        [135463] = 'Interface/Icons/INV_Wand_01',
        [135464] = 'Interface/Icons/INV_Wand_02',
        [135465] = 'Interface/Icons/INV_Wand_03',
        [135466] = 'Interface/Icons/INV_Wand_04',
        [135467] = 'Interface/Icons/INV_Wand_05',
        [135468] = 'Interface/Icons/INV_Wand_06',
        [135469] = 'Interface/Icons/INV_Wand_07',
        [135470] = 'Interface/Icons/INV_Wand_08',
        [135471] = 'Interface/Icons/INV_Wand_09',
        [135472] = 'Interface/Icons/INV_Wand_10',
        [135473] = 'Interface/Icons/INV_Wand_11',
        [135474] = 'Interface/Icons/INV_Wand_12',
        [135475] = 'Interface/Icons/INV_Wand_14',
        [135476] = 'Interface/Icons/INV_Wand_15',
        [135477] = 'Interface/Icons/INV_Wand_16',
        [135478] = 'Interface/Icons/INV_Wand_17',
        [135479] = 'Interface/Icons/INV_Wand_18',
        [135480] = 'Interface/Icons/INV_Wand_19',
        [135483] = 'Interface/Icons/INV_Wand_20',
        [135484] = 'Interface/Icons/INV_Wand_21',
        [135485] = 'Interface/Icons/INV_Wand_22',
        [135486] = 'Interface/Icons/INV_Wand_23',
        [135487] = 'Interface/Icons/INV_Wand_24',
        [135488] = 'Interface/Icons/INV_Wand_25'
    },
    Weapon = {
        [135530] = 'Interface/Icons/INV_Weapon_Crossbow_01',
        [135531] = 'Interface/Icons/INV_Weapon_Crossbow_02',
        [135532] = 'Interface/Icons/INV_Weapon_Crossbow_03',
        [135533] = 'Interface/Icons/INV_Weapon_Crossbow_04',
        [135534] = 'Interface/Icons/INV_Weapon_Crossbow_05',
        [135535] = 'Interface/Icons/INV_Weapon_Crossbow_06',
        [135536] = 'Interface/Icons/INV_Weapon_Crossbow_07',
        [135537] = 'Interface/Icons/INV_Weapon_Crossbow_08',
        [135538] = 'Interface/Icons/INV_Weapon_Crossbow_09',
        [135539] = 'Interface/Icons/INV_Weapon_Crossbow_10',
        [135540] = 'Interface/Icons/INV_Weapon_Crossbow_11',
        [135541] = 'Interface/Icons/INV_Weapon_Crossbow_12',
        [135542] = 'Interface/Icons/INV_Weapon_Crossbow_13',
        [135543] = 'Interface/Icons/INV_Weapon_Crossbow_14',
        [135544] = 'Interface/Icons/INV_Weapon_Crossbow_15',
        [135545] = 'Interface/Icons/INV_Weapon_Crossbow_16',
        [135546] = 'Interface/Icons/INV_Weapon_Crossbow_17',
        [135547] = 'Interface/Icons/INV_Weapon_Crossbow_18',
        [135548] = 'Interface/Icons/INV_Weapon_Crossbow_19',
        [135549] = 'Interface/Icons/INV_Weapon_Crossbow_20',
        [135554] = 'Interface/Icons/INV_Weapon_Crossbow_25',
        [135555] = 'Interface/Icons/INV_Weapon_Crossbow_26',
        [135561] = 'Interface/Icons/INV_Weapon_Glave_01',
        [135562] = 'Interface/Icons/INV_Weapon_Halbard_01',
        [135563] = 'Interface/Icons/INV_Weapon_Halberd13',
        [135564] = 'Interface/Icons/INV_Weapon_Halberd14',
        [135565] = 'Interface/Icons/INV_Weapon_Halberd15',
        [135566] = 'Interface/Icons/INV_Weapon_Halberd16',
        [135567] = 'Interface/Icons/INV_Weapon_Halberd17',
        [135568] = 'Interface/Icons/INV_Weapon_Halberd18',
        [135569] = 'Interface/Icons/INV_Weapon_Halberd19',
        [135572] = 'Interface/Icons/INV_Weapon_Halberd_02',
        [135573] = 'Interface/Icons/INV_Weapon_Halberd_03',
        [135574] = 'Interface/Icons/INV_Weapon_Halberd_04',
        [135575] = 'Interface/Icons/INV_Weapon_Halberd_05',
        [135576] = 'Interface/Icons/INV_Weapon_Halberd_06',
        [135577] = 'Interface/Icons/INV_Weapon_Halberd_07',
        [135578] = 'Interface/Icons/INV_Weapon_Halberd_08',
        [135579] = 'Interface/Icons/INV_Weapon_Halberd_09',
        [135580] = 'Interface/Icons/INV_Weapon_Halberd_10',
        [135581] = 'Interface/Icons/INV_Weapon_Halberd_11',
        [135582] = 'Interface/Icons/INV_Weapon_Halberd_12',
        [135583] = 'Interface/Icons/INV_Weapon_Halberd_20',
        [135585] = 'Interface/Icons/INV_WEAPON_HALBERD_22',
        [135591] = 'Interface/Icons/INV_Weapon_Halberd_AhnQiraj',
        [135592] = 'Interface/Icons/INV_Weapon_Hand_01',
        [135593] = 'Interface/Icons/INV_Weapon_Hand_02',
        [135594] = 'Interface/Icons/INV_Weapon_Hand_03',
        [135595] = 'Interface/Icons/INV_Weapon_Hand_04',
        [135596] = 'Interface/Icons/INV_Weapon_Hand_05',
        [135597] = 'Interface/Icons/INV_Weapon_Hand_06',
        [135598] = 'Interface/Icons/INV_Weapon_Hand_07',
        [135599] = 'Interface/Icons/INV_WEAPON_HAND_08',
        [135600] = 'Interface/Icons/INV_Weapon_Hand_09',
        [135601] = 'Interface/Icons/INV_Weapon_Hand_10',
        [135602] = 'Interface/Icons/INV_Weapon_Hand_11',
        [135603] = 'Interface/Icons/INV_Weapon_Hand_12',
        [135604] = 'Interface/Icons/INV_Weapon_Hand_13',
        [135605] = 'Interface/Icons/INV_Weapon_Hand_14',
        [135606] = 'Interface/Icons/INV_Weapon_Hand_15',
        [135607] = 'Interface/Icons/INV_Weapon_Hand_16',
        [135610] = 'Interface/Icons/INV_Weapon_Rifle_01',
        [135611] = 'Interface/Icons/INV_Weapon_Rifle_02',
        [135612] = 'Interface/Icons/INV_Weapon_Rifle_03',
        [135613] = 'Interface/Icons/INV_Weapon_Rifle_04',
        [135614] = 'Interface/Icons/INV_Weapon_Rifle_05',
        [135615] = 'Interface/Icons/INV_Weapon_Rifle_06',
        [135616] = 'Interface/Icons/INV_Weapon_Rifle_07',
        [135617] = 'Interface/Icons/INV_Weapon_Rifle_08',
        [135618] = 'Interface/Icons/INV_Weapon_Rifle_09',
        [135619] = 'Interface/Icons/INV_Weapon_Rifle_10',
        [135620] = 'Interface/Icons/INV_Weapon_Rifle_11',
        [135621] = 'Interface/Icons/INV_Weapon_Rifle_13',
        [135622] = 'Interface/Icons/INV_Weapon_Rifle_14',
        [135623] = 'Interface/Icons/INV_Weapon_Rifle_15',
        [135624] = 'Interface/Icons/INV_Weapon_Rifle_16',
        [135625] = 'Interface/Icons/INV_Weapon_Rifle_17',
        [135626] = 'Interface/Icons/INV_Weapon_Rifle_18',
        [135627] = 'Interface/Icons/INV_Weapon_Rifle_19',
        [135628] = 'Interface/Icons/INV_Weapon_Rifle_20',
        [135629] = 'Interface/Icons/INV_Weapon_Rifle_21',
        [135630] = 'Interface/Icons/INV_Weapon_Rifle_22',
        [135631] = 'Interface/Icons/INV_Weapon_Rifle_23',
        [135632] = 'Interface/Icons/INV_Weapon_Rifle_24',
        [135637] = 'Interface/Icons/INV_Weapon_ShortBlade_01',
        [135638] = 'Interface/Icons/INV_Weapon_ShortBlade_02',
        [135639] = 'Interface/Icons/INV_Weapon_ShortBlade_03',
        [135640] = 'Interface/Icons/INV_Weapon_ShortBlade_04',
        [135641] = 'Interface/Icons/INV_Weapon_ShortBlade_05',
        [135642] = 'Interface/Icons/INV_Weapon_ShortBlade_06',
        [135643] = 'Interface/Icons/INV_Weapon_ShortBlade_07',
        [135644] = 'Interface/Icons/INV_Weapon_ShortBlade_08',
        [135645] = 'Interface/Icons/INV_Weapon_ShortBlade_09',
        [135646] = 'Interface/Icons/INV_Weapon_ShortBlade_10',
        [135647] = 'Interface/Icons/INV_Weapon_ShortBlade_11',
        [135648] = 'Interface/Icons/INV_Weapon_ShortBlade_12',
        [135649] = 'Interface/Icons/INV_Weapon_ShortBlade_13',
        [135650] = 'Interface/Icons/INV_Weapon_ShortBlade_14',
        [135651] = 'Interface/Icons/INV_Weapon_ShortBlade_15',
        [135652] = 'Interface/Icons/INV_Weapon_ShortBlade_16',
        [135653] = 'Interface/Icons/INV_Weapon_ShortBlade_17',
        [135654] = 'Interface/Icons/INV_Weapon_ShortBlade_18',
        [135655] = 'Interface/Icons/INV_Weapon_ShortBlade_19',
        [135656] = 'Interface/Icons/INV_Weapon_ShortBlade_20',
        [135657] = 'Interface/Icons/INV_Weapon_ShortBlade_21',
        [135658] = 'Interface/Icons/INV_Weapon_ShortBlade_22',
        [135659] = 'Interface/Icons/INV_Weapon_ShortBlade_23',
        [135660] = 'Interface/Icons/INV_Weapon_ShortBlade_24',
        [135661] = 'Interface/Icons/INV_Weapon_ShortBlade_25',
        [135662] = 'Interface/Icons/INV_Weapon_ShortBlade_26',
        [135663] = 'Interface/Icons/INV_Weapon_ShortBlade_27',
        [135664] = 'Interface/Icons/INV_Weapon_Shortblade_28',
        [135665] = 'Interface/Icons/INV_Weapon_Shortblade_29',
        [135666] = 'Interface/Icons/INV_Weapon_Shortblade_30',
        [135667] = 'Interface/Icons/INV_Weapon_Shortblade_31',
        [135668] = 'Interface/Icons/INV_Weapon_Shortblade_32',
        [135669] = 'Interface/Icons/INV_Weapon_Shortblade_33',
        [135670] = 'Interface/Icons/INV_Weapon_Shortblade_34',
        [135671] = 'Interface/Icons/INV_Weapon_Shortblade_35',
        [135672] = 'Interface/Icons/INV_Weapon_Shortblade_37',
        [135673] = 'Interface/Icons/INV_Weapon_Shortblade_38',
        [135674] = 'Interface/Icons/INV_Weapon_Shortblade_39',
        [135675] = 'Interface/Icons/INV_Weapon_Shortblade_40',
        [135676] = 'Interface/Icons/INV_Weapon_Shortblade_41',
        [135677] = 'Interface/Icons/INV_Weapon_Shortblade_42',
        [135678] = 'Interface/Icons/INV_Weapon_Shortblade_43',
        [135679] = 'Interface/Icons/INV_Weapon_Shortblade_44',
        [135680] = 'Interface/Icons/INV_Weapon_Shortblade_45',
        [135681] = 'Interface/Icons/INV_Weapon_Shortblade_46',
        [135682] = 'Interface/Icons/INV_Weapon_Shortblade_47',
        [135683] = 'Interface/Icons/INV_Weapon_Shortblade_48',
        [135684] = 'Interface/Icons/INV_Weapon_Shortblade_49',
        [135685] = 'Interface/Icons/INV_Weapon_Shortblade_50',
        [135686] = 'Interface/Icons/INV_Weapon_Shortblade_51',
        [135687] = 'Interface/Icons/INV_Weapon_Shortblade_52',
        [135688] = 'Interface/Icons/INV_Weapon_Shortblade_53',
        [135689] = 'Interface/Icons/INV_Weapon_Shortblade_54',
        [135690] = 'Interface/Icons/INV_Weapon_Shortblade_55',
        [135691] = 'Interface/Icons/INV_Weapon_Shortblade_56',
        [135692] = 'Interface/Icons/INV_Weapon_Shortblade_57',
        [135693] = 'Interface/Icons/INV_Weapon_Shortblade_58',
        [135694] = 'Interface/Icons/INV_Weapon_Shortblade_59',
        [135695] = 'Interface/Icons/INV_Weapon_Shortblade_60',
        [135696] = 'Interface/Icons/INV_Weapon_Shortblade_61',
        [135697] = 'Interface/Icons/INV_Weapon_Shortblade_62',
        [135698] = 'Interface/Icons/INV_Weapon_Shortblade_63',
        [135699] = 'Interface/Icons/INV_Weapon_Shortblade_64',
        [135700] = 'Interface/Icons/INV_Weapon_Shortblade_65',
        [135701] = 'Interface/Icons/INV_Weapon_Shortblade_66',
        [135706] = 'Interface/Icons/INV_WEAPON_SHORTBLADE_71',
        [135708] = 'Interface/Icons/INV_Weapon_Shortblade_73',
        [135709] = 'Interface/Icons/INV_Weapon_Shortblade_74',
        [135710] = 'Interface/Icons/INV_Weapon_Shortblade_75',
        [135713] = 'Interface/Icons/INV_Weapon_Shortblade_78',
        [135714] = 'Interface/Icons/INV_Weapon_Shortblade_79'
    },
    ZulGurubTrinket = {
        [135723] = 'Interface/Icons/INV_ZulGurubTrinket'
    }
}

function C:GetCategoriesCache() return self.categoriesCache end

ABP_MacroIconCategories = C